//----------------------------------------------------------
//	Copyright (C) Siemens AG (1998). All Rights Reserved
//	Product:      SIMATIC PDM
//
//	Device:			Mettler-Toledo Cond 7100e /2(X)H
//	Description:	Device Description
//	Dictionary:		SIPADC01.dct, MT__STTA.dct
//	Copyright:		Mettler Toledo GmbH,
//						Process Analytics
//						P.O.Box
//						8902 Urdorf
//						Switzerland
//
// Last edit:		23.03.2005
//----------------------------------------------------------

MANUFACTURER	142,	// Mettler
DEVICE_TYPE		122,	// Cond 7100e / 2(X)H
DEVICE_REVISION 2,
DD_REVISION		1



#define PDM 



#ifdef PDM
#define AMS_PDM
#define PDM_bool true
#else
#define PDM_bool false
#endif

#include "SI_HlpM.inc"
#include "SIHASTIDENT01.inc"


#define STATUS_SIZE		3	  
#define STATUS_RESPONSE_CODE	0	 							   
#define STATUS_COMM_STATUS	1
#define STATUS_DEVICE_STATUS	2

#define UNIT_SAL		"g/kg"
#define UNIT_CELL		"1/cm"
#define UNIT_TC_LIN		"%/K"
#define UNIT_TEMP_C		"C"
#define UNIT_TEMP_F		"F"
#define UNIT_PERC		"%"
#define UNIT_US			"S"
#define UNIT_MS			"mS"
#define UNIT_SM         "Sm"
#define UNIT_MOHM		"MOhm"
#define UNIT_MA			[mA]
#define UNIT_NON		"";
#define UNIT_SEC	    "s";


#define UNITS_CODE_TEMP_C	32
#define UNITS_CODE_TEMP_F	33
#define UNITS_CODE_OHM		37
#define UNITS_CODE_MA		39
#define UNITS_CODE_SEC		51
#define UNITS_CODE_US		56
#define UNITS_CODE_PERC		57
#define UNITS_CODE_TC_LIN	243
#define UNITS_CODE_CELL		244
#define UNITS_CODE_SAL		246
#define UNITS_CODE_NON		251

#define ALL_UNITS        UNITS_CODE (UNITS_CODE_OHM), UNITS_CODE (UNITS_CODE_US), \
								 UNITS_CODE (UNITS_CODE_TEMP_C), UNITS_CODE (UNITS_CODE_TEMP_F), \
								 UNITS_CODE (UNITS_CODE_MA), UNITS_CODE (UNITS_CODE_PERC), \
								 { UNITS_CODE_TC_LIN, UNIT_TC_LIN }, { UNITS_CODE_SAL, UNIT_SAL }, { UNITS_CODE_CELL, UNIT_CELL }

#define USED_UNITS      UNITS_CODE (UNITS_CODE_OHM), UNITS_CODE (UNITS_CODE_US)

/* Stratos e ab SW 4.0 */
#define USED_UNITS_E    UNITS_CODE (UNITS_CODE_OHM), UNITS_CODE (UNITS_CODE_US), UNITS_CODE (UNITS_CODE_SAL), UNITS_CODE (UNITS_PERC)

#define TEMP_UNITS      UNITS_CODE (UNITS_CODE_TEMP_C), UNITS_CODE (UNITS_CODE_TEMP_F)


#define DISPLAY_SAL		"4.1f";
#define DISPLAY_TEMP_C	"5.1f";
#define DISPLAY_TEMP_F	"5.0f";
#define DISPLAY_CURR   	"4.1f";
#define DISPLAY_PERC   	"5.1f";
#define DISPLAY_SEC		"5.1f";
#define DISPLAY_CONDUCT "5.2f";


/* Transmittervariablen */

#define transvar_cond 		0
#define transvar_res		1
#define transvar_temp   	2
#define transvar_sal		3 

/*****************************/
/* Stratos E                 */
/*****************************/
#define transvar_conductance 4
#define transvar_conc        5
/*****************************/

#define transvar_curr		8
#define transvar_perc		9
#define transvar_input 		10
#define transvar_tc			11
#define transvar_tc_lin		12
#define transvar_lin_log	13
#define transvar_curr_lrv	14
#define transvar_curr_urv	15
#define transvar_diag		16
#define transvar_cell		17
#define transvar_output		18
#define transvar_fix_value	19

/* Stratos e */
#define transvar_conc_sol    	20
#define transvar_sample_cal	    30
#define transvar_filter_1    	31
#define transvar_alarmdelay_1	32
#define transvar_conf_4 		33

/*------------------------------------------------------------------------------------*/

#define selected_pv_enum            \
        TYPE ENUMERATED             \
        {                           \
        IF ((!e2211)&&(!e2211_43)){                \
            { 0, "0.000 S"},       \
		    { 1, "00.00 S"},       \
		    { 2, "000.0 S"},       \
		    { 3, "0000 S"},        \
		    { 4, "0.000 mS"},       \
		    { 5, "00.00 mS"},       \
		    { 6, "000.0 mS"},       \
		    { 7, "0.000 MOhm"},     \
		    { 8, "00.00 MOhm"},     \
		    { 9, "000.0 MOhm"},     \
		    { 10, "000.0 SAL" }     \
        }							\
        IF (e2211_43){              \
            { 0, "0.000 S"},       \
		    { 1, "00.00 S"},       \
		    { 2, "000.0 S"},       \
		    { 3, "0000 S"},        \
		    { 4, "0.000 mS"},       \
		    { 5, "00.00 mS"},       \
		    { 6, "000.0 mS"},       \
		    { 8, "00.00 MOhm"},     \
		    { 10, "000.0 SAL" },    \
            { 11, "00.00 %"},       \
            { 12, "USP"},           \
            { 13, "0.000 S/m"},     \
            { 14, "00.00 S/m"}      \
        }                           \
        IF (e2211_40){				\
		    { 0, "0.000 S"},       \
		    { 1, "00.00 S"},       \
		    { 2, "000.0 S"},       \
		    { 3, "0000 S"},        \
		    { 4, "0.000 mS"},       \
		    { 5, "00.00 mS"},       \
		    { 6, "000.0 mS"},       \
		    { 8, "00.00 MOhm"},     \
		    { 10, "000.0 SAL" },    \
            { 11, "00.00 %"},       \
            { 13, "0.000 S/m"},     \
            { 14, "00.00 S/m"}      \
		}							\
       } /* Type enumerated */


     
     #define selected_pv_meth \
		"0.000 S;00.00 S;000.0 S;0000 S;0.000 mS;00.00 mS;000.0 mS;0.000 MOhm;00.00 MOhm;000.0 MOhm;000.0 SAL"

    /* Stratos e ab SW 4.0 */
    #define selected_pv_meth_e \
		"0.000 S;00.00 S;000.0 S;0000 S;0.000 mS;00.00 mS;000.0 mS;00.00 MOhm;000.0 SAL;00.00 %;0.000 S/m;00.00 S/m"   

    /* Stratos e ab SW 4.3 */
    #define selected_pv_meth_e43 \
		"0.000 S;00.00 S;000.0 S;0000 S;0.000 mS;00.00 mS;000.0 mS;00.00 MOhm;000.0 SAL;00.00 %;USP;0.000 S/m;00.00 S/m"   
      
/*------------------------------------------------------------------------------------*/

#define selected_cell_enum \
	TYPE ENUMERATED{ \
			 { 0, "2-EL"}, \
			 { 1, "4-EL"} }
#define selected_cell_meth "2-EL;4-EL"

/*------------------------------------------------------------------------------------*/
#define selected_temp_unit_enum \
	TYPE ENUMERATED{ \
			 { 0, UNIT_TEMP_C } , \
			 { 1, UNIT_TEMP_F } }
#define selected_temp_unit_meth "C;F"

/*------------------------------------------------------------------------------------*/
#define selected_temp_sensor_enum \
	TYPE ENUMERATED{          \
        IF (!e2211){          \
			 { 0, "Pt100"},   \
			 { 1, "Pt1000"},  \
			 { 2, "NTC100k"}, \
			 { 3, "NTC30k"}   \
        }ELSE{                \
  			 { 0, "Pt100"},   \
			 { 1, "Pt1000"},  \
			 { 3, "NTC30k"},  \
			 { 4, "NTC8.55k"} \
        }                     \
    }

#define selected_temp_sensor_meth "Pt100;Pt1000;NTC100k;NTC30k"
#define selected_temp_sensor_meth_e "Pt100;Pt1000;NTC30k;NTC8.55k"

/*------------------------------------------------------------------------------------*/
#define selected_tc_enum \
	TYPE ENUMERATED{ \
			 { 0, "OFF"}, \
			 { 1, "LIN"}, \
			 { 2, "NLF"}, \
			 { 3, "-01- FCT (NaCl)"}, \
			 { 4, "-02- FCT (HCl)"}, \
			 { 5, "-03- FCT (NH3)"} }
#define selected_tc_meth \
			 "OFF;LIN;NLF;-01- FCT (NaCl);-02- FCT (HCl);-03- FCT (NH3)"
/*------------------------------------------------------------------------------------*/			

#define selected_lin_log_meth "Lin;Log"

/*------------------------------------------------------------------------------------*/
/* #define log_enum klappt mit den Compiler(n) (old + new) nicht                      */
/*------------------------------------------------------------------------------------*/


#define selected_log_meth \
			 "0.1 S/mS/MOhm;1.000 S/mS/MOhm;10.00 S/mS/MOhm;100.0 S/mS/MOhm;1000 S/mS/MOhm"

#define selected_log_meth_e \
			 "0.1 S/mS/Sm/MOhm;1.000 S/mS/Sm/MOhm;10.00 S/mS/Sm/MOhm;100.0 S/mS/Sm/MOhm;1000 S/mS/Sm/MOhm"

#define selected_log_meth_e_sw42 \
			 "0.1 S/0.001 Sm;1.000 S/0.01 Sm;10.00 S/0.1 Sm;100.0 S/1.0 Sm;1 mS/10.0 Sm; 10 mS/100.0 Sm; 100 mS;1000 mS"
             
/*------------------------------------------------------------------------------------*/

#define selected_off_on_enum \
	TYPE ENUMERATED{ \
			 { 0, "Off"}, \
			 { 1, "On "} }
#define selected_off_on_meth "Off;On"

/*------------------------------------------------------------------------------------*/
#define sel_hl0	"Last Value" "|de|Letzter Wert"
#define sel_hl1	"Fixed Current"	"|de|Festwert"
#define selected_hold_last_fix_enum	TYPE ENUMERATED{ { 0, sel_hl0 }, { 1, sel_hl1 } }
#define selected_hold_last_fix_meth	sel_hl0 ";" sel_hl1
/*------------------------------------------------------------------------------------*/


#define def_unit_type \
    CONSTANT_UNIT IF (!e2211){                  \
    SELECT (selected_pv_unit){                  \
			    CASE 0: UNIT_US ;               \
			    CASE 1: UNIT_US ;	            \
			    CASE 2: UNIT_US ;	            \
			    CASE 3: UNIT_US ;	            \
			    CASE 4: UNIT_MS ;	            \
			    CASE 5: UNIT_MS ;	            \
			    CASE 6: UNIT_MS ;	            \
			    CASE 7: UNIT_MOHM ;             \
			    CASE 8: UNIT_MOHM ;             \
			    CASE 9: UNIT_MOHM ;             \
			    DEFAULT: UNIT_SAL ; }           \
        }ELSE{                                  \
                SELECT (selected_pv_unit){      \
			    CASE 0: UNIT_US ;               \
			    CASE 1: UNIT_US ;	            \
			    CASE 2: UNIT_US ;	            \
			    CASE 3: UNIT_US ;	            \
			    CASE 4: UNIT_MS ;	            \
			    CASE 5: UNIT_MS ;	            \
			    CASE 6: UNIT_MS ;	            \
			    CASE 8: UNIT_MOHM ;             \
			    CASE 10: UNIT_SAL ;             \
                CASE 11: UNIT_PERC ;            \
                CASE 12: UNIT_US ;              \
                CASE 13: UNIT_SM ;              \
			    DEFAULT: UNIT_SM ; }            \
        }                                       \
	TYPE FLOAT{ SCALING_FACTOR                  \
        IF (!e2211){                            \
		  SELECT (selected_pv_unit){            \
		    CASE 0: 1 ;	                        \
			CASE 1: 1 ;	                        \
			CASE 2: 1 ;	                        \
			CASE 3: 1 ;	                        \
			CASE 4: 1.0e-3 ;                    \
			CASE 5: 1.0e-3 ;                    \
			CASE 6: 1.0e-3 ;                    \
			CASE 7: 1.0e-6 ;                    \
			CASE 8: 1.0e-6 ;                    \
			CASE 9: 1.0e-6 ;                    \
			DEFAULT: 1 ; }	                    \
        }ELSE{                                  \
		  SELECT (selected_pv_unit){            \
		    CASE 0: 1 ;	                        \
			CASE 1: 1 ;	                        \
			CASE 2: 1 ;	                        \
			CASE 3: 1 ;	                        \
			CASE 4: 1.0e-3 ;                    \
			CASE 5: 1.0e-3 ;                    \
			CASE 6: 1.0e-3 ;                    \
			CASE 8: 1.0e-6 ;                    \
			CASE 10: 1 ;                        \
            CASE 11: 1 ;                        \
            CASE 12: 1 ;                        \
            CASE 13: 0.0001;                    \
			DEFAULT: 0.0001 ; }	                \
        }                                       \
        DISPLAY_FORMAT                          \
          IF (!e2211){                          \
            SELECT (selected_pv_unit){          \
		      CASE 0: "5.3f" ;	                \
		      CASE 1: "5.2f" ;	                \
			  CASE 2: "5.1f" ;	                \
			  CASE 3: "4.0f" ;	                \
			  CASE 4: "5.3f" ;	                \
			  CASE 5: "5.2f" ;	                \
			  CASE 6: "5.1f" ;	                \
			  CASE 7: "5.3f" ;                  \
			  CASE 8: "5.2f" ;                  \
			  CASE 9: "5.1f" ;                  \
			  DEFAULT: DISPLAY_SAL}             \
        }ELSE{                                  \
            SELECT (selected_pv_unit){          \
		      CASE 0: "5.3f" ;	                \
		      CASE 1: "5.2f" ;	                \
			  CASE 2: "5.1f" ;	                \
			  CASE 3: "4.0f" ;	                \
			  CASE 4: "5.3f" ;	                \
			  CASE 5: "5.2f" ;	                \
			  CASE 6: "5.1f" ;	                \
			  CASE 8: "5.2f" ;                  \
              CASE 10: "4.1f";                  \
              CASE 11: "5.2f";                  \
              CASE 12: "5.2f";                  \
              CASE 13: "5.3f";                  \
              DEFAULT: "5.2f";}                 \
        }                                       \
     

/*------------------------------------------------------------------------------------*/
#define pv_unit_type def_unit_type }

#define output_unit_type def_unit_type \
		MIN_VALUE 0.0; \
		MAX_VALUE  IF ((!e2211)&&(!e2211_43)){\
                SELECT (selected_pv_unit){ \
			    CASE 0: 9.99  ;	\
			    CASE 1: 99.99 ;	\
			    CASE 2: 999.9 ;	\
			    CASE 3: 9999  ;	\
			    CASE 4: 9.999 ;	\
			    CASE 5: 99.99 ;	\
			    CASE 6: 999.9 ;	\
			    CASE 7: 99.99 ;	\
			    CASE 8: 9.99  ;	\
			    CASE 9: 99.99  ;	\
			    DEFAULT:  45.0 ; }  \
            }ELSE{ \
            	IF (e2211_43){             \
                	SELECT (selected_pv_unit){ \
			    	CASE 0: 9.999  ;\
			    	CASE 1: 99.99  ;\
			    	CASE 2: 999.9  ;\
			    	CASE 3: 9999   ;\
			    	CASE 4: 9.999  ;\
			    	CASE 5: 99.99  ;\
			    	CASE 6: 999.9  ;\
			    	CASE 8: 9.99   ;\
			    	CASE 10: 45.0  ;\
                	CASE 11: 10.0  ;\
                	CASE 12: 99.99 ;\
                	CASE 13: 9.999 ;\
			    	DEFAULT:  99.99 ; }  \
				}ELSE{					\
					SELECT (selected_pv_unit){ \
			    	CASE 0: 9.999  ;\
			    	CASE 1: 99.99  ;\
			    	CASE 2: 999.9  ;\
			    	CASE 3: 9999   ;\
			    	CASE 4: 9.999  ;\
			    	CASE 5: 99.99  ;\
			    	CASE 6: 999.9  ;\
			    	CASE 8: 9.99   ;\
			    	CASE 10: 45.0  ;\
                	CASE 11: 10.0  ;\
                	CASE 12: 99.99 ;\
                	CASE 13: 9.999 ;\
			    	DEFAULT:  99.99 ; }  \
                }\
            }\
			DEFAULT_VALUE 0.0; \
}\


#define output_unit_type_up def_unit_type \
		MIN_VALUE 0.0; \
		MAX_VALUE  IF ((!e2211)&&(!e2211_43)){\
                SELECT (selected_pv_unit){ \
			    CASE 0: 9.99  ;	\
			    CASE 1: 99.99 ;	\
			    CASE 2: 999.9 ;	\
			    CASE 3: 9999  ;	\
			    CASE 4: 9.999 ;	\
			    CASE 5: 99.99 ;	\
			    CASE 6: 999.9 ;	\
			    CASE 7: 99.99 ;	\
			    CASE 8: 9.99  ;	\
			    CASE 9: 99.99  ;	\
			    DEFAULT:  45.0 ; }  \
            }ELSE{ \
            	IF (e2211_43){             \
                	SELECT (selected_pv_unit){ \
			    	CASE 0: 9.999  ;\
			    	CASE 1: 99.99  ;\
			    	CASE 2: 999.9  ;\
			    	CASE 3: 9999   ;\
			    	CASE 4: 9.999  ;\
			    	CASE 5: 99.99  ;\
			    	CASE 6: 999.9  ;\
			    	CASE 8: 9.99   ;\
			    	CASE 10: 45.0  ;\
                	CASE 11: 10.0  ;\
                	CASE 12: 99.99 ;\
                	CASE 13: 9.999 ;\
			    	DEFAULT:  99.99 ; }  \
				}ELSE{					\
					SELECT (selected_pv_unit){ \
			    	CASE 0: 9.999  ;\
			    	CASE 1: 99.99  ;\
			    	CASE 2: 999.9  ;\
			    	CASE 3: 9999   ;\
			    	CASE 4: 9.999  ;\
			    	CASE 5: 99.99  ;\
			    	CASE 6: 999.9  ;\
			    	CASE 8: 9.99   ;\
			    	CASE 10: 45.0  ;\
                	CASE 11: 10.0  ;\
                	CASE 12: 99.99 ;\
                	CASE 13: 9.999 ;\
			    	DEFAULT:  99.99 ; }  \
                }\
            }\
		DEFAULT_VALUE  IF ((!e2211)&&(!e2211_43)){\
                SELECT (selected_pv_unit){ \
			    CASE 0: 9.99  ;	\
			    CASE 1: 99.99 ;	\
			    CASE 2: 999.9 ;	\
			    CASE 3: 9999  ;	\
			    CASE 4: 9.999 ;	\
			    CASE 5: 99.99 ;	\
			    CASE 6: 999.9 ;	\
			    CASE 7: 99.99 ;	\
			    CASE 8: 9.99  ;	\
			    CASE 9: 99.99  ;	\
			    DEFAULT:  45.0 ; }  \
            }ELSE{ \
            	IF (e2211_43){             \
                	SELECT (selected_pv_unit){ \
			    	CASE 0: 9.999  ;\
			    	CASE 1: 99.99  ;\
			    	CASE 2: 999.9  ;\
			    	CASE 3: 9999   ;\
			    	CASE 4: 9.999  ;\
			    	CASE 5: 99.99  ;\
			    	CASE 6: 999.9  ;\
			    	CASE 8: 9.99   ;\
			    	CASE 10: 45.0  ;\
                	CASE 11: 10.0  ;\
                	CASE 12: 99.99 ;\
                	CASE 13: 9.999 ;\
			    	DEFAULT:  99.99 ; }  \
				}ELSE{					\
					SELECT (selected_pv_unit){ \
			    	CASE 0: 9.999  ;\
			    	CASE 1: 99.99  ;\
			    	CASE 2: 999.9  ;\
			    	CASE 3: 9999   ;\
			    	CASE 4: 9.999  ;\
			    	CASE 5: 99.99  ;\
			    	CASE 6: 999.9  ;\
			    	CASE 8: 9.99   ;\
			    	CASE 10: 45.0  ;\
                	CASE 11: 9.99  ;\
                	CASE 12: 99.99 ;\
                	CASE 13: 9.999 ;\
			    	DEFAULT:  99.99 ; }  \
                }\
            }\
}\

/*------------------------------------------------------------------------------------*/

#define cond_unit_type \
 	CONSTANT_UNIT IF (!e2211){      \
         SELECT (selected_pv_unit){ \
	 	    CASE 0: UNIT_US ;       \
			CASE 1: UNIT_US ;	    \
			CASE 2: UNIT_US ;       \
			CASE 3: UNIT_US ;   	\
			CASE 4: UNIT_MS ;   	\
			CASE 5: UNIT_MS ;    	\
			CASE 6: UNIT_MS ;    	\
			CASE 7: UNIT_US ;	    \
			CASE 8: UNIT_US ;	    \
			CASE 9: UNIT_US ;	    \
			DEFAULT: UNIT_MS ; }	\
         }ELSE{                     \
         SELECT (selected_pv_unit){ \
	 	    CASE 0: UNIT_US ;       \
			CASE 1: UNIT_US ;    	\
			CASE 2: UNIT_US ;   	\
			CASE 3: UNIT_US ;   	\
			CASE 4: UNIT_MS ;   	\
			CASE 5: UNIT_MS ;       \
			CASE 6: UNIT_MS ;	    \
			CASE 8: UNIT_MS ;	    \
			CASE 10: UNIT_MS ;      \
            CASE 11: UNIT_MS ;      \
            CASE 12: UNIT_MS ;      \
            CASE 13: UNIT_MS ;      \
			DEFAULT: UNIT_MS ;      \
         }}                              \
        TYPE FLOAT{                      \
		    SCALING_FACTOR IF (!e2211){  \
              SELECT (selected_pv_unit){ \
		        CASE 0: 1 ;	             \
		    	CASE 1: 1 ;              \
		    	CASE 2: 1 ;	             \
		    	CASE 3: 1 ;	             \
		    	CASE 4: 1.0e-3 ;         \
		    	CASE 5: 1.0e-3 ;         \
		    	CASE 6: 1.0e-3 ;         \
		    	CASE 7: 1 ;	             \
		    	CASE 8: 1 ;	             \
		    	CASE 9: 1 ;	             \
		    	DEFAULT: 1.0e-3 ; }      \
              }ELSE{                     \
              SELECT (selected_pv_unit){ \
		        CASE 0: 1 ;	             \
		    	CASE 1: 1 ;	             \
		    	CASE 2: 1 ;	             \
		    	CASE 3: 1 ;	             \
		    	CASE 4: 1.0e-3 ;         \
		    	CASE 5: 1.0e-3 ;         \
		    	CASE 6: 1.0e-3 ;         \
		    	CASE 8: 1 ;	             \
		    	CASE 10: 1.0e-3 ;	     \
                CASE 11: 1 ;	         \
                CASE 12: 1 ;	         \
                CASE 13: 1 ;	         \
		    	DEFAULT: 1 ; }           \
              }                          \
		    DISPLAY_FORMAT	IF(!e2211){  \
                SELECT (selected_pv_unit){ \
		            CASE 0: "5.3f" ; \
		    	    CASE 1: "5.2f" ; \
		    	    CASE 2: "5.1f" ; \
		    	    CASE 3: "4.0f" ; \
		    	    CASE 4: "5.3f" ; \
		    	    CASE 5: "5.2f" ; \
		    	    CASE 6: "5.1f" ; \
		    	    CASE 7: "5.3f" ; \
		    	    CASE 8: "5.2f" ; \
		    	    CASE 9: "5.1f" ; \
		    	    DEFAULT:"5.1f" ; }\
               }ELSE{\
                    SELECT (selected_pv_unit){ \
		            CASE 0: "5.3f" ; \
		    	    CASE 1: "5.2f" ; \
		    	    CASE 2: "5.1f" ; \
		    	    CASE 3: "4.0f" ; \
		    	    CASE 4: "5.3f" ; \
		    	    CASE 5: "5.2f" ; \
		    	    CASE 6: "5.1f" ; \
		    	    CASE 8: "5.2f" ; \
		    	    CASE 10:"5.1f"; \
                    CASE 11:"5.2f"; \
                    CASE 12:"5.2f"; \
                    CASE 13:"5.2f"; \
                    DEFAULT:"5.2f" ; }\
               }\
}




#define res_unit_type                  \
 	CONSTANT_UNIT UNIT_MOHM ;          \
	TYPE FLOAT{	                       \
		SCALING_FACTOR  1.0e-6 ;       \
		DISPLAY_FORMAT	IF (!e2211){   \
        SELECT (selected_pv_unit){     \
		    CASE 0: "5.1f" ;           \
			CASE 1: "5.2f" ;           \
			CASE 2: "5.3f" ;           \
			CASE 3: "5.3f" ;           \
			CASE 4: "5.3f" ;           \
			CASE 5: "5.3f" ;           \
			CASE 6: "5.3f" ;           \
			CASE 7: "5.3f" ;           \
			CASE 8: "5.2f" ;           \
			CASE 9: "5.1f" ;           \
			DEFAULT:"5.1f" ; }         \
        }ELSE{                          \
        SELECT (selected_pv_unit){     \
		    CASE 0: "5.1f" ;           \
			CASE 1: "5.2f" ;           \
			CASE 2: "5.3f" ;           \
			CASE 3: "5.3f" ;           \
			CASE 4: "5.3f" ;           \
			CASE 5: "5.3f" ;           \
			CASE 6: "5.3f" ;           \
			CASE 8: "5.2f" ;           \
			CASE 10: "5.1f";           \
            CASE 11: "5.2f";           \
            CASE 12: "5.3f";           \
            CASE 13: "5.3f";           \
			DEFAULT:"5.3f" ; }         \
        }                              \
    }                                  



/*------------------------------------------------------------------------------------*/

#define sel_cs0	"00: NaCl"
#define sel_cs1 "01: HCl"
#define sel_cs2 "02: NaOH"
#define sel_cs3 "03: H2SO4"
#define sel_cs4 "04: HNO3"
#define selected_conc_sol_enum 		TYPE ENUMERATED{ { 0, sel_cs0 }, { 1, sel_cs1 }, { 2, sel_cs2 }, { 3, sel_cs3 }, { 4, sel_cs4 } }
#define selected_conc_sol_meth 		sel_cs0 ";" sel_cs1 ";" sel_cs2 ";" sel_cs3 ";" sel_cs4 

/*------------------------------------------------------------------------------------*/

#define sv_unit_type \
	CONSTANT_UNIT   IF (sv_temp_units == UNITS_CODE_TEMP_C) { UNIT_TEMP_C; }ELSE{  UNIT_TEMP_F; } \
   TYPE FLOAT{ DISPLAY_FORMAT IF (sv_temp_units == UNITS_CODE_TEMP_C) { DISPLAY_TEMP_C }ELSE{ DISPLAY_TEMP_F } }






/**/
/*                                                                                                            */
/*      SSSS  TTTTT  RRRR    AAA   TTTTT   OOO    SSSS        EEEEE                                           */
/*     S        T    R   R  A   A    T    O   O  S            E                                               */
/*      SSS     T    RRRR   AAAAA    T    O   O   SSS         EEEE                                            */
/*         S    T    R  R   A   A    T    O   O      S        E                                               */
/*     SSSS     T    R   R  A   A    T     OOO   SSSS         EEEEE                                           */
/*                                                                                                            */
/**/

#define e2211_SW_rev			40
#define e2211_SW_rev43			43

#define e2211					(software_revision >= e2211_SW_rev) 
#define e2211_40				((software_revision >= e2211_SW_rev) && (software_revision < e2211_SW_rev43))
#define e2211_43				(software_revision >= e2211_SW_rev43)

#define e2211_meth_43		    (int_value( software_revision ) >= e2211_SW_rev43)
#define e2211_meth				(int_value( software_revision ) >= e2211_SW_rev)


#define x2211( _new, _old ) 	IF( e2211 ){ _new }ELSE{ _old }	

#define valid_2211				VALIDITY x2211( FALSE;, TRUE; ) 
#define valid_e2211				VALIDITY x2211( TRUE;, FALSE; ) 





#define e2211_conc ((software_revision >= e2211_SW_rev) && (selected_pv_unit == 11))
#define x2211_conc ( _new, _old) IF( e2211_conc ){ _new }ELSE{ _old }	
#define valid_e2211_conc VALIDITY x2211_conc( TRUE;, FALSE; )


//=============================================================================
//  VARIABLEN
//=============================================================================

VARIABLE response_code		// Standard-Variable
{
  LABEL	[response_code];
  HELP	[command_specific_response_code_help];
  CLASS USER_INTERFACE & DIAGNOSTIC;
  HANDLING READ;
  TYPE ENUMERATED {
    {  0, [success] },
    {  1, [undefined] },
    {  2, [invalid_selection] },
    {  3, [passed_parameter_too_large] },
    {  4, [passed_parameter_too_small] },
    {  5, [too_few_data_bytes_recieved] },
    {  6, [xmtr_specific_command_error] },
    {  7, [in_write_protect_mode] },
    {  8, [xmtr_specific_command_error] },
    {  9, [xmtr_specific_command_error] },
    { 10, [xmtr_specific_command_error] },
    { 11, "Invalid Transmitter Variable" },
    { 12, "Invalid Unit Code" },
    { 13, [xmtr_specific_command_error] },
    { 14, [xmtr_specific_command_error] },
    { 15, [xmtr_specific_command_error] },
    { 16, [access_restricted] },
    { 32, [busy] },
    { 64, [command_not_implemented] }
  }
}

//-------------------------------------

VARIABLE device_status		// Standard-Variable
{
  LABEL	[device_status] ;
  HELP	[field_device_status_help];
  CLASS HART & DYNAMIC & DIAGNOSTIC;
  HANDLING READ;
  TYPE BIT_ENUMERATED {
    { 0x00, [no_error], MISC },
    { 0x01, "Primary variable outside limits"	"|de|Hauptvariable auerhalb Bereich", DV1 (AUTO & BAD) },
    { 0x02, "Temperature outside limits"	"|de|Nebenvariable auerhalb Bereich", DV2 (AUTO & BAD) },
    { 0x04, "Output outside operating range"	"|de|Ausgang auerhalb Mebereich",    AO1 (AUTO & BAD) },
    { 0x08, "Output in fixed mode"		"|de|Ausgang ist auf Festwert",	       AO1 (MANUAL & GOOD) },
    { 0x10, "More Status available"		"|de|Gert hat mehr Informationen",    MORE },
    { 0x20, "Device cold start"			"|de|Feldgert Kaltstart",	       MISC },
    { 0x40, "Configuration has been changed"	"|de|Konfiguration wurde verndert",   MISC & IGNORE_IN_HANDHELD },
    { 0x80, "Device malfunction or failure"	"|de|Gertefehlern oder Ausfall",      MORE}
  }
}


VARIABLE xmtr_specific_status_0 
{
	LABEL	"Error Status""|de|Fehlerzustnde" ;
	HELP   	"Field Device Error Status- Failure messages of the Field Device are listed" "|de|Feldgertfehlermeldungen";
    STYLE "MULTILINE 12 4";	 
	 TYPE		BIT_ENUMERATED {

			{ 0x01, "Err 01 Sensor" "|de|Err 01 Sensor-Fehler", DV1 (AUTO & BAD) } ,
			{ 0x02, "Err 02 Unsuitable Sensor" "|de|Err 02 ungeeigneter Sensor", DV1 (AUTO & BAD) } ,
			{ 0x04, "Err 03 Temp Value" "|de|Err 03 Temperaturfhler", TV1 (AUTO & BAD) } ,
			{ 0x08, "Err 11 Loop < 3.8mA" "|de|Err 11 Stromausgang < 3,8 mA", AO1 (AUTO & BAD) } ,
			{ 0x10, "Err 12 Loop >20.5mA" "|de|Err 12 Stromausgang > 20.5 mA", AO1 (AUTO & BAD) } ,
			{ 0x20, "Err 13 Loop Span" "|de|Err 13 Stromspanne zu klein / zu gro", DATA } ,
			{ 0x40, "Err 98 Config Data" "|de|Err 98 Systemfehler", HARDWARE } ,
			{ 0x80, "Err 99 Data Lost" "|de|Err 99 Abgleichdaten defekt", HARDWARE }	}
}


VARIABLE xmtr_specific_status_2 {
	LABEL 	"Smiley Sad""|de|Smiley traurig" ;
	HELP  	"Smiley Sad - Correct measurment is no longer ensured. Sensoface provides information on wear and required maintance. However, device continues operation with seriously diminished accuracy."
			"|de| Smiley traurig - Eine korrekte Messung wird nicht mehr gewhrleistet!  Sensoface gibt Hinweise zum Zustand Ihrer Mekette.";
    STYLE "MULTILINE 12 3";
	TYPE  	BIT_ENUMERATED {

			{ 0x04, "Err 33 Sensocheck" "|de|Err 33 Sensocheck", PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x40, "Err Cell Constant" "|de|Zellkonstante auerhalb des Bereiches", PROCESS & IGNORE_IN_HANDHELD }
		 }
		}


VARIABLE analog_output_saturated1 {
 	 TYPE  BIT_ENUMERATED {
			{ 0x01, "Analog Out Saturated" "|de|Analoge Ausgang befindet sich in Sttigung", AO1 (AUTO & BAD) }
	 }
}



VARIABLE analog_output_fixed1 {
	LABEL "HOLD Mode" "|de|Hold Modus" ;
	HELP  "Analog Outputs of the Field Device are fixed in HOLD mode. The analog and digital Outputs remain unchanged." 
		  "|de|Der Analoge Ausgang des Feldgertes befindet sich im HOLD-Modus." ;
	TYPE  BIT_ENUMERATED{
						{ 0x01, "HOLD Mode" "|de|HOLD-Modus", AO1 (MANUAL & GOOD) }
	}
}

//-------------------------------------

VARIABLE tag
{
  LABEL	[tag];
  HELP	[tag_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(8); 
  HANDLING READ & WRITE;
}

//-------------------------------------

VARIABLE descriptor
{
  LABEL	[descriptor];
  HELP	[discriptor_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(16); 
  HANDLING READ & WRITE;
}

//-------------------------------------

VARIABLE message
{
  LABEL	[message];
  HELP	[message_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(32);
  HANDLING READ & WRITE;
}

//-------------------------------------


VARIABLE manufacturer_id
{
  LABEL	[manufacturer_id];
  HELP	[manufacturer_id_code_help];
  HANDLING READ;
  CLASS HART;
  TYPE ENUMERATED {
    DEFAULT_VALUE 142;
    { 142,  "Mettler Toledo" }
  }
}
//-------------------------------------

VARIABLE universal_revision
{
  LABEL	[universal_revision];
  HELP	[universal_revision_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
}

//-------------------------------------

VARIABLE transmitter_revision
{
  LABEL	[transmitter_revision];
  HELP	[field_device_revision_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
}

//-------------------------------------

VARIABLE software_revision
{
  LABEL	[software_revision];
  HELP	[field_device_software_revision_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
  DEFAULT_VALUE 43;
}

//-------------------------------------

VARIABLE hardware_revision
{
  LABEL	[hardware_revision];
  HELP	[hardware_revision_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER;
}

//-------------------------------------

VARIABLE device_id
{
  LABEL	[device_identification];
  HELP	[field_device_identification_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER(3);
}

//-------------------------------------

VARIABLE device_type 
{
  LABEL	[device_type];
  HELP	[manufacturers_device_type_help];
  HANDLING READ;
  CLASS HART; 
  TYPE ENUMERATED(1) {
    IF( manufacturer_id == 142 ) {	// Mettler Toledo Device Types
      { 122, "Cond 7100e/2(X)H" }
    }
    { 252, [unknown] }
  }
}

//-------------------------------------

VARIABLE request_preambles
{
  LABEL	[number_of_request_preambles];
  HELP	[number_of_request_preambles_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER {
    INITIAL_VALUE 5;
    DEFAULT_VALUE 5;
    MIN_VALUE  2;
    MAX_VALUE 20;
  }
}

//-------------------------------------

VARIABLE response_preambles
{
  LABEL	[number_of_response_preambles];
  HELP	[number_of_response_preambles_help];
  HANDLING WRITE;
  CLASS HART;
  TYPE UNSIGNED_INTEGER	{
    INITIAL_VALUE 5;
    DEFAULT_VALUE 5;
  }
}

//-------------------------------------

VARIABLE device_flags
{
  LABEL	[device_flags];
  HELP	[field_device_flags_help];
  HANDLING READ;
  CLASS HART; 
  TYPE BIT_ENUMERATED {
    { 0x01, [Multisens_Dev], [multi_sensor_fld_dev] },
    { 0x02, [EEPROM_Ctrl] },
    { 0x04, [protocol_bridge_device] }
  }
}

//-------------------------------------

VARIABLE physical_signaling_code
{															  
  LABEL	[physical_signalling_code];
  HELP	[physical_signalling_code_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    { 0, [bell_202_current] },
    { 1, [bell_202_voltage] },
    { 2, [rs_485] },
    { 3, [rs_232], [rs_232_help] },
    { 6, [special] }
  }
}

//-------------------------------------

VARIABLE final_assembly_number
{
  LABEL	[final_assembly_number];
  HELP	[final_assembly_number_help];
  HANDLING READ & WRITE;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER(3) {
    MAX_VALUE 16777215;
  }
}

//-------------------------------------

VARIABLE date
{
  LABEL	[date];
  HELP	[date_help];
  HANDLING READ & WRITE;
  CLASS DEVICE;
  TYPE DATE;
}

//-------------------------------------

VARIABLE primary_damping_value
{
  LABEL	[damping_value];
  HELP	[seconds_damping_value_help]; 
  CLASS CORRECTION;
  TYPE FLOAT {
    DISPLAY_FORMAT	".2f";
  }
  CONSTANT_UNIT	[sec];
  HANDLING READ & WRITE;
}


//-------------------------------------

VARIABLE dummy_status
{	LABEL		"dummy" ;
	HELP		" " ;
	HANDLING READ ;
	TYPE		BIT_ENUMERATED {
     /* HC275:"1234567890123456" */
		{ 0x01, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x02, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x04, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x08, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x10, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x20, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x40, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x80, " ", MISC & IGNORE_IN_HANDHELD }
	}
}

//-------------------------------------

VARIABLE function_check_status {
	CLASS    DEVICE & DYNAMIC;
	LABEL		"Device Status" "|de|Gertestatus" ;
	HELP		"Device status and mode" "|de|Gertestatus und Zustnde";
	STYLE "MULTILINE 12 3";
	HANDLING READ ;
	TYPE		BIT_ENUMERATED {
     /* HC275:"1234567890123456" */
		{ 0x01, "Configuration" "|de|Konfiguration", MODE & IGNORE_IN_HANDHELD } ,
		{ 0x02, "Calibration" "|de|Kalibrierung", MODE & IGNORE_IN_HANDHELD } ,
		{ 0x04, "Sample was taken" "|de|Produktkalbrierung gestartet", MISC & IGNORE_IN_HANDHELD }
	}
	valid_e2211
}
/*------------------------------------------------------------------------------------*/
/*		definition of collection for dynamic variables								  */
/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE pv {
	LABEL           [pv] ;
	HELP            [primary_variable_help] ;
	MEMBERS         {
			 /*             Sensor Correction Information                          			  */
			 DIGITAL_UNITS,         sensor_units,           [units],                        [digital_units_help] ;
			 DIGITAL_VALUE,         sensor_value,           [blank],                        [digital_value_help] ;
			 SENSOR_UNITS,          sensor_units,           [sensor_unit],                  [digital_units_help] ;

			 UPPER_SENSOR_LIMIT,    sensor_upper_limit,     [usl],                          [upper_sensor_limit_help] ;
			 LOWER_SENSOR_LIMIT,    sensor_lower_limit,     [lsl],                          [lower_sensor_limit_help] ;
			 MINIMUM_SPAN,          sensor_minimum_span,    [minimum_span],                 [minimum_span_help] ;
			 
			 /*             Analog Output Information                                       */
			 ANALOG_VALUE,          mA_output_current,      [analog_output_value],          [analog_value_help] ;
			 ALARM_CODE,            analog_alarm_code,      [alarm_select],                 [alarm_code_help] ;
			 
			 /*             Input Information                                               */
			 PERCENT_RANGE,         percent_of_range,       [percent_of_range_help] ;
			 TRANSFER_FUNCTION,     xmtr_transfer_function, [transfer_function_help] ;
			 RANGE_UNITS,           sensor_units,           [range_units_help] ;

			 UPPER_RANGE_VALUE,     output_current_urv,[urv],[upper_range_value_help] ;
			 LOWER_RANGE_VALUE,     output_current_lrv,[lrv],[lower_range_value_help] ;
			 SENSOR_SERIAL_NUMBER,  sensor_serial_number,   [sensor_serial_number],         [sensor_serial_number_help] ;
			 DAMPING_VALUE,         sensor_damping_value,   [damping_value],                [seconds_damping_value_help] ;
			}
}


/* 2211pH */
#define def_config_variables \
        selected_pv_unit, \
        selected_cell_type,\
        selected_22mA,\
        selected_hold_last_fix,\
        var_fix_value, \
        selected_temp_unit,\
        selected_temp_sensor,\
        selected_lin_log, \
        selected_log_lr, \
        selected_log_ur, \
        output_current_urv, \
        output_current_lrv,  \
        selected_TC_func,\
        var_TC_lin,\
        selected_senso_check

#define def_config_variables_e 	\
    selected_pv_unit,			\ 
    selected_cell_type,			\
    selected_temp_unit, 		\
    selected_temp_sensor,		\
    output_current_urv,			\
    output_current_lrv,			\
    selected_22mA,				\
    selected_hold_last_fix,		\
    var_fix_value, 				\
    selected_TC_func,			\
    var_TC_lin,					\
    selected_senso_check, 		\
    var_filter_1,				\
    var_alarmdelay_1,           \
    selected_holdLED,
	
/* #define def_config_variables_e_conc 	\
    def_config_variables_e, \
	selected_conc_sol */


MENU upload_variables
{
	LABEL "Upload Variables";
   
		ITEMS { 	polling_address,
    				tag,	   
    				descriptor,																		   
    				message,
    				final_assembly_number,
    				date,
    				response_preambles,
					sensor_value,

					IF (software_revision >= e2211_SW_rev){
						
							IF (selected_pv_unit_local == 0){
								def_config_variables_e				
							    selected_lin_log,			
							    selected_log_lr,			
							    selected_log_ur
							}
							 	
							ELSE{
								def_config_variables_e				
							 	selected_conc_sol
							}

					}ELSE{
						def_config_variables
					}
					
   		}
}



MENU download_variables		// Lesen aus Feldgert
{
  LABEL	[menu_load_to_PC];
  ITEMS {
    		tag,		//--- Standard-HART-Parameter ---
    		descriptor,
    		message,
    		manufacturer_id,
    		universal_revision,
    		transmitter_revision,
    		software_revision,
    		hardware_revision,
    		device_id,
    		device_type,
    		device_flags,
    		physical_signaling_code,
    		final_assembly_number,
    		date,
			sensor_value,

	 		IF (software_revision >= e2211_SW_rev){
	 			
	 				IF(selected_pv_unit_local == 0){
	 					def_config_variables_e				
	 				    selected_lin_log,			
	 				    selected_log_lr,			
	 				    selected_log_ur
	 
	 				}
	 				 	
	 				ELSE{
	 					def_config_variables_e				
	 				 	selected_conc_sol
	 				}

	 		}ELSE{
	 			def_config_variables
	 		}	

  }
	PRE_READ_ACTIONS{
		pre_load	
	}
}



METHOD pre_load
{
	LABEL "Pre-Read for Up/Download Menu";
	DEFINITION
	{

		send_command( 15 );


		 if (sensor_units == UNITS_CODE_PERC){
			assign_int (selected_pv_unit_local , 1);
		 }else{
		 	assign_int (selected_pv_unit_local , 0);		
		 }

	}
}

/*------------------------------------------------------------------------------------*/
/* Hilfsvariablen zum fllen von Lcken, Inhalt wird verworfen						  */
/*------------------------------------------------------------------------------------*/

VARIABLE dummy1
{
  CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
  LABEL	"Dummy1Byte";
  HANDLING READ & WRITE;
  TYPE UNSIGNED_INTEGER(1);
}

VARIABLE dummy4
{
  CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
  LABEL	"Dummy4Byte";
  HANDLING READ & WRITE;
  TYPE UNSIGNED_INTEGER(4);
}


/*------------------------------------------------------------------------------------*/
/*      transmitter-specific commands #128, #129                                      */
/*------------------------------------------------------------------------------------*/

#define send_trans_read( _status, _transvar ) \
				if( e2211_meth ){ \
					iassign( selection_code_index_e, _transvar ); \
					send_trans( 128, 3, _status ); \
				}else{ \
					iassign( selection_code_index, _transvar ); \
					send_trans( 128, 2, _status ); \
				}

#define send_trans_write( _status, _transvar ) \
				if( e2211_meth ){ \
					iassign( selection_code_index_e, _transvar ); \
					send_trans( 129, 3, _status ); \
				}else{ \
					iassign( selection_code_index, _transvar ); \
					send_trans( 129, 2, _status ); \
				}

/*-------------------------------------------*/

REFRESH rel_pv_unit
{
	sensor_units, selected_pv_unit :
	sensor_value, 	var_cond, var_res, var_sample_cal,
	sensor_upper_limit, sensor_lower_limit, sensor_minimum_span,
	output_current_urv ,output_current_lrv, var_cellconstant, analog_output_fixed1  
}

/*-------------------------------------------*/

REFRESH rel_sv_unit
{
	selected_temp_unit :
	sv_temp_value, var_temp
}

/*-------------------------------------------*/

REFRESH rel_status
{
	function_check_status :
	def_config_variables_e
	
}


/*------------------------------------------------------------------------------------*/
/* Hilfsvariablen um zusammengesetzte Transmitter Variablen zu definieren			  */
/*------------------------------------------------------------------------------------*/

VARIABLE selection_code_index
{
  CLASS USER_INTERFACE;
  LABEL	"Sel. Code Index";
  HELP	"";
  TYPE INDEX selection_codes;
  HANDLING READ & WRITE;
}  


VARIABLE selection_code_index_e
{
  CLASS USER_INTERFACE;
  LABEL	"Sel. Code Index e";
  HELP	"";
  TYPE INDEX selection_codes_e;
  HANDLING READ & WRITE;
} 

ARRAY OF COLLECTION selection_codes
{
  LABEL	"Selection Codes";
  HELP	"";
  ELEMENTS {
    transvar_input, input1_selection_code, 	"";
    transvar_tc, TC_selection_code, 	"";
    transvar_lin_log, output1_function_code, 	"";
    transvar_diag, diag_code, 		"";
    transvar_output, output1_selection_code, 	"";
   }
} 

ARRAY OF COLLECTION selection_codes_e
{
  LABEL	"Selection Codes";
  HELP	"";
  ELEMENTS {
      transvar_conf_4, conf_4_selection_code, "";
      transvar_conc_sol, conc_sol_selection_code, "";

   }
} 
/*------------------------------------------------------------------------------------*/

/*------------------------------------------------------------------------------------*/
 


COLLECTION OF VARIABLE input1_selection_code
{
  LABEL "Input Selection Code";
  MEMBERS {
    BYTE1,	selected_pv_unit ;
    BYTE2,	selected_cell_type ;
    BYTE3,	selected_temp_unit ;
    BYTE4,	selected_temp_sensor ;
  }
}

/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE TC_selection_code
{
  LABEL "TC Selection Code";
  MEMBERS {
    BYTE1,	selected_TC_func ;
    BYTE2,	dummy1 ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE output1_function_code
{
  LABEL "Output Function Code";
  MEMBERS {
    BYTE1,	selected_lin_log ;
    BYTE2,	selected_log_lr ;
    BYTE3,	selected_log_ur ;
    BYTE4,	dummy1 ;
  }
}

/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE diag_code
{
  LABEL "Diag. Code";
  MEMBERS {
    BYTE1,	selected_senso_check ;
    BYTE2,	dummy1 ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE output1_selection_code
{
  LABEL "Output Selection Code";
  MEMBERS {
    BYTE1,	selected_22mA ;
    BYTE2,	selected_hold_last_fix ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

COLLECTION OF VARIABLE conc_sol_selection_code
{
    LABEL "Conc Solution" "|de|Konzentrationslsung";
    MEMBERS {
        BYTE1, selected_conc_sol;
        BYTE2, dummy1;
        BYTE3, dummy1;
        BYTE4, dummy1;
    }
}
/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE conf_4_selection_code
{
  LABEL "Conf.4 Sel. Code";
  MEMBERS {
    BYTE1,	selected_holdLED;
    BYTE2,	dummy1 ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*------------------------------------------------------------------------------------*/

VARIABLE sensor_units
{
	CLASS           INPUT;
	LABEL           "PV Unit" ;
	HELP            [digital_units_help] ;
	HANDLING        READ & WRITE ;
/*	TYPE            ENUMERATED { IF (!e2211) {USED_UNITS}ELSE{USED_UNITS_E} }*/
  TYPE ENUMERATED {
    { 37, UNIT_MOHM,   UNIT_MOHM },
    { 56, UNIT_US,     UNIT_US },
	{ 57, UNIT_PERC,   UNIT_PERC},
    { 246, UNIT_SAL,   UNIT_SAL}
  }
}

VARIABLE sensor_value
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           [pv] ;
	HELP            [digital_value_help] ;
	HANDLING        READ ;
	pv_unit_type
}

VARIABLE sensor_upper_limit
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "PV USL" ;
	HELP            [upper_sensor_limit_help];
	HANDLING        READ;
	pv_unit_type
}

VARIABLE sensor_lower_limit
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "PV LSL" ;
	HELP            [lower_sensor_limit_help] ;
	HANDLING        READ ;
	pv_unit_type
}

VARIABLE sensor_minimum_span
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "Min. Span" ;
	HELP            [minimum_span_help] ;
	HANDLING        READ ;
	pv_unit_type
}

VARIABLE sensor_damping_value
{
	CLASS           INPUT;
	LABEL           [pv_damping_value] ;
	HELP            [seconds_damping_value_help] ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   [sec] ;
	TYPE            INTEGER (4) ;
}

VARIABLE analog_alarm_code
{
	CLASS           ANALOG_OUTPUT ;
	LABEL           [alarm_select] ;
	HELP            [alarm_code_help] ;
	HANDLING        READ ;
	TYPE            ENUMERATED
			{
			 ALARM_SELECTION_CODE(0) ,
			 ALARM_SELECTION_CODE(1) ,
			 ALARM_SELECTION_CODE(239) ,
			 ALARM_SELECTION_CODE(250) ,
			 ALARM_SELECTION_CODE(251) ,
			 ALARM_SELECTION_CODE(252) ,
			 ALARM_SELECTION_CODE(253)
			}
}

VARIABLE xmtr_transfer_function
/*
	From Table 9.2 of the Transmitter Specific Document, Rev 5.0.
	Subset of Table III, Transfer Function Codes.
*/
{
	CLASS           CORRECTION;
	LABEL           [transfer_function] ;
	HELP            "You can choose the kind of dependence of the current from the digital value";
	HANDLING        READ & WRITE ;
	TYPE            ENUMERATED
			{
			 TRANSFER_FUNCTION_CODE (0),            /* Linear */
			 TRANSFER_FUNCTION_CODE (1)             /* Square Root */
			}
}

//-------------------------------------

VARIABLE write_protect
{
  LABEL	[write_protect];
  HELP	[write_protect_mode_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    {   0, [not_write_protected] },
    {   1, [write_protected] },
    { 250, [not_used] },
    { 251, [none] },
    { 252, [unknown] },
    { 253, [special] }
  }
}

//-------------------------------------

VARIABLE private_label_distributor
{
  LABEL	[private_label_distributor];
  HELP	[private_label_distributor_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    { 142, "Mettler Toledo"}
  }
}


VARIABLE primary_analog_current_value
{   
  LABEL	[analog_value_block_1];
  HELP	[analog_value_help];    
  CLASS	CONTAINED & DYNAMIC;
  HANDLING READ;  
  CONSTANT_UNIT	[mA]; 
  TYPE FLOAT {
    DISPLAY_FORMAT	".3f";
  }
}


VARIABLE sensor_serial_number
{
	CLASS           DEVICE;
	LABEL           "Number" ;
	HELP            [sensor_serial_number_help] ;
	HANDLING        READ & WRITE ;
	TYPE            UNSIGNED_INTEGER (3) ;
}

/*	secondary variable for universal command #3		*/

VARIABLE sv_temp_value
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "SV" ;
	HELP			"Temperature for conductivity temperature compensation if applied" ;
	HANDLING        READ ;
	sv_unit_type
}

VARIABLE sv_temp_units
{
  LABEL	"Unit";
  HELP	[digital_units_help];
  CLASS CORRECTION & DYNAMIC;
  HANDLING READ & WRITE;
  DEFAULT_VALUE	32;
  TYPE ENUMERATED {
    { 32, [degC],    [degrees_celsius_help] },
    { 33, [degF],    [degrees_fahrenheit_help] }
  }
}

/********************************************************************************************************/
/*      array and index for transmitter-specific commands                                               */
/********************************************************************************************************/

VARIABLE transmitter_variable_index
{
	CLASS           USER_INTERFACE ;
	LABEL           [blank] ;
	TYPE            INDEX transmitter_variable_array ;
}

ARRAY OF VARIABLE transmitter_variable_array
{
	ELEMENTS {											/* Var Nr */
		transvar_cond, 			var_cond ;				/*   00   */
		transvar_res, 			var_res ;				/*   01   */
		transvar_temp, 			var_temp ;				/*   02   */		
		transvar_sal, 			var_salinity ;			/*   03   */
        transvar_conductance, 	var_conductance;		/*   04   */
        transvar_conc, 			var_conc;				/*   05   */
        transvar_curr, 			mA_output_current ;		/*   08   */
		transvar_perc, 			percent_of_range ;		/*   09   */
		transvar_tc_lin, 		var_TC_lin ;			/*   12   */
		transvar_curr_lrv, 		output_current_lrv ;	/*   14   */
		transvar_curr_urv, 		output_current_urv ;	/*   15   */
		transvar_cell, 			var_cellconstant ;		/*   17   */
		transvar_fix_value, 	var_fix_value ;		    /*   19   */
		transvar_sample_cal,	var_sample_cal ;	    /*   30   */
	    transvar_filter_1,		var_filter_1 ;		    /*   31   */
	    transvar_alarmdelay_1,	var_alarmdelay_1 ;		/*   32   */
	}
}

/********************************************************************************************************/
/*              transmitter specfic variables (9.3)                                                     */
/********************************************************************************************************/

																							     /* V0  */
VARIABLE var_cond                                                               
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "Cond" ;
	HELP            "Conductivity, temperature compensated if applied" ;
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_US;
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_CONDUCT }
}       

/********************************************************************************************************/

VARIABLE var_res                                                                                 /* V1  */
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "Resist" "|de|Widerstnad" ;
	HELP            "Specific resistance, temperature compensated if applied" ;
	HANDLING        READ ;
	res_unit_type	
}

/********************************************************************************************************/

VARIABLE var_temp																				 /* V2  */
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "Temp" "|de|Temperatur";
	HELP			"Temperature for conductivity temperature compensation if applied" ;
	HANDLING        READ ;
	sv_unit_type
}

/********************************************************************************************************/

VARIABLE var_salinity                                                                            /* V3  */
{
	CLASS           COMPUTATION & DYNAMIC ;
	LABEL           "Salinity" "|de|Salinitt" ;
	HELP            "Salinity calculated from conductivity and temperature"  ;
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_SAL;
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_SAL }
}


/********************************************************************************************************/
/*                                     Stratos e                                                        */
/********************************************************************************************************/

VARIABLE var_conductance																		 /* V4  */
{
    LABEL "Conductance Value";
    HELP  "Conductance Value without TK";
    CLASS INPUT & DYNAMIC;
    HANDLING READ & WRITE;
    CONSTANT_UNIT   UNIT_US;
    TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_CONDUCT }
}

/********************************************************************************************************/

VARIABLE var_conc																				 /* V5  */
{
    LABEL "Concentration" "|de|Konzentration";
    HELP  "";
    CLASS INPUT & DYNAMIC;
    HANDLING READ & WRITE;
    CONSTANT_UNIT UNIT_PERC;
    TYPE FLOAT { DISPLAY_FORMAT DISPLAY_PERC } 
}

/********************************************************************************************************/

VARIABLE mA_output_current                                                                       /* V8  */
{
	CLASS           ANALOG_OUTPUT & DYNAMIC ;
	LABEL           "PV AO" ;
	HELP            [analog_value_help] ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MA ;
	TYPE            FLOAT{
		DISPLAY_FORMAT	DISPLAY_CURR	
		EDIT_FORMAT		DISPLAY_CURR 
	}
}

/********************************************************************************************************/

VARIABLE percent_of_range                                                                        /* V9  */
{
	CLASS           ANALOG_OUTPUT & DYNAMIC ;
	LABEL           "PV %" ;
	HELP            [percent_of_range_help] ;
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_PERC;
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_PERC }
}

/********************************************************************************************************/
/*      variable declarations for the input selection codes 9.4                                         */
/********************************************************************************************************/

VARIABLE selected_pv_unit                                                                      /* V10.0 */
{
	CLASS 			 INPUT;
	LABEL           "PV Range/Unit" ;
	HELP            "Select display format" ;
	HANDLING        READ & WRITE ;
	selected_pv_enum


//	POST_READ_ACTIONS{
//		method_set_concentration
//	}
	
	POST_EDIT_ACTIONS{
		 pre_test
		 method_set_lin
	}

	POST_WRITE_ACTIONS{
		pre_test
	}

}


METHOD pre_test
{
	LABEL "Pre Test Method";
	DEFINITION
	{
		if (selected_pv_unit !=  11){
	   		assign_int( selected_pv_unit_local, 0 ); 
		}else{
			assign_int( selected_pv_unit_local, 1 );		
		}
	}
}
 
VARIABLE selected_pv_unit_local                                                                /* V10.0 */
{
	CLASS 			LOCAL;
	HANDLING        READ & WRITE;
	TYPE			INTEGER;

}

METHOD method_set_concentration
{
  CLASS	INPUT;
  DEFINITION
  {
   	if  ((selected_pv_unit==11)){
		   assign_int( selected_pv_unit_local, 1 );
	} else{
	   	assign_int( selected_pv_unit_local, 0 ); 	
	}  
  } 
}


     


/********************************************************************************************************/

VARIABLE selected_cell_type                                                                    /* V10.1 */
{
	CLASS           INPUT;
	LABEL           "Sensor Selection" "|de|Sensorauswahl" ;
	HELP            "Select used electrode cell" "|de|Auswahl zwischen 2-/4-Elektroden Sensor";
	HANDLING        READ & WRITE ;
	selected_cell_enum
}

/********************************************************************************************************/

VARIABLE selected_temp_unit                                                                    /* V10.2 */
{
	CLASS           INPUT;
	LABEL           "Temp Unit" "|de|Temperatureinheit" ;
	HELP			"Select the temperature unit" "|de|Auswahl Temperatureinheit" ;
	HANDLING        READ & WRITE ;
	selected_temp_unit_enum
}

/********************************************************************************************************/

VARIABLE selected_temp_sensor                                                                  /* V10.3 */
{
	CLASS           INPUT;
	LABEL           "Temp Probe" "|de|Temperatursensor" ;
	HELP			"Select the temperature source" "|de|Auswahl Temperatursensor" ;
	HANDLING        READ & WRITE ;
	selected_temp_sensor_enum
}


/********************************************************************************************************/
/*      variable declarations for TC selection code in 9.5                                              */
/********************************************************************************************************/

VARIABLE selected_TC_func                                                                      /* V11.0 */
{
	CLASS           CORRECTION;
	LABEL           "Temp Compensation" "|de|Temperaturkompensation" ;
	HELP            "Select temp compensation" "|de|Auswahl Temperaturkompensation" ;
	HANDLING        READ & WRITE ;
	selected_tc_enum
}

/********************************************************************************************************/

VARIABLE var_TC_lin                                                                             /* V12  */
{
	CLASS           CORRECTION;
	LABEL           "Linear TC" "|de|Linearer TC" ;
	HELP            "Linear temperature coefficent used to compute the temperature compensated conductivity if applied" ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_TC_LIN;
	TYPE            FLOAT{
			 DISPLAY_FORMAT  "5.2f";
			 EDIT_FORMAT     "5.2f";
			 MIN_VALUE       0.00 ;
			 MAX_VALUE       19.99 ;
	}
    VALIDITY IF (selected_TC_func == 1){  /* if TC Lin selected */
        TRUE;
    }ELSE{
       FALSE;
   }
}

/********************************************************************************************************/
/*      variable declarations for Meas/Output relation codes in 9.6                                     */
/********************************************************************************************************/

VARIABLE selected_lin_log                                                                      /* V13.0 */
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "Characteristic" ;
	HELP            "Select current characteristic" ;
	HANDLING        READ & WRITE ;
	
    TYPE ENUMERATED{ 
        IF ((e2211) && ((selected_pv_unit == 12) || (selected_pv_unit==10) || (selected_pv_unit==8))){
            { 0, "Lin"}
        }ELSE{
           { 0, "Lin"},
           { 1, "Log"}
        }    
	}
	POST_READ_ACTIONS{
		method_set_lin
	}
	VALIDITY IF (selected_pv_unit == 11){
		FALSE;
	}ELSE{
		TRUE;
	}

}

METHOD method_set_lin
{
  CLASS	INPUT;
  DEFINITION
  {
   	if  ((selected_pv_unit==11)){
		   assign_int( selected_lin_log, 0);
	}  
  } 
}

/********************************************************************************************************/

VARIABLE selected_log_lr                                                                       /* V13.1 */
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "Log: Lower Range" ;
	HELP            "Select lower current range for log" ;
	HANDLING        READ & WRITE ;
	/* selected_log_enum */
	TYPE ENUMERATED{                   
           IF (!e2211){                
			 { 0, "0.1 S/mS/MOhm"},   
			 { 1, "1.000 S/mS/MOhm"}, 
			 { 2, "10.00 S/mS/MOhm"}, 
			 { 3, "100.0 S/mS/MOhm"}, 
			 { 4, "1000 S/mS/MOhm"}   
           }IF(e2211 && (software_revision<42)){
             { 0, "0.1 S/mS/Sm/MOhm"},   
			 { 1, "1.000 S/mS/Sm/MOhm"}, 
			 { 2, "10.00 S/mS/Sm/MOhm"}, 
			 { 3, "100.0 S/mS/Sm/MOhm"}, 
			 { 4, "1000 S/mS/Sm/MOhm"}   
           }ELSE{                         
             { 0, "0.1 S/0.001 Sm"},     
			 { 1, "1.0 S/0.01 Sm"},      
			 { 2, "10.0 S/0.1 Sm"},      
			 { 3, "100.0 S/1.0 Sm"},     
			 { 4, "1.0 mS/10.0 Sm"},      
             { 5, "10.0 mS/100.0 Sm"},    
             { 6, "100.0 mS"},            
             { 7, "1000.0 mS"}
           }                              
         }        	
    VALIDITY IF (selected_lin_log == 1){  /* if Log selected */
        TRUE;
    }ELSE{
       FALSE;
   }         
}



/********************************************************************************************************/

VARIABLE selected_log_ur                                                                       /* V13.2 */
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "Log: Upper Range" ;
	HELP            "Select upper current range for log" ;
	HANDLING        READ & WRITE ;
	TYPE ENUMERATED{                   
	           IF (!e2211){                
				 { 0, "0.1 S/mS/MOhm"},   
				 { 1, "1.000 S/mS/MOhm"}, 
				 { 2, "10.00 S/mS/MOhm"}, 
				 { 3, "100.0 S/mS/MOhm"}, 
				 { 4, "1000 S/mS/MOhm"}   
	           }IF(e2211 && (software_revision<42)){
	                         { 0, "0.1 S/mS/Sm/MOhm"},   
				 { 1, "1.000 S/mS/Sm/MOhm"}, 
				 { 2, "10.00 S/mS/Sm/MOhm"}, 
				 { 3, "100.0 S/mS/Sm/MOhm"}, 
				 { 4, "1000 S/mS/Sm/MOhm"}   
	           }ELSE{                         
	                         { 0, "0.1 S/0.001 Sm"},     
				 { 1, "1.0 S/0,01 Sm"},      
				 { 2, "10.0 S/0,1 Sm"},      
				 { 3, "100.0 S/1,0 Sm"},     
				 { 4, "1.0 mS/10,0 Sm"},      
	         	 { 5, "10.0 mS/100.0 Sm"},    
	         	 { 6, "100.0 mS"},            
	         	 { 7, "1000.0 mS"}
	           }                              
         } 
    VALIDITY IF (selected_lin_log == 1){  /* if Log selected */
        TRUE;
    }ELSE{
       FALSE;
   }                	
}

/********************************************************************************************************/

VARIABLE output_current_lrv 														             /* V14 */
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "LIN: Lower Range";
	HELP            [lower_range_value_help];
	HANDLING        READ & WRITE ;
	output_unit_type

   
    VALIDITY IF (selected_lin_log == 0){  /* if Lin selected */
        TRUE;
    }ELSE{
       FALSE;
   }         
}

/********************************************************************************************************/

VARIABLE output_current_urv 														             /* V15 */
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "LIN: Upper Range" ;
	HELP            [upper_range_value_help] ;
	HANDLING        READ & WRITE ;

	output_unit_type_up


    VALIDITY IF (selected_lin_log == 0){  /* if Lin selected */
        TRUE;
    }ELSE{
       FALSE;
   }         
   
}


/********************************************************************************************************/
/*      variable declaration for Sensocheck  (9.7)                                                      */
/********************************************************************************************************/

VARIABLE selected_senso_check                                                                  /* V16.0 */
{
	CLASS           CORRECTION;
	LABEL           "Sensocheck" ;
	HELP            "Sensocheck continously monitors the sensor" ;
	HANDLING        READ & WRITE ;
	selected_off_on_enum
}

/********************************************************************************************************/

VARIABLE var_cellconstant                                                                      /* V17   */
{
	CLASS           CORRECTION;
	LABEL           "Cell Constant" "Zellkonstante" ;
	HELP            "Cell constant according to data sheet or calibration" ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_CELL;
	TYPE            FLOAT{
			 DISPLAY_FORMAT         "6.4f";
			 EDIT_FORMAT            "6.4f";
			 MIN_VALUE              0.005 ;
			 MAX_VALUE              19.999 ;
	}

}


/********************************************************************************************************/
/*      variable declarations for alarm selection codes (9.8)                                           */
/********************************************************************************************************/

VARIABLE selected_22mA                                                                         /* V18.0 */         
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "22mA on Error" ;
	HELP            "Switch 22mA signal for error message on or off" ;
	HANDLING        READ & WRITE ;
	selected_off_on_enum
}

VARIABLE selected_hold_last_fix                                                                /* V18.1 */
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "HOLD Last/Fix" ;
	HELP            "The output current behavior in the HOLD mode can be specified. Last- The output current is frozen at its last value, Fix- A constant value from 3.8mA to 22mA" ;
	HANDLING        READ & WRITE ;
	selected_hold_last_fix_enum
}


/********************************************************************************************************/

VARIABLE var_fix_value							/* V21		*/
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "HOLD Fix Value" "|de|HOLD-Festwert";
	HELP			"Specifies fixed output current in HOLD mode" "|de|Festwert fr Ausgangsstrom im HOLD-Zustand";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MA;
	DEFAULT_VALUE	21;
	TYPE            FLOAT{	
		DISPLAY_FORMAT       DISPLAY_CURR
		EDIT_FORMAT          DISPLAY_CURR
		MIN_VALUE            3.8;
		MAX_VALUE            22.0;
	}
}

/********************************************************************************************************/
/* Solutions Code (9.9)                                                                                 */
/********************************************************************************************************/

VARIABLE selected_conc_sol																	   /* V20.0 */
{																							 
    LABEL "Conc Solution" "|de|Konzentrationslsung";
    HELP  "";
    CLASS ANALOG_OUTPUT;
    HANDLING READ & WRITE;
    selected_conc_sol_enum
    VALIDITY IF ((software_revision >= e2211_SW_rev) && (selected_pv_unit == 11)){
        TRUE;
    }ELSE{
       FALSE;
   }  
}	   

/********************************************************************************************************/

VARIABLE var_sample_cal							                                                /* V30  */
{
	/* var_sample_cal darf nicht in die upload_variables Liste */
	CLASS           x2211( CORRECTION;, LOCAL; )
	LABEL           "Sample" ;
	HELP			"Calibration with Sampling to determine the electrode zero point" ;
	HANDLING        READ & WRITE ;
    pv_unit_type
    valid_e2211
}

/********************************************************************************************************/

VARIABLE var_filter_1																			/* V31  */
{
	CLASS           x2211( ANALOG_OUTPUT;, LOCAL; )
	LABEL           "Output Filter" "|de|Ausgangsfilter";
	HELP			"Time constant of output current filter" "|de|Filterzeit des Ausgangs";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_SEC
	TYPE            FLOAT{	
		DISPLAY_FORMAT         DISPLAY_SEC
		EDIT_FORMAT            DISPLAY_SEC
		MIN_VALUE              0.0;
		MAX_VALUE              120.0;
		DEFAULT_VALUE		   0.0;
	}
	valid_e2211
}


/********************************************************************************************************/

VARIABLE var_alarmdelay_1							                                            /* V32  */ 
{
	CLASS           x2211( ANALOG_OUTPUT;, LOCAL; )
	LABEL           "Alarm Delay" "|de|Alarmzeitverzgerung";
	HELP			"Alarm delay time of alarm signal" "|de|Alarmzeitverzgerung fr das Alarmsymbol";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_SEC
	TYPE            FLOAT{	
		DISPLAY_FORMAT         DISPLAY_SEC
		EDIT_FORMAT            DISPLAY_SEC
		MIN_VALUE              0.0;
		MAX_VALUE              600.0;
		DEFAULT_VALUE		   10.0;
	}
	valid_e2211
}


/********************************************************************************************************/
/* extended selection code (9.10)                                                                       */
/********************************************************************************************************/
VARIABLE selected_holdLED						  	                                           /* V33.0 */
{
	CLASS           x2211( DEVICE;, LOCAL; )
	LABEL           "Alarm LED Hold";
	HELP			"Alarm LED Hold:\nPara. Alarm  Hold on	 : on     off : off";
	HANDLING        READ & WRITE ;
	selected_off_on_enum
	valid_e2211
}




/********************************************************************************************************/
/*      common variable set                                                                             */

VARIABLE transmitter_variable_unit_code
{
	CLASS           LOCAL;
	LABEL           "" ;
	HANDLING        READ;
	TYPE            INTEGER (1) ;
}



/********************************************************************************************************/

//=============================================================================
//  COMMANDS
//=============================================================================

COMMAND read_unique_identifier
{
  NUMBER 0;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      254,
      manufacturer_id,
      device_type,
      request_preambles,
      universal_revision,
      transmitter_revision,
      software_revision,
      hardware_revision <0xf8>,
      physical_signaling_code <0x07>,
      device_flags,
      device_id
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_primary_variable
{
  NUMBER 1;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      sensor_units,
      sensor_value //sensor_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_current_and_percent_range
{
  NUMBER 2;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      mA_output_current,
      percent_of_range
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_dynamic_variables_and_pv_current
{
  NUMBER 3;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      mA_output_current,
      sensor_units,
      sensor_value, 
      sv_temp_units,
      sv_temp_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND write_polling_address
{
  NUMBER 6;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      polling_address
    }
    REPLY {
      response_code,
      device_status,
      polling_address
    }
  }
  RESPONSE_CODES {
     0,	SUCCESS, [no_command_specific_errors];
     2,	DATA_ENTRY_ERROR, [invalid_selection];
     5,	MISC_ERROR, [too_few_data_bytes_recieved];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND read_unique_identifier_with_tag
{
  NUMBER 11;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST {
      tag
    }
    REPLY {
      response_code,
      device_status,
      254,
      manufacturer_id,
      device_type,
      request_preambles,
      universal_revision,
      transmitter_revision,
      software_revision,
      hardware_revision <0xf8>,
      physical_signaling_code <0x07>,
      device_flags,
      device_id 
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_message
{
  NUMBER 12;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      message
    }
  }
  RESPONSE_CODES {
    0, SUCCESS,	[no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_tag_descriptor_date
{
  NUMBER 13;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      tag,
      descriptor,
      date
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_sensor_info
{
  NUMBER 14;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      sensor_serial_number,
      sensor_units,
      sensor_upper_limit,
      sensor_lower_limit,
      sensor_minimum_span
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_output_info
{
  NUMBER 15;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      analog_alarm_code,
      xmtr_transfer_function,
      sensor_units,
      output_current_urv,
      output_current_lrv,
      primary_damping_value,
      write_protect,
      private_label_distributor
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_final_assembly_number
{
  NUMBER 16;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      final_assembly_number
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND write_message
{
  NUMBER 17;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      message
    }
    REPLY {
      response_code,
      device_status,
      message
    }
  }
  RESPONSE_CODES {
     0,	SUCCESS,    [no_command_specific_errors];
     5,	MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_tag_descriptor_date
{
  NUMBER 18;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      tag,
      descriptor,
      date
    }
    REPLY {
      response_code,
      device_status,
      tag,
      descriptor,
      date
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_final_assembly_number
{
  NUMBER 19;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      final_assembly_number
    }
    REPLY {
      response_code,
      device_status,
      final_assembly_number
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_pv_range_values
{
  NUMBER 35;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      sensor_units,
      output_current_urv,
      output_current_lrv
    }
    REPLY {
      response_code,
      device_status,
      sensor_units,
      output_current_urv,
      output_current_lrv
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
     2, DATA_ENTRY_ERROR, [invalid_selection];
     5, MISC_ERROR, [too_few_data_bytes_recieved];
     9, DATA_ENTRY_ERROR, [lower_range_value_too_high];
    10, DATA_ENTRY_ERROR, [lower_range_value_too_low];
    11, DATA_ENTRY_ERROR, [upper_range_value_too_high];
    12, DATA_ENTRY_ERROR, [upper_range_value_too_low];
    13, DATA_ENTRY_ERROR, [URV_and_LRV_out_of_limits];
    14, DATA_ENTRY_WARNING, [span_too_small];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND set_pv_upper_range_value
{
  NUMBER 36;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND set_pv_lower_range_value
{
  NUMBER 37;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND reset_configuration_change_flag
{
  NUMBER 38;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND enter_exit_fixed_pv_current_mode
{
  NUMBER 40;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST {
      primary_analog_current_value
    }
    REPLY {
      response_code,
      device_status,
      primary_analog_current_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
    4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND perform_transmitter_self_test
{
  NUMBER 41;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND perform_master_reset
{
  NUMBER 42;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND read_additional_transmitter_status
{
  NUMBER 48;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
  	  xmtr_specific_status_0 ,		/*  0  */
	  dummy_status ,				/*  1  */
	  xmtr_specific_status_2 ,		/*  2  */		  	
	  dummy_status ,				/*  3 undefined */
	  dummy_status ,				/*  4 undefined */
	  dummy_status ,     			/*  5 undefined */
	  dummy_status ,				/*  6  */
	  dummy_status ,				/*  7  */
	  analog_output_saturated1 ,  	/*  8  */
	  dummy_status ,			  	/*  9 undefined */
	  dummy_status ,			  	/* 10 undefined */
	  analog_output_fixed1,			/* 11  */
	  dummy_status ,				/* 12 undefined */
	  dummy_status ,				/* 13 undefined */
	  dummy_status ,				/* 14 undefined */
	  dummy_status ,				/* 15 undefined */
	  dummy_status ,				/* 16 undefined */
	  dummy_status ,				/* 17 undefined */
	  dummy_status ,				/* 18 undefined */
	  dummy_status ,				/* 19 undefined */
	  dummy_status ,				/* 20 undefined */
	  dummy_status ,				/* 21 undefined */
	  dummy_status ,				/* 22 undefined */
	  dummy_status ,				/* 23 undefined */
	  function_check_status	}		/* 24  */    
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}


//-------------------------------------

COMMAND read_transmitter_variable_information
{
  NUMBER 54;
  OPERATION READ;
  TRANSACTION {
    REQUEST {
      transmitter_variable_index( INFO, INDEX )
    }
    REPLY {
      response_code,
      device_status,
      transmitter_variable_index,
      transmitter_variables[transmitter_variable_index].SENSOR_SERIAL_NUMBER,
      transmitter_variables[transmitter_variable_index].SENSOR_UNITS,
      transmitter_variables[transmitter_variable_index].UPPER_SENSOR_LIMIT,
      transmitter_variables[transmitter_variable_index].LOWER_SENSOR_LIMIT,
      transmitter_variables[transmitter_variable_index].DAMPING_VALUE,
      transmitter_variables[transmitter_variable_index].MINIMUM_SPAN
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, MISC_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_number_of_response_preambles
{
  NUMBER 59;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      response_preambles
    }
    REPLY {
      response_code,
      device_status,
      response_preambles
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
    4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-----------------------------------------------------------------------------

COMMAND read_float_variable
{
  NUMBER 128;
  OPERATION READ;
  TRANSACTION {
    REQUEST {
      transmitter_variable_index (INFO, INDEX)
    }
    REPLY {
      response_code,
      device_status,
	  transmitter_variable_index,
	  transmitter_variable_unit_code,
	  transmitter_variable_array [transmitter_variable_index]
 }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, DATA_ENTRY_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-----------------------------------------------------------------------------

COMMAND read_selections
{
  NUMBER 128;
  OPERATION READ;
  TRANSACTION 1 {
		REQUEST { transmitter_variable_index (INFO,INDEX) }
	 	REPLY {	
	 		response_code,	device_status,
			transmitter_variable_index,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]
		}
	}
	TRANSACTION 2 {
		REQUEST { selection_code_index (INFO,INDEX) }
		REPLY {
			response_code,	device_status,
			selection_code_index,
			UNITS_CODE_NON,
      	selection_codes[selection_code_index].BYTE1,
      	selection_codes[selection_code_index].BYTE2,
      	selection_codes[selection_code_index].BYTE3,
      	selection_codes[selection_code_index].BYTE4
		}
	}
	TRANSACTION 3 {
		REQUEST { selection_code_index_e (INFO,INDEX) }
		REPLY {
			response_code,	device_status,
			selection_code_index_e,
			UNITS_CODE_NON,
      	selection_codes_e[selection_code_index_e].BYTE1,
      	selection_codes_e[selection_code_index_e].BYTE2,
      	selection_codes_e[selection_code_index_e].BYTE3,
      	selection_codes_e[selection_code_index_e].BYTE4
		}
      }

  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, DATA_ENTRY_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_float_variable
{
  NUMBER 129 ;
  OPERATION WRITE ;
  TRANSACTION {
    REQUEST {
			transmitter_variable_index (INFO,INDEX) ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]

    }
    REPLY {
			response_code,	device_status,
			transmitter_variable_index ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors] ;
     2, DATA_ENTRY_ERROR, [invalid_selection] ;
     3, DATA_ENTRY_ERROR, [passed_parameter_too_large] ;
     4, DATA_ENTRY_ERROR, [passed_parameter_too_small] ;
     5, MISC_ERROR, [too_few_data_bytes_recieved] ;
     7, MODE_ERROR, [in_write_protect_mode] ;
    12, DATA_ENTRY_ERROR, "Invalid unit code" ;
    32, DATA_ENTRY_ERROR, "Busy" ;
  }
}

//-------------------------------------

COMMAND write_selections
{
  NUMBER 129 ;
  OPERATION WRITE ;
TRANSACTION 1 {
		REQUEST {
			transmitter_variable_index (INFO,INDEX) ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]
		}
		REPLY {
			response_code,	device_status,
			transmitter_variable_index ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]
		}
	}
	TRANSACTION 2 {
		REQUEST {
			selection_code_index (INFO,INDEX),
			UNITS_CODE_NON,
      	selection_codes[selection_code_index].BYTE1,
      	selection_codes[selection_code_index].BYTE2,
      	selection_codes[selection_code_index].BYTE3,
      	selection_codes[selection_code_index].BYTE4
		}
		REPLY {
			response_code,	device_status,
			selection_code_index,
			UNITS_CODE_NON,
      	selection_codes[selection_code_index].BYTE1,
      	selection_codes[selection_code_index].BYTE2,
      	selection_codes[selection_code_index].BYTE3,
      	selection_codes[selection_code_index].BYTE4
		}
	}
	TRANSACTION 3 {
		REQUEST {
			selection_code_index_e (INFO,INDEX),
			UNITS_CODE_NON,
      	selection_codes_e[selection_code_index_e].BYTE1,
      	selection_codes_e[selection_code_index_e].BYTE2,
      	selection_codes_e[selection_code_index_e].BYTE3,
      	selection_codes_e[selection_code_index_e].BYTE4
		}
		REPLY {
			response_code,	device_status,
			selection_code_index_e,
			UNITS_CODE_NON,
      	selection_codes_e[selection_code_index_e].BYTE1,
      	selection_codes_e[selection_code_index_e].BYTE2,
      	selection_codes_e[selection_code_index_e].BYTE3,
      	selection_codes_e[selection_code_index_e].BYTE4
		}
	}
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors] ;
     2, DATA_ENTRY_ERROR, [invalid_selection] ;
     3, DATA_ENTRY_ERROR, [passed_parameter_too_large] ;
     4, DATA_ENTRY_ERROR, [passed_parameter_too_small] ;
     5, MISC_ERROR, [too_few_data_bytes_recieved] ;
     7, MODE_ERROR, [in_write_protect_mode] ;
    12, DATA_ENTRY_ERROR, "Invalid unit code" ;
    32, DATA_ENTRY_ERROR, "Busy" ;
  }
}


/*------------------------------------------------------------------------------------*/
/*      transmitter-specific commands #128, #129                                      */
/*------------------------------------------------------------------------------------*/

#define send_trans_read( _status, _transvar ) \
				if( e2211_meth ){ \
					iassign( selection_code_index_e, _transvar ); \
					send_trans( 128, 3, _status ); \
				}else{ \
					iassign( selection_code_index, _transvar ); \
					send_trans( 128, 2, _status ); \
				}

#define send_trans_write( _status, _transvar ) \
				if( e2211_meth ){ \
					iassign( selection_code_index_e, _transvar ); \
					send_trans( 129, 3, _status ); \
				}else{ \
					iassign( selection_code_index, _transvar ); \
					send_trans( 129, 2, _status ); \
				}

/*------------------------------------------------------------------------------------*/
/*      transmitter-specific commands #131                                			  */
/*------------------------------------------------------------------------------------*/

COMMAND cmd_take_sample_calibration
{
	NUMBER          131;
	OPERATION       COMMAND;

	TRANSACTION
	{
		REQUEST{ }
		REPLY{ response_code, device_status	}
	}
	RESPONSE_CODES  {	 
				 0 , SUCCESS ,          [no_command_specific_errors] ; 
				 5 , MISC_ERROR ,       [too_few_data_bytes_recieved] ; 
				16, MODE_ERROR ,		[access_restricted];	
	}
}




//=============================================================================
//  MENU Bar
//=============================================================================

MENU Menu_Main_Specialist
{
  LABEL [main_menu];
  ITEMS {
    Menu_File,
    Menu_S_Device,
    Menu_S_View,
    Menu_Options,
    Menu_Help
  }
}

//-------------------------------------

MENU Menu_Main_Maintenance
{
  LABEL [main_menu];
  ITEMS	{
    Menu_File,
    Menu_M_Device,
    Menu_M_View,
    Menu_Options,
    Menu_Help
  }
}

//-----------------------------------------------------------------------------
//    Menu: File
//-----------------------------------------------------------------------------

MENU Menu_File
{
  LABEL [menu_File];
  ITEMS {
    std_Save,
    SEPARATOR,
    std_Eigenschaften,
    SEPARATOR,
    std_Print,
    std_PrintPreview,
    std_PrintSetup,
    std_PageSetup,
    std_Schriftfelder,
    SEPARATOR,
    std_Exit
  }
}

//-------------------------------------

MENU Menu_S_Device
{
  LABEL [menu_Device];
  ITEMS {
    std_CommWay,
    SEPARATOR,
    std_LoadinDevice,										
    std_LoadinPC,											
    SEPARATOR,
    loop_test,
    self_test,
    master_reset,
    configuration_flag_reset,
    SEPARATOR,
    meth_take_sample_calibration,
    meth_lab_sample_calibration,
    SEPARATOR,
    OnlineDialog_rerange,
    SEPARATOR,
    OnlineDialog_hart_comm
  }
}

MENU Menu_M_Device
{
  LABEL [menu_Device];
  ITEMS {
    std_LoadinDevice,										
    std_LoadinPC,											
    SEPARATOR,
    self_test,
  }
}

//-------------------------------------

MENU Menu_S_View
{
  LABEL [menu_View];
  ITEMS {
    OnlineWindow_display,
    OnlineWindow_S_diagnosis, 
    SEPARATOR,
    std_Funktionsleiste,
    std_Statuszeile,
    SEPARATOR,
    std_Update
  }
}

MENU Menu_M_View
{
  LABEL [menu_View];
  ITEMS {
    OnlineWindow_display,
    OnlineWindow_M_diagnosis, 
    SEPARATOR,
    std_Funktionsleiste,
    std_Statuszeile,
    SEPARATOR,
    std_Update
  }
}

//-------------------------------------

MENU Menu_Options
{
  LABEL [menu_Options];
  ITEMS {
    std_Einstellungen,
    std_Untereintraege
  }
}

//-------------------------------------

MENU Menu_Help
{
  LABEL [menu_Help];
  ITEMS {
    std_Hilfethemen,
    std_HilfeKontext,
    SEPARATOR,
    std_HilfeGeraet,
    SEPARATOR,
    std_HilfeEinfuehrung,
    std_HilfeErsteSchritte,
    SEPARATOR,
    std_Hilfebenutzen,
    std_Info
  }
}

//=============================================================================
//  Online-Windows
//=============================================================================

MENU OnlineWindow_display	// sollte vorhanden sein (Button: Mewertanzeige)
{
  LABEL [menu_dialog_display];
  ITEMS {
    Page_1_display		// sollte vorhanden sein (Button: Mewertanzeige)
  }
}

//-----------------------------------------------------------------------------

MENU Page_1_display		// sollte vorhanden sein (Button: Mewertanzeige)
{
  LABEL "Mettler Toledo - Cond 7100e/2(X)H";
  ITEMS {
    analog_output_fixed1 (READ_ONLY),
    
    IF (selected_lin_log == 0){
	    BarVal_meas_display,
    }ELSE{
      	Val_messwert_display,
		selected_log_lr (READ_ONLY),
		selected_log_ur (READ_ONLY),
    }    	
    Val_temp_display,
    mA_output_current (READ_ONLY),
    var_cond,
	var_res,
    var_temp,
    device_status
  }
}

//-------------------------------------

MENU BarVal_meas_display
{
	LABEL	[menu_dialog_display_measure];
  	ITEMS{
					sensor_value, /*,main_unit, /**/    			    
			    	output_current_lrv		(READ_ONLY),
			    	output_current_urv		(READ_ONLY)
    }
}



//-------------------------------------
MENU Val_messwert_display
{
  LABEL	"PV"	"|de|PV";
  ITEMS {																										 
    sensor_value
  }
}

MENU Val_temp_display
{
  LABEL	"Temperature"	"|de|Temperatur";
  ITEMS {																										 
    sv_temp_value
  }
}

//-----------------------------------------------------------------------------

MENU OnlineWindow_S_diagnosis
{
  LABEL	[menu_dialog_diagnosis];
  ITEMS {
    OnlineWindow_diagnosis_device,
    Page_S_diagnosis_status
  }
}

MENU OnlineWindow_M_diagnosis
{
  LABEL	[menu_dialog_diagnosis];
  ITEMS {
    OnlineWindow_diagnosis_device,
    Page_M_diagnosis_status
  }
}

//-------------------------------------

MENU OnlineWindow_diagnosis_device
{
  LABEL	[menu_ident_device];
  ITEMS {
    tag			 (READ_ONLY),
// ??? removed by Siemens 03/29/99:    unit_tag		 (READ_ONLY),
    manufacturer_id	 (READ_ONLY),
    device_id		 (READ_ONLY),
    device_type		 (READ_ONLY),
    software_revision	 (READ_ONLY),
    hardware_revision	 (READ_ONLY),
    transmitter_revision (READ_ONLY),
    universal_revision	 (READ_ONLY)
  }
}

//-------------------------------------

MENU Page_S_diagnosis_status
{
  LABEL	"Errors && Smileys" "|de|Fehler && Smileys";
  ITEMS {
    xmtr_specific_status_0 (READ_ONLY),
    analog_output_fixed1	(READ_ONLY),
    function_check_status	(READ_ONLY),
    xmtr_specific_status_2	(READ_ONLY),
	analog_aoutput_saturated1 (READ_ONLY),
    configuration_flag_reset
  }
}

MENU Page_M_diagnosis_status
{
  LABEL	"Errors && Smileys" "|de|Fehler && Smileys";
  ITEMS {
    xmtr_specific_status_0 (READ_ONLY),
    analog_output_fixed1	(READ_ONLY),
    function_check_status	(READ_ONLY),
    xmtr_specific_status_2	(READ_ONLY),
	analog_aoutput_saturated1 (READ_ONLY),
    configuration_flag_reset
  }
}

//-------------------------------------

MENU OnlineDialog_rerange
{
  LABEL	[menu_window_lo_up_value];
  ITEMS {
    Page_rerange
  }
}

//-------------------------------------

MENU Page_rerange  //Messbereich Anfang/Ende
{
  LABEL	[menu_window_lo_up_value];
  
   ITEMS {
    selected_pv_unit, 					     //selected_pv_unit,		 //primary_variable
	
	IF (selected_lin_log == 0){
	
	    output_current_lrv, 			     //  4 mA Eingabe
    	sensor_lower_limit (READ_ONLY),	     //max LOWER Limit	
	    output_current_urv, 			     // 20 mA Eingabe	
	    sensor_upper_limit (READ_ONLY),	     //max UPPER limit
	
	}ELSE{
	
	    selected_log_lr, 			         //  4 mA Eingabe
    	sensor_lower_limit (READ_ONLY),	     //max LOWER Limit	
	    selected_log_ur, 			         // 20 mA Eingabe	
	    sensor_upper_limit (READ_ONLY),	     //max UPPER limit	
	
	}

    sie_set    		
  }
}

//-------------------------------------

MENU OnlineDialog_hart_comm
{
  LABEL	[menu_HART_Comm];
  ITEMS {
    Page_polling_address,
    Page_request_response_preambles
  }
}

//-------------------------------------

MENU Page_polling_address
{
  LABEL	[menu_polling_address];
  ITEMS {
    polling_address,
    polling_address_set
  }
}

//-------------------------------------

MENU Page_request_response_preambles
{
  LABEL	[menu_request_response_preambles];
  ITEMS {
    response_preambles,
    request_preambles,
    sie_set
  }
}

//-----------------------------------------------------------------------------
//   Standard Methods
//-----------------------------------------------------------------------------

METHOD SEPARATOR
{
  LABEL	[menu_Separator];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Save
{
  LABEL	[menu_File_Save];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Eigenschaften
{
  LABEL	[menu_File_Properties];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Print
{
  LABEL	[menu_File_Print];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PrintPreview
{
  LABEL	[menu_File_PrintPreview];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PrintSetup
{
  LABEL	[menu_File_PrintSetup];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PageSetup
{
  LABEL	[menu_File_PageSetup];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Schriftfelder
{
  LABEL	[menu_File_Labels];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Exit
{
  LABEL	[menu_File_Exit];
  DEFINITION { }
}

//-------------------------------------

METHOD std_CommWay
{
  LABEL	[menu_Device_CommWay];
  DEFINITION { }
}

//-------------------------------------

METHOD std_LoadinDevice
{
  LABEL	[menu_Device_LoadinDevice];
  DEFINITION { }
}

//-------------------------------------

METHOD std_LoadinPC
{
  LABEL	[menu_Device_LoadinPC];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Funktionsleiste
{
  LABEL	[menu_View_Toolbar];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Statuszeile
{
  LABEL	[menu_View_Statusbar];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Update
{
  LABEL	[menu_View_Update];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Einstellungen
{
  LABEL	[menu_Options_Properties];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Untereintraege
{
  LABEL	[menu_Options_Subitems];
  DEFINITION { }
}


//=============================================================================
//  Table
//=============================================================================

MENU Table_Main_Specialist
{
  LABEL "Mettler Toledo - Cond 7100e/2(X)H";
  ITEMS {
    Tab_s_identification,
    Tab_s_inputs,
    Tab_s_outputs,
    Tab_s_calibration
  }
}

//-------------------------------------

MENU Tab_s_identification
{
  LABEL [menu_ident];
  ITEMS {
    Tab_s_opunit,
    Tab_s_device
  }
}

//-------------------------------------

MENU Tab_s_opunit
{
  LABEL [menu_ident_opunit];
  ITEMS {
    tag,
    descriptor,
    message
  }
}

//-------------------------------------

MENU Tab_s_device
{
  LABEL [menu_ident_device];
  ITEMS	{
    manufacturer_id,
    universal_revision,
    transmitter_revision,
    software_revision,
    hardware_revision,
    device_id,
    device_type,
    device_flags,
    physical_signaling_code,
    final_assembly_number,
    date
  }
}

//-------------------------------------

MENU Tab_s_inputs
{
  LABEL "Inputs" "|de|Eingang";
  ITEMS {
	selected_cell_type,
	var_cellconstant,
	selected_pv_unit,
	selected_conc_sol,
    selected_temp_unit,
	selected_temp_sensor
  }
}

//-------------------------------------

MENU Tab_s_outputs
{
  LABEL "Outputs" "|de|Ausgang";
  ITEMS	{
    selected_lin_log,       //Lin Log
    selected_log_lr,		// Log Anfang
    output_current_lrv,		// Lin Anfang (4mA)
	selected_log_ur,		// Log Ende
    output_current_urv,		// Lin Ende  (20mA)
	selected_TC_func,       // Auswahl TC 
	var_TC_lin,				// Einstellung TC Lin Koeffizient
	var_filter_1,			// Filterzeitkonstant
    selected_22mA,			// 22mA bei Fehler
	selected_hold_last_fix, // Fix - Last
    selected_hold_fix,		// HOLD Last/Fix
    var_fix_value			// HOLD-Fix Wert
					   
  }
}

//-------------------------------------
MENU Tab_s_calibration
{
  LABEL "Alarm settings"	"|de|Alarm Einstellungen";
  ITEMS	{
    selected_senso_check,
    var_alarmdelay_1,
	selected_holdLED
  }
}



//-----------------------------------------------------------------------------

MENU Table_Main_Maintenance
{
  LABEL "Mettler Toledo - Cond 7100e/2(X)H";
  ITEMS {
    Tab_m_identification,
    Tab_m_inputs,
    Tab_m_outputs,
    Tab_m_calibration,
  }
}

//-------------------------------------

MENU Tab_m_identification
{
  LABEL [menu_ident];
  ITEMS {
    Tab_s_opunit,
    Tab_s_device
  }
}

//-------------------------------------

MENU Tab_m_opunit
{
  LABEL [menu_ident_opunit];
  ITEMS {
    tag (READ_ONLY),
    descriptor,
    message
  }
}

//-------------------------------------

MENU Tab_m_device
{
  LABEL [menu_ident_device];
  ITEMS	{
    manufacturer_id,
    universal_revision,
    transmitter_revision,
    software_revision,
    hardware_revision,
    device_id,
    device_type,
    device_flags,
    physical_signaling_code,
    final_assembly_number,
    date
  }
}

//-------------------------------------

MENU Tab_m_inputs
{
  LABEL "Inputs" "|de|Eingang";
  ITEMS {
	selected_cell_type (READ_ONLY),
	var_cellconstant (READ_ONLY),
	selected_pv_unit (READ_ONLY),
	selected_conc_sol (READ_ONLY),
    selected_temp_unit (READ_ONLY),
	selected_temp_sensor (READ_ONLY)  }
}

//-------------------------------------

MENU Tab_m_outputs
{
  LABEL "Outputs" "|de|Ausgang";
  ITEMS	{
    output_current_lrv (READ_ONLY),		// Anfang (4mA)
    output_current_urv (READ_ONLY),		// Ende  (20mA)
	var_filter_1 (READ_ONLY),
    selected_22mA (READ_ONLY),		// 22mA bei Fehler
    selected_hold_fix (READ_ONLY),		// HOLD Last/Fix
    var_fix_value (READ_ONLY)		// HOLD-Fix Wert
  }
}

//-------------------------------------
MENU Tab_m_calibration
{
  LABEL "Alarm settings"	"|de|Alarm Einstellungen";
  ITEMS	{
    selected_senso_check (READ_ONLY),
    var_alarmdelay_1 (READ_ONLY),
	selected_holdLED (READ_ONLY)
  }
}






//=============================================================================
//  Methods
//=============================================================================

METHOD sie_set			// Transmit-Button
{
  LABEL	[transfer];
  HELP	[transfer_help];
  CLASS INPUT;
  DEFINITION { }
}

//-------------------------------------

METHOD polling_address_set
{
  LABEL	[transfer];
  HELP 	[transfer_help];
  CLASS INPUT;
  DEFINITION {
    ACKNOWLEDGE( [message_polling_address] );
  }
}






/*------------------------------------------------------------------------------------*/
/*	methods of value transmitter_variables 			   								  */
/* Warntext wird ausgegeben da die Wert sofort im Gert gendert werden, fr AMS	  */
/* notwendig und im HC275 sinnvoll, der Anwender muss nicht extra <send> drcken 	  */
/*------------------------------------------------------------------------------------*/

#define meth_sample_check_e2211 \
		if( !e2211_meth ){ \
			ACKNOWLEDGE( "Product calibration via HART not available for device software before V4.0. \n\n Press OK to finish" \
						 "|de|Produktkalibrierung ber HART-Kommunikation erst verfgbar ab Softwareversion 4.0. \n\n Drcken Sie OK zum Beenden"  );\
			process_abort(); \
		}

#define meth_head( _check_e ) \
		  		char	status [STATUS_SIZE]; \
				char  disp_string1 [60];    \
				int   slen1;					 \
				int	selc;						 \
				long	ids [2];					 \
				int 	sec;						 \
				slen1 = 60;						 \
				if( _check_e != 0 ){ meth_sample_check_e2211 } \
				get_dictionary_string (remove_loop_from_auto, disp_string1, slen1); \
				ACKNOWLEDGE (disp_string1); \
				add_abort_method (return_to_normal);

#define meth_definition_var( _transvar, _var, _label, _meth ) \
				{	meth_head( 0 ) \
					iassign( transmitter_variable_index, _transvar ); \
					send_trans( 128, 1, status ); \
					GET_DEV_VAR_VALUE ( _label, _var ); \
					IGNORE_ALL_RESPONSE_CODES (); \
					iassign( transmitter_variable_index, _transvar ); \
					send_trans( 129, 1, status ); \
					if (status [STATUS_RESPONSE_CODE]){ \
						display_response_status (132, status [STATUS_RESPONSE_CODE]); \
						ACKNOWLEDGE( "WARNING: Configuration was abborted!\n \nACTION: Repeat this step." \
						"|de|WARNUNG: Konfiguration wurde abgebrochen!\n Hinweis:Wiederholung dieses Schrittes!" ); \
					} \
					process_abort(); \
				}


//-----------------------------------------------------------------------------

METHOD loop_test
{
  LABEL	[loop_test];
  HELP	[loop_test_help];
  DEFINITION {
    char status[STATUS_SIZE];
    int choice;
    long var_id[1];
    int use_abort_method;
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;
    get_dictionary_string( remove_loop_from_auto, disp_string1, slen1 );
    ACKNOWLEDGE( disp_string1 );
    add_abort_method( return_to_normal );

    IGNORE_ALL_RESPONSE_CODES( );

    use_abort_method = 0;
    do {
     	 get_dictionary_string( choose_analog_output_level, disp_string1, slen1 );
     	 get_dictionary_string( choices_4_20_other_end, disp_string2, slen2 );
      	choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
      
      switch( choice ) {
							case 0:		assign_float( primary_analog_current_value, 4.0 ); 
										break;
							
							case 1:		assign_float( primary_analog_current_value, 20.0 ); 
										break;

							case 2:		get_dictionary_string( loop_output, disp_string1, slen1 );
										GET_DEV_VAR_VALUE( disp_string1, primary_analog_current_value ); 
										break;

							case 3:
				
							default:	process_abort( );
							break;
      }

      send( 40, status );
      
      if( !use_abort_method ) {
				if( (status[STATUS_RESPONSE_CODE] != 0) && (status[STATUS_RESPONSE_CODE] != 3) && (status[STATUS_RESPONSE_CODE] != 4) ) {
					  display_response_status( 40, status[STATUS_RESPONSE_CODE] );
					  get_dictionary_string( abort_last_error, disp_string1, slen1 );
					  DELAY( 2, disp_string1 );
					  process_abort( );
				}
				remove_abort_method( return_to_normal );
				add_abort_method( leave_fixed_current_mode );
				use_abort_method = 1;
      }

      if( status[STATUS_RESPONSE_CODE] ) {
				display_response_status( 40, status[STATUS_RESPONSE_CODE] );
				if( (status[STATUS_RESPONSE_CODE] != 3) && (status[STATUS_RESPONSE_CODE] != 4) ) {
					  get_dictionary_string( abort_last_error, disp_string1, slen1 );
					  DELAY( 2, disp_string1 );
					  process_abort( );
				}
      }else {
				var_id[0] = VARID( primary_analog_current_value ); 
				get_dictionary_string( fld_dev_otpt_fixed, disp_string1, slen1 );
				acknowledge( disp_string1, var_id );
      }

    } while( choice < 3 );
	    process_abort( );
  }
}

//-------------------------------------

METHOD leave_fixed_current_mode
{
  LABEL	[leaving_fixed_current_mode];
  HELP	[leaving_fixed_current_mode_help_2];
  DEFINITION {
    char status[STATUS_SIZE];
    long var_id[1];
    char disp_string1[60];
    int slen1;

    slen1 = 60;

    assign_float( primary_analog_current_value, 0.0 );  
    IGNORE_ALL_RESPONSE_CODES( ); 
    do {
      get_dictionary_string( return_fld_dev_to_orig_otpt, disp_string1, slen1 );
      DELAY( 3, disp_string1 );
      send( 40, status );
      if( status[STATUS_RESPONSE_CODE] ) {
	display_response_status( 40, status[STATUS_RESPONSE_CODE] );
      }
    } while( status[STATUS_RESPONSE_CODE] );
    get_dictionary_string( loop_may_be_returned_to_auto, disp_string1, slen1 );
    ACKNOWLEDGE( disp_string1 );
  }
}




//-----------------------------------------------------------------------------

METHOD self_test
{
  LABEL	[selftest];
  HELP	[selftest_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char status[3];
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;
		
    slen1 = 60;
    slen2 = 60;
		
    get_dictionary_string( selftest_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );
		
    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      add_abort_method( return_to_normal );
      IGNORE_ALL_RESPONSE_CODES( );
      send( 41, status );
      if( (status[STATUS_RESPONSE_CODE] > 1) || status[STATUS_COMM_STATUS] || status[STATUS_DEVICE_STATUS] ) {
	if( status[STATUS_RESPONSE_CODE] > 1 ) {
	  display_response_status( 41, status[STATUS_RESPONSE_CODE] );
	}
	if( status[STATUS_COMM_STATUS] > 1 ) { // COMM_STATUS > 1 damit nur eine Fehlermeldung bei Kommunikationsfehlern ausgegeben wird
	  display_comm_status( status[STATUS_COMM_STATUS] );
	}
	if( status[STATUS_DEVICE_STATUS] ) {
	  display_device_status( status[STATUS_DEVICE_STATUS] );
	}
	process_abort( );
      }
      else {
	get_dictionary_string( selftest_ok, disp_string1, slen1 );
	ACKNOWLEDGE( disp_string1 );
      }
    }
  }
}

//-----------------------------------------------------------------------------

METHOD master_reset
{
  LABEL	[master_reset];
  HELP	[master_reset_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char status[3];
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;

    get_dictionary_string( master_reset_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );

    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      add_abort_method( return_to_normal );
      IGNORE_ALL_RESPONSE_CODES( );
      send( 42, status );
      if( (status[STATUS_RESPONSE_CODE] > 1)|| status[STATUS_COMM_STATUS] || status[STATUS_DEVICE_STATUS] ) {
	if( status[STATUS_RESPONSE_CODE] > 1 ) {
	  display_response_status(41, status[STATUS_RESPONSE_CODE]);
	}
	if( status[STATUS_COMM_STATUS] ) {
	  display_comm_status(status[STATUS_COMM_STATUS]);
	}
	if( status[STATUS_DEVICE_STATUS] ) {
	  display_device_status(status[STATUS_DEVICE_STATUS]);
	}
	process_abort( );
      }
      else {
	get_dictionary_string( master_reset_ok, disp_string1, slen1 );
	ACKNOWLEDGE( disp_string1 );
      }
    }
  }
}

//-----------------------------------------------------------------------------

METHOD configuration_flag_reset
{																																 
  LABEL	[configuration_flag_reset];
  HELP	[configuration_flag_reset_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;

    get_dictionary_string( configuration_flag_reset_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );

    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      send_command( 38 );
    }
  }
}

/*------------------------------------------------------------------------------------*/
/* e2211pH	calibration methods																		  */
																										

#define 	text_sample_abort "WARNING: Product calibration was abborted!\n \nACTION: Repeat this step." "|de|Produktkalibrierung wurde abgebrochen. Wiederholen Sie diesen Schritt"
#define 	text_sample_ok 	  "Press OK finish"	"|de|Drcken Sie OK zum Beenden"

METHOD meth_take_sample_calibration
{
/* HC275:			"123456789012345678" */
	LABEL          "Take Sample" "|de|Produktkalibrierung - Probenentnahme";
	HELP           "Product Calibration Sequence Take Sample" "|de|Produktkalibrierung Schritt 1 Probenentnahme";
	DEFINITION {
		char   status[STATUS_SIZE] ;
		long   ids[5];

		ids[0] = VARID( sensor_value ) ;
		ids[1] = VARID( sensor_units ) ;
		ids[2] = VARID( sv_temp_value ) ;
		ids[3] = VARID( sv_temp_units ) ;
		ids[4] = VARID( var_cond ) ;

		meth_sample_check_e2211
		/* e2211 */
		/*----------------*/  

		if (sensor_units == UNITS_CODE_PERC) {
			ACKNOWLEDGE ("Product Calibration in measure Mode Concentration, not allowed. Please Choose another measure unit.""|de|Produktkalibrierung im Messmodus Konzentration nicht erlaubt. Bitte whlen Sie eine andere Messeinheit.");
			process_abort;
		}



			ACKNOWLEDGE("Take a sample from the process and store the currently measured value."
						"\n"
						"Note that the meassured value of the sample is temperature dependent."
						" \n" 
						"Therefore, laboratory measurement should be performed at the sample temperature shown in the display, if possible."
						"\n"
						"As far as possible, you should transport the sample in an insulated container (Dewar)."
						"\n"
						"The meassured value may also be altered due to escaping of volatile substances.\nPress OK to show measured value."

						"|de|Entnehmen Sie dem Proze eine Probe und messen Sie diese, z.B. im Labor."
						"\n"
						"Beachten Sie, da der entnomme Wert temperaturbhngig ist."
						"\n"
						"Die Messung im Labor sollte daher mglichst bei der im Display angezeigten Probentemperatur erfolgen."
						"\n"
						"Transportieren Sie die Probe mglichst in einem Isoliergef (Dewar)."
						"\n" 
						"Der gemessene Wert der Probe kann auch durch Entweichen flchtiger Substanzen verflscht werden."
						"\n"
						"Drcken Sie OK um den gemessenen Wert zu erhalten.");

		/*----------------*/
		send (48, status) ;
	   if( int_value(function_check_status) & 0x03 ){
		/*----------------*/

			ACKNOWLEDGE("WARNING: Device is in calibration or configuration, no sample calibration allowed!"
						"\n\n"
						"ACTION: Leave device calibration or configuration and repeat this step."
						"\n\n"
						"Press OK finish" 
						"|de|WARNUNG: Das Feldgert befindet sich innerhalb einer Kalibrierung oder Konfigurierung, keine Probenentnahme erlaubt!"
						"\n\n"
						"HINWEIS: Verlassen Sie die Kalibrierung oder Konfigurierung und wiederholen Sie diesen Schritt."
						"\n\n"
						"Drcken Sie OK zum Beenden.");


		/*----------------*/
		}else{
	   	if( (int_value(function_check_status) & 0x04) ){
		/*----------------*/

			ACKNOWLEDGE("WARNING: Sample was already taken. If you call <Take Sample> twice then the first sample will be lost!"
						" \n\n"
						"ACTION: Confirm discarding the first sample."
						"\n\n"
						"Press OK to discard the first sample"
						"|de|WARNUNG: Es wurde bereits eine Probe entnommen! Wenn Sie (Produktkalibrierung - Probenentnahme) doppelt drcken, wird der zuerst entnommene Probenwert verworfen!"
						"\n\n"
						"HINWEIS: Besttigen Sie, das der zuletzt entnomme Probenwert verworfen werden kann."
						"\n\n"
						"Drcken Sie OK um den zuletzt entnommen Probenwert zu verwerfen");
			}


		  	if (sensor_units == UNITS_CODE_OHM){	   /* bei MOHM normalen Sensorvalue ausgeben */
		  		display("Actual measureed value: %{0} %{1}  Temperature: %{2} %{3}" "|de|Aktueller Messwert: %{0} %{1}  Temperatur: %{2} %{3}",ids); 
			} else {                       			  /* bei dem Rest nur uS */
		  		display("Actual measureed value: %{4} %{1}  Temperature: %{2} %{3}" "|de|Aktueller Messwert: %{4} %{1}  Temperatur: %{2} %{3}",ids); 
			}



			IGNORE_ALL_RESPONSE_CODES () ;
			send (131, status) ;
			if (status [STATUS_RESPONSE_CODE]){
				display_response_status (131, status [STATUS_RESPONSE_CODE]) ;


				ACKNOWLEDGE("Press OK finish\n\n WARNING: Product calibration was abborted!"
							"\n\n"
							"ACTION: Repeat this step."
							"|de|Drcken Sie OK zum Beenden. WARNUNG: Produktkalibrierung wurde abgebrochen!"
							"\n\n"
							"HINWEIS:Wiederholen Sie diesen Schritt.");
			}
		} /*else */
		process_abort();
	}
}

// --------------------------------------------------------------------------------------------------------------------------------
/*Produktkalibrierung Schritt 2
--------------------------------------------------------------------------------------------------------------------------------*/

METHOD meth_lab_sample_calibration
{
/* HC275:			"123456789012345678" */
	LABEL          "Input Lab Sample" "|de|Produktkalibrierung - Vergleichswerteingabe";
	HELP           "Product Calibration Sequence Input Lab Sample" "|de|Produktkalibrierung Schritt2 Vergleichswerteingabe";
	DEFINITION{
		char   status [STATUS_SIZE] ;
	
		float  fval, fval2;

		long   ids[2];

		ids[0] = VARID(sensor_units) ;
		ids[1] = VARID(var_cond) ;

		meth_sample_check_e2211


			ACKNOWLEDGE("Enter the measured lab value. The new zero point is automatically calculated and stored."
						"\n\n"
						"The values obtained by sample calibration are always accepted, even if they are outside calibration limits!"
						"\n\n"
						"Press OK to enter lab value"

						"|de|Geben Sie den gemessenen Wert der Probe ein. Der neue Meketten-Nullpunkt wird automatisch berechnet und gespeichert."
						"\n\n"
						"Die Werte bei der Probenkalibrierung werden immer bernommen, auch wenn sie auerhalb des Cal-Toleranzbandes liegen!"
						"\n\n"
						"Drcken Sie OK um den Vergleichswert einzugeben");

		/*----------------*/
		send (48, status) ;
	   if( int_value(function_check_status) & 0x03 ){
		/*----------------*/

			ACKNOWLEDGE( "WARNING: Device is in calibration or configuration, no sample calibration allowed"
						 "\n\n" 
						 "ACTION: Leave device calibration or configuration and repeat this step."
						 "\n\n"
						 "Press OK finish"
						
						"|de|WARNUNG: Das Feldgert befindet sich innerhalb einer Kalibrierung oder Konfigurierung, keine Probenentnahme erlaubt!"
						"\n\n"
						"HINWEIS: Verlassen Sie die Kalibrierung oder Konfigurierung und wiederholen Sie diesen Schritt"
						"\n\n"
						"Drcken Sie OK zum Beenden.");

		/*----------------*/
		}else{
	   	if( !(int_value(function_check_status) & 0x04) ){
		/*----------------*/
 

			ACKNOWLEDGE("WARNING: No sample was taken, no sample calibration allowed"
						"\n\n"
						"ACTION: First call <Take Sample> and then <Input Lab Sample>."
						"\n\n"
						"Press OK finish"
						
						"|de|WARNUNG: Es wurde keine Probe entnommen, Produktkalibrierung nicht zulssig!"
						"\n\n"
						"HINWEIS: Als Erstes mssen Sie <Produktkalibrierung - Probenentnahme> und dann <Produktkalibrierung - Vergleichswerteingabe> aufrufen."
						"\n\n"
						"Drcken Sie OK zum Beenden.");

		/*----------------*/
		 
			}else{
                if (sensor_units == UNITS_CODE_OHM){

	            	fval = fvar_value (sensor_value);
					fval2 = fval;
	                get_local_var_value ("Enter the lab value (%{0}) : ""|de|Eingabe des Vergleichwertes (%{0})", ids, fval) ;	     /* MOHM */

				}else{

					fval = fvar_value (var_cond);
					fval2 = fval;
					get_local_var_value ("Enter the lab COND value (%{0}) : ""|de|Eingabe des Vergleichwertes (%{0})", ids, fval) ;  /* uS,mS,Sm */
					
				   if (selected_pv_unit == 0)  { fval2 = fval;  } /* 0.000 mS */
				   if (selected_pv_unit == 1)  { fval2 = fval;  } /* 00.00 mS */
				   if (selected_pv_unit == 2)  { fval2 = fval;  } /* 000.0 mS */
				   if (selected_pv_unit == 3)  { fval2 = fval;  } /* 0000  mS */
				   if (selected_pv_unit == 4)  { fval2 = fval/1000;  } /* 0.000 mS */
				   if (selected_pv_unit == 5)  { fval2 = fval/1000;  } /* 00.00 mS */
				   if (selected_pv_unit == 6)  { fval2 = fval/1000;  } /* 000.0 mS */
				   if (selected_pv_unit == 13) { fval2 = fval/10000; } /* 0.000 Sm */
				   if (selected_pv_unit == 14) { fval2 = fval/10000; } /* 00.00 Sm */				   				   				   					
 				}


				IGNORE_ALL_RESPONSE_CODES () ;
                assign_float (var_sample_cal, fval2);
				iassign( transmitter_variable_index, transvar_sample_cal );
				send_trans (129, 1, status);
				if (status [STATUS_RESPONSE_CODE]){
					display_response_status (129, status [STATUS_RESPONSE_CODE]) ;
		/*----------------*/


					ACKNOWLEDGE("WARNING: Product calibration was abborted!\n \nACTION: Repeat this step"
								"\n\n"
								"Press OK finish"

								"|de|WARNUNG: Produktkalibrierung wurde abgebrochen!\n\nHINWEIS:Wiederholen Sie diesen Schritt."
								"\n\n"
								"Drcken Sie OK zum Beenden.");

		/*----------------*/
				}
			}
		}
		process_abort();
	}
}


