//----------------------------------------------------------
//	Copyright (C) Siemens AG (1998). All Rights Reserved
//	Product:      SIMATIC PDM
//
//	Device:			Mettler-Toledo O2 4100e/2(x)H
//	Description:	Device Description
//	Dictionary:		SIPADC01.dct, MT__STTA.dct
//	Copyright:		Mettler Toledo GmbH,
//						Process Analytics
//						P.O.Box
//						8902 Urdorf
//						Switzerland
//
// Last edit:		23.03.2005
//----------------------------------------------------------


MANUFACTURER	142,	// Mettler
DEVICE_TYPE		121,	// O2 4100e / 2(X)H
DEVICE_REVISION 1,
DD_REVISION		1


#define PDM 

#ifdef PDM
#define AMS_PDM
#define PDM_bool true
#else
#define PDM_bool false
#endif

#include "SI_HlpM.inc"
#include "SIHASTIDENT01.inc"


#define STATUS_SIZE		3	 
#define STATUS_RESPONSE_CODE	0	 							   
#define STATUS_COMM_STATUS	1
#define STATUS_DEVICE_STATUS	2



#define MANUFACTURER_LABEL "Mettler Toledo - O2 4100e/2(X)H";


#define DISPLAY_SAT		"4.2f";
#define DISPLAY_MBAR	"4.1f";
#define DISPLAY_TEMP_C	"5.1f";
#define DISPLAY_TEMP_F	"5.0f";
#define DISPLAY_CURR	"4.1f";
#define DISPLAY_PERC	"5.2f";
#define DISPLAY_SLOPE	"8.6f";
#define DISPLAY_SEC		"5.1f";
#define DISPLAY_TC		"5.2f";	
#define DISPLAY_MV		"5.0f";

#define MIN_SAT		 			 0.0;
#define MAX_SAT		 		   500.0;
#define MIN_SAT_GAS	 			 0.0;
#define MAX_SAT_GAS	 		   120.0;

#define MIN_GL				     0.0;
#define MAX_GL				    0.05;

#define MIN_PPM					 0.0;
#define MAX_PPM	 				50.0;
#define MIN_PPM_GAS	  			 0.0;
#define MAX_PPM_GAS			  9999.0;

#define MIN_PPB					 0.0;
#define MAX_PPB	 			  9999.0;
#define MIN_UGL					 0.0;
#define MAX_UGL	 			  9999.0;

#define MIN_TEMP_MEAS_C   	   -20.0;
#define MAX_TEMP_MEAS_C	       150.0;
#define MIN_TEMP_MEAS_F	        -4.0;
#define MAX_TEMP_MEAS_F	       302.0;

#define MIN_SLOPE		     0.00003;  /*   30 nA */
#define MAX_SLOPE			 0.00011;  /*  110 nA */

#define MIN_POL_VOLTAGE		   400.0;  /*  400 mV */
#define MAX_POL_VOLTAGE		  1000.0;  /* 1000 mV */

#define MIN_PRESSURE			0.0;
#define MAX_PRESSURE			9999.9;

/* Transmittervariablen */
#define transvar_sat 			      0
#define transvar_conc			      1
#define transvar_temp   		      2
#define transvar_input_curr		      3
#define transvar_curr			      8
#define transvar_perc			      9
#define transvar_input 			      10
#define transvar_press_meas		      11
#define transvar_press_cal 		      12
#define transvar_curr_lrv		      13
#define transvar_curr_urv		      14
#define transvar_cal			      15
#define transvar_slope			      16
#define transvar_cal_timer		      17
#define transvar_npkt				  18
#define transvar_salinity			  20
#define transvar_rh				      21
#define transvar_output			      22
#define transvar_fix_value		      23
#define transvar_input_temp		      24
#define transvar_polarisation_voltage 29
#define transvar_sample_cal	   		  30
#define transvar_filter_1			  31
#define transvar_alarmdelay_1		  32
#define transvar_led_mode			  33

/*	used common unit codes					*/

#define UNIT_MBAR	"mbar"
#define UNIT_TEMP_C	"C"
#define UNIT_TEMP_F	"F"
#define UNIT_MV		"mV"
#define UNIT_MA		"mA"
#define UNIT_SEC	"s"
#define UNIT_HOURS	"h"
#define UNIT_PERC	"%"
#define UNIT_GL		"gl"
#define	UNIT_PPM	"ppm"
#define	UNIT_UGL	"ugl"
#define	UNIT_PPB	"ppb"
#define UNIT_NON	""
#define UNIT_DEFAULT	" "

#define UNITS_CODE_MBAR		UNITS_CODE(8)
#define UNITS_CODE_TEMP_C	32
#define UNITS_CODE_TEMP_F	33
#define UNITS_CODE_MV		UNITS_CODE(36)
#define UNITS_CODE_MA		UNITS_CODE(39)
#define UNITS_CODE_SEC		UNITS_CODE(51)
#define UNITS_CODE_HOURS	UNITS_CODE(52)
#define UNITS_CODE_PERC		UNITS_CODE(57)
#define UNITS_CODE_GL		UNITS_CODE(97)
#define UNITS_CODE_PPM		{ 139, UNIT_PPM }
#define UNITS_CODE_UGL		{ 146, UNIT_UGL }
#define UNITS_CODE_PPB		{ 169, UNIT_PPB }
#define UNITS_CODE_NON		{ 251, UNIT_NON }





#define DV_UNITS   UNITS_CODE_PERC, UNITS_CODE_GL, UNITS_CODE_MV, UNITS_CODE_MBAR, UNITS_CODE_PPM, UNITS_CODE_UGL, UNITS_CODE_PPB
				 
#define TEMP_UNITS UNITS_CODE (UNITS_CODE_TEMP_C), UNITS_CODE (UNITS_CODE_TEMP_F)



#define PSI_FKT 0.01450326
#define KPA_FKT 0.1
#define MAX_BAR 9.999
#define DEF_BAR 1.013


/*------------------------------------------------------------------------------------*/
/*      definitions of composite transmitter_variables  							  */
/*------------------------------------------------------------------------------------*/

#define meth_sel_unit_label 	      "PV Unit" "|de|PV Einheit"	
#define meth_sel_unit_help			  "Select the PV Unit" "|de|Whlen Sie die PV Einheit"

#define meth_test					  "Test help"




#define var_temp_unit_type \
	CONSTANT_UNIT IF (sv_temp_units == UNITS_CODE_TEMP_C){ UNIT_TEMP_C }ELSE{ UNIT_TEMP_F } \
	TYPE FLOAT { \
		DISPLAY_FORMAT IF (sv_temp_units == UNITS_CODE_TEMP_C) { DISPLAY_TEMP_C } ELSE { DISPLAY_TEMP_F } }


#define def_unit_type \
			CONSTANT_UNIT IF (selected_proc_medium == 0){ SELECT (main_unit){      \
					CASE 0:  "%"    ;														\
					CASE 1:  "g/l" ;														\
					CASE 2:  "g/l"  ;														\
					CASE 3:  "ppb"  ;														\
					DEFAULT: "ppm"  ;}														\
			 }ELSE{  SELECT (main_unit){											    \
				   	CASE 0:  "%"   ;														\
				  	DEFAULT: "ppm" ; }		   											    \
			}TYPE FLOAT{					   												\
			 SCALING_FACTOR IF (selected_proc_medium == 0) { SELECT (main_unit) {  \
			    	CASE 0: 1 ;																\
					CASE 1: 1 ;																\
					CASE 2: 1 ;																\
					CASE 3: 1 ;																\
					DEFAULT: 1 ;}															\
			}ELSE{ 	SELECT (main_unit){											    \
			        CASE 0: 1 ;	    														\
				    DEFAULT: 1 ;}															\
			} DISPLAY_FORMAT IF (selected_proc_medium == 0) { SELECT (main_unit){ 	\
			 		CASE 0:        "5.3f" ;		   										    \
					CASE 1:        "5.2f" ;		   											\
					CASE 2:        "5.5f" ;		   											\
					CASE 3:        "4.0f" ;		   											\
					DEFAULT:       "5.1f" ;}	   											\
		  	 }ELSE{	SELECT (main_unit){		   									    \
		  		 	CASE 0:        "5.2f" ;													\
		  			DEFAULT:       "5.1f" ;}												\
             }								   												\

#define pv_unit_type def_unit_type }

#define output_current_unit_type_edit def_unit_type											\
			EDIT_FORMAT IF (selected_proc_medium == 0) {  SELECT (main_unit){  	\
				    CASE 0:        "5.3f" ;													\
					CASE 1:        "5.2f" ;													\
					CASE 2:        "7.5f" ;													\
					CASE 3:        "4.0f" ;													\
					DEFAULT:       "5.1f" ; }												\
			 }ELSE{ SELECT (main_unit) {      										\
				 	CASE 0:        "5.3f" ;													\
					DEFAULT:       "5.1f" ; }}												\
			MIN_VALUE  IF (selected_proc_medium == 0) {  SELECT (main_unit){		\
				    CASE 0:        0.0 ;													\
					CASE 1:        0.0 ;													\
					CASE 2:        0.0 ;													\
					CASE 3:        0.0 ;													\
					DEFAULT:       0.0 ; }													\
			}ELSE{ SELECT (main_unit) {      										\
				 	CASE 0:        0.0 ;													\
					DEFAULT:       0.0 ; }}													\
																							\
			MAX_VALUE IF (selected_proc_medium == 0) {  SELECT (main_unit){		\
				    CASE 0:      500.0  ;													\
					CASE 1:      9999.9 ;													\
					CASE 2:      0.05   ;													\
					CASE 3:      9999.9 ;													\
					DEFAULT:     50.0   ; }													\
			}ELSE{ SELECT (main_unit) {      										\
				 	CASE 0:      120.0  ;													\
					DEFAULT:     9999.9 ; }}}														
																									
																									

/*------------------------------------------------------------------------------------*/
#define selected_pv_unit_enum TYPE ENUMERATED   { {0, "%" },{ 1,"g/l" },{2, "g/l" },{3, "ppb" },{4, "ppm" } } 

#define selected_pv_unit_meth { "%" ";" "g/l" ";" "g/l" ";" "ppb" ";" "ppm" } 

#define selected_pv_unit_meth_gas { "%" ";" "ppm" }
#define selected_pv_unit_enum_gas TYPE ENUMERATED { {0, "%" },{1, "ppm" } }

/*------------------------------------------------------------------------------------*/
	   /* HC275:"123456789012345678" */
#define sel_oo0	"Off" "|de|Aus" 
#define sel_oo1	"On " "|de|Ein" 
#define selected_off_on_enum 			TYPE ENUMERATED{ { 0, sel_oo0 }, { 1, sel_oo1 } }                 
#define selected_off_on_meth			sel_oo0 ";" sel_oo1

/*------------------------------------------------------------------------------------*/
	   /* HC275:"123456789012345678" */
#define sel_hl0	"Last Value" "|de|Letzter Wert"
#define sel_hl1	"Fixed Current"	"|de|Festwert"
#define selected_hold_last_fix_enum	TYPE ENUMERATED{ { 0, sel_hl0 }, { 1, sel_hl1 } }
#define selected_hold_last_fix_meth	sel_hl0 ";" sel_hl1

/*------------------------------------------------------------------------------------*/

#define sel_proc0 "GAS"
#define sel_proc1 "DO"
#define selected_proc_medium_enum 	TYPE ENUMERATED{ {0, sel_proc0}, {1, sel_proc1} }
#define selected_proc_medium_meth sel_proc0 ";" sel_proc1

/*------------------------------------------------------------------------------------*/

#define sel_sensor_typ0 "Typ A"
#define sel_sensor_typ1 "Typ B "
#define selected_sensor_typ_enum TYPE ENUMERATED{ {0, sel_sensor_typ0}, {1, sel_sensor_typ1} } 
#define selected_sensor_type_meth sel_sensor_typ0 ";" sel_sensor_typ1

/*------------------------------------------------------------------------------------*/

#define sel_press_unit0 "BAR"
#define sel_press_unit1 "KPA"
#define sel_press_unit2 "PSI"

#define selected_press_unit_enum TYPE ENUMERATED{ {0, sel_press_unit0}, {1, sel_press_unit1}, {2, sel_press_unit2 } }
#define selected_press_unit_meth sel_press_unit0 ";" sel_press_unit1 ";" sel_press_unit2

/*------------------------------------------------------------------------------------*/
#define DISPLAY_FORMAT_OXY_PRESS DISPLAY_FORMAT SELECT(selected_press_unit){ \
			 CASE 1: "3.1f"; /* psi  */ \
			 CASE 2: "3.1f"; /* kPa  */ \
			 DEFAULT:   "3.1f"; /* bar  */ }

/*------------------------------------------------------------------------------------*/

#define sel_cal_mode0 "Conc"
#define sel_cal_mode1 "Sat"
#define selected_cal_mode_enum TYPE ENUMERATED{{0, sel_cal_mode0}, {1, sel_cal_mode1} }
#define selected_cal_mode_meth sel_cal_mode0 ";" sel_cal_mode1

/*------------------------------------------------------------------------------------*/

#define sel_temp0	"C"
#define sel_temp1	"F"
#define selected_temp_unit_enum TYPE ENUMERATED {{ 0, sel_temp0  } , { 1, sel_temp1 }}
#define selected_temp_unit_meth sel_temp0 ";" sel_temp1

/*------------------------------------------------------------------------------------*/

#define sel_temp_sensor0	"NTC22k"
#define sel_temp_sensor1	"NTC30k"
#define selected_temp_sensor_enum TYPE ENUMERATED {{ 0, sel_temp_sensor0  } , { 1, sel_temp_sensor1 }}
#define selected_temp_sensor_meth sel_temp_sensor0 ";" sel_temp_sensor1


#define sel_fix_val "mA"
#define selected_var_fix_value_meth sel_fix_val



/*------------------------------------------------------------------------------------*/
#define e2211_SW_rev			10
#define e2211					(software_revision >= e2211_SW_rev)
#define e2211_meth				(int_value( software_revision ) >= e2211_SW_rev)

#define x2211( _new, _old ) 	IF( e2211 ){ _new }ELSE{ _old }	

#define valid_2211				VALIDITY x2211( FALSE;, TRUE; ) 
#define valid_e2211				VALIDITY x2211( TRUE;, FALSE; ) 


#define modesat(T,F) 	IF  (main_unit== 0) { T } ELSE { F }

/*------------------------------------------------------------------------------------*/


//=============================================================================
//  VARIABLEN
//=============================================================================

VARIABLE response_code		// Standard-Variable
{
  LABEL	[response_code];
  HELP	[command_specific_response_code_help];
  CLASS USER_INTERFACE & DIAGNOSTIC;
  HANDLING READ;
  TYPE ENUMERATED {
    {  0, [success] },
    {  1, [undefined] },
    {  2, [invalid_selection] },
    {  3, [passed_parameter_too_large] },
    {  4, [passed_parameter_too_small] },
    {  5, [too_few_data_bytes_recieved] },
    {  6, [xmtr_specific_command_error] },
    {  7, [in_write_protect_mode] },
    {  8, [xmtr_specific_command_error] },
    {  9, [xmtr_specific_command_error] },
    { 10, [xmtr_specific_command_error] },
    { 11, [xmtr_specific_command_error] },
    { 12, [xmtr_specific_command_error] },
    { 13, [xmtr_specific_command_error] },
    { 14, [xmtr_specific_command_error] },
    { 15, [xmtr_specific_command_error] },
    { 16, [access_restricted] },
    { 32, [busy] },
    { 64, [command_not_implemented] }
  }
}

//-------------------------------------

VARIABLE device_status		// Standard-Variable
{
  LABEL	[device_status] ;
  HELP	[field_device_status_help];
  CLASS HART & DYNAMIC & DIAGNOSTIC;
  HANDLING READ;
  TYPE BIT_ENUMERATED {
    { 0x00, [no_error], MISC },
    { 0x01, "Primary variable outside limits"	"|de|Hauptvariable auerhalb Bereich", DV1 (AUTO & BAD) },
    { 0x02, "Temperature outside limits"	"|de|Nebenvariable auerhalb Bereich", DV2 (AUTO & BAD) },
    { 0x04, "Output outside operating range"	"|de|Ausgang auerhalb Mebereich",    AO1 (AUTO & BAD) },
    { 0x08, "Output in fixed mode"		"|de|Ausgang ist auf Festwert",	       AO1 (MANUAL & GOOD) },
    { 0x10, "More Status available"		"|de|Gert hat mehr Informationen",    MORE },
    { 0x20, "Device cold start"			"|de|Feldgert Kaltstart",	       MISC },
    { 0x40, "Configuration has been changed"	"|de|Konfiguration wurde verndert",   MISC & IGNORE_IN_HANDHELD },
    { 0x80, "Device malfunction or failure"	"|de|Gertefehlern oder Ausfall",      MORE}
  }
}

//-------------------------------------

VARIABLE tag
{
  LABEL	[tag];
  HELP	[tag_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(8); 
  HANDLING READ & WRITE;
}

//-------------------------------------

VARIABLE descriptor
{
  LABEL	[descriptor];
  HELP	[discriptor_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(16); 
  HANDLING READ & WRITE;
}

//-------------------------------------

VARIABLE message
{
  LABEL	[message];
  HELP	[message_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(32);
  HANDLING READ & WRITE;
}

//-------------------------------------

VARIABLE manufacturer_id
{
  LABEL	[manufacturer_id];
  HELP	[manufacturer_id_code_help];
  HANDLING READ;
  CLASS HART;
  TYPE ENUMERATED {
    DEFAULT_VALUE 142;
    { 142,  "Mettler Toledo" }
  }
}

//-------------------------------------

VARIABLE universal_revision
{
  LABEL	[universal_revision];
  HELP	[universal_revision_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
}

//-------------------------------------

VARIABLE transmitter_revision
{
  LABEL	[transmitter_revision];
  HELP	[field_device_revision_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
}

//-------------------------------------

VARIABLE software_revision
{
  LABEL	[software_revision];
  HELP	[field_device_software_revision_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
  DEFAULT_VALUE  13;
}

//-------------------------------------

VARIABLE hardware_revision
{
  LABEL	[hardware_revision];
  HELP	[hardware_revision_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER;
}

//-------------------------------------

VARIABLE device_id
{
  LABEL	[device_identification];
  HELP	[field_device_identification_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER(3);
}

//-------------------------------------

VARIABLE device_type 
{
  LABEL	[device_type];
  HELP	[manufacturers_device_type_help];
  HANDLING READ;
  CLASS HART; 
  TYPE ENUMERATED(1) {
    IF( manufacturer_id == 142 ) {	// Mettler Toledo Device Types
      { 121, "O2 4100e/2(X)H" }
    }
    { 252, [unknown] }
  }
}

//-------------------------------------

VARIABLE request_preambles
{
  LABEL	[number_of_request_preambles];
  HELP	[number_of_request_preambles_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER {
    INITIAL_VALUE 5;
    DEFAULT_VALUE 5;
    MIN_VALUE  2;
    MAX_VALUE 20;
  }
}

//-------------------------------------

VARIABLE response_preambles
{
  LABEL	[number_of_response_preambles];
  HELP	[number_of_response_preambles_help];
  HANDLING WRITE;
  CLASS HART;
  TYPE UNSIGNED_INTEGER	{
    INITIAL_VALUE 5;
    DEFAULT_VALUE 5;
  }
}

//-------------------------------------

VARIABLE device_flags
{
  LABEL	[device_flags];
  HELP	[field_device_flags_help];
  HANDLING READ;
  CLASS HART; 
  TYPE BIT_ENUMERATED {
    { 0x01, [Multisens_Dev], [multi_sensor_fld_dev] },
    { 0x02, [EEPROM_Ctrl] },
    { 0x04, [protocol_bridge_device] }
  }
}

//-------------------------------------

VARIABLE physical_signaling_code
{															  
  LABEL	[physical_signalling_code];
  HELP	[physical_signalling_code_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    { 0, [bell_202_current] },
    { 1, [bell_202_voltage] },
    { 2, [rs_485] },
    { 3, [rs_232], [rs_232_help] },
    { 6, [special] }
  }
}

//-------------------------------------

VARIABLE final_assembly_number
{
  LABEL	[final_assembly_number];
  HELP	[final_assembly_number_help];
  HANDLING READ & WRITE;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER(3) {
    MAX_VALUE 16777215;
  }
}

//-------------------------------------

VARIABLE date
{
  LABEL	[date];
  HELP	[date_help];
  HANDLING READ & WRITE;
  CLASS DEVICE;
  TYPE DATE;
}

//-------------------------------------
VARIABLE primary_damping_value
{
  LABEL	[damping_value];
  HELP	[seconds_damping_value_help]; 
  CLASS CORRECTION;
  TYPE FLOAT {
    DISPLAY_FORMAT	".2f";
  }
  CONSTANT_UNIT	[sec];
  HANDLING READ & WRITE;
}



/*------------------------------------------------------------------------------------*/
/*	transmitter status variables (command #48)					*/
VARIABLE dummy_status
{	LABEL		"dummy" ;
	HELP		" " ;
	HANDLING READ ;
	TYPE		BIT_ENUMERATED {
		{ 0x01, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x02, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x04, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x08, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x10, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x20, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x40, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x80, " ", MISC & IGNORE_IN_HANDHELD }
	}
} 

VARIABLE function_check_status {
	CLASS    DEVICE & DYNAMIC;
	LABEL		"Device Status""|de|Gertestatus" ;
	HELP		"Device status and mode" "|de|Gertestatus und Zustnde" ;
	STYLE "MULTILINE 12 3";
	HANDLING READ ;
	TYPE		BIT_ENUMERATED {
     /* HC275:"1234567890123456" */
		{ 0x01, "Configuration" "|de|Konfiguration", MODE & IGNORE_IN_HANDHELD } ,
		{ 0x02, "Calibration" "|de|Kalibrierung", MODE & IGNORE_IN_HANDHELD } ,
		{ 0x04, "Sample was taken" "|de|Produktkalbrierung gestartet", MISC & IGNORE_IN_HANDHELD }
	}
	valid_e2211
}


VARIABLE sensor_units
{
	CLASS           INPUT ;
	LABEL           "PV unit" ;
	HELP            [digital_units_help] ;
	HANDLING        READ & WRITE ;
	TYPE            ENUMERATED{ DV_UNITS }
}

VARIABLE sensor_value
{															
	CLASS           CORRECTION & DYNAMIC ;
	LABEL           "PV";
	HELP            [digital_value_help] ;
	HANDLING        READ ;
	DEFAULT_VALUE	1;
	pv_unit_type
}



VARIABLE sensor_upper_limit
{
	CLASS           INPUT ;
	LABEL           "PV Upper Sensor limit" ;
	HELP            [upper_sensor_limit_help];
	HANDLING        READ;
	DEFAULT_VALUE	0;
    pv_unit_type
}


 
VARIABLE sensor_lower_limit
{
	CLASS           INPUT ;
	LABEL           "PV Lower Sensor Limit" ;
	HELP            [lower_sensor_limit_help] ;
	HANDLING        READ ;
	DEFAULT_VALUE	500;
	pv_unit_type
}


VARIABLE sensor_minimum_span
{
	CLASS           INPUT  ;
	LABEL           "Min. Span" ;
	HELP            [minimum_span_help] ;
	HANDLING        READ ;
	pv_unit_type   
}			



VARIABLE mA_output_current						
{
	CLASS           ANALOG_OUTPUT & DYNAMIC ;
	LABEL           "PV AO" ;
	HELP				 [analog_value_help] ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MA;
	DEFAULT_VALUE	21;
	TYPE            FLOAT
	{	
		DISPLAY_FORMAT	DISPLAY_CURR	
		EDIT_FORMAT		DISPLAY_CURR 
	}
}



VARIABLE analog_alarm_code
{
	CLASS           ANALOG_OUTPUT ;
	LABEL           [alarm_select] ;
	HELP            [alarm_code_help] ;
	HANDLING        READ ;
	TYPE            ENUMERATED{
		ALARM_SELECTION_CODE(0) ,
		ALARM_SELECTION_CODE(1) ,
		ALARM_SELECTION_CODE(239) ,
		ALARM_SELECTION_CODE(250) ,
		ALARM_SELECTION_CODE(251) ,
		ALARM_SELECTION_CODE(252) ,
		ALARM_SELECTION_CODE(253)
	}
}


VARIABLE percent_of_range						
{
	CLASS           ANALOG_OUTPUT & DYNAMIC ;
	LABEL           "PV %" ;
	HELP            [percent_of_range_help] ;
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_PERC;
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_PERC }
}



VARIABLE xmtr_transfer_function
{
	CLASS           CORRECTION;
	LABEL           [transfer_function] ;
	HELP            "You can choose the kind of dependence of the current from the digital value" ;
	HANDLING        READ & WRITE ;
	TYPE            ENUMERATED{
		TRANSFER_FUNCTION_CODE (0),            /* Linear 		*/
		TRANSFER_FUNCTION_CODE (1)             /* Square Root 	*/
	}
}



VARIABLE output_current_lrv                                         
{
	CLASS ANALOG_OUTPUT & DYNAMIC;
	LABEL           [pv_lrv] ;
	HELP            [lower_range_value_help] ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT IF (selected_proc_medium == 0){ SELECT (main_unit){ 
					CASE 0:  "%"    ;										 
					CASE 1:  "g/l" ;										 
					CASE 2:  "g/l"  ;										 
					CASE 3:  "ppb"  ;										 
					DEFAULT: "ppm"  ;}										 
			 }ELSE{  SELECT (main_unit){								 
				   	CASE 0:  "%"   ;										 
				  	DEFAULT: "ppm" ; }
	}
   TYPE FLOAT {
 
 
	DISPLAY_FORMAT IF (selected_proc_medium == 0) { SELECT (main_unit){ 	
			 		CASE 0:        "5.3f" ;		   								
					CASE 1:        "5.2f" ;		   								
					CASE 2:        "5.5f" ;		   								
					CASE 3:        "4.0f" ;		   								
					DEFAULT:       "5.1f" ;}	   								
		  	 }ELSE{	SELECT (main_unit){		   							
		  		 	CASE 0:        "5.2f" ;										
		  			DEFAULT:       "5.1f" ;}									
             } 
    
 
	
	MIN_VALUE  IF (selected_proc_medium == 0) {  SELECT (main_unit){		
				    CASE 0:        0.0 ;										
					CASE 1:        0.0 ;										
					CASE 2:        0.0 ;										
					CASE 3:        0.0 ;										
					DEFAULT:       0.0 ; }										
			}ELSE{ SELECT (main_unit) {      							
				 	CASE 0:        0.0 ;										
					DEFAULT:       0.0 ; }
			}
													
																				
	MAX_VALUE IF (selected_proc_medium == 0) {  SELECT (main_unit){		
				    CASE 0:      500.0  ;										
					CASE 1:      9999.9 ;										
					CASE 2:      0.05   ;										
					CASE 3:      9999.9 ;										
					DEFAULT:     50.0   ; }										
			}ELSE{ SELECT (main_unit) {      							
				 	CASE 0:      120.0  ;										
					DEFAULT:     9999.9 ;} 
			}
	}
}


VARIABLE output_current_urv                                         
{
	CLASS ANALOG_OUTPUT & DYNAMIC;
	LABEL           [pv_urv] ;
	HELP            [upper_range_value_help] ;
	HANDLING        READ & WRITE ;

	CONSTANT_UNIT IF (selected_proc_medium == 0){ SELECT (main_unit){ 
					CASE 0:  "%"    ;										 
					CASE 1:  "g/l" ;										 
					CASE 2:  "g/l"  ;										 
					CASE 3:  "ppb"  ;										 
					DEFAULT: "ppm"  ;}										 
			 }ELSE{  SELECT (main_unit){								 
				   	CASE 0:  "%"   ;										 
				  	DEFAULT: "ppm" ; }
	}
   TYPE FLOAT {
 
 
	DISPLAY_FORMAT IF (selected_proc_medium == 0) { SELECT (main_unit){ 	
			 		CASE 0:        "5.3f" ;		   								
					CASE 1:        "5.2f" ;		   								
					CASE 2:        "5.5f" ;		   								
					CASE 3:        "4.0f" ;		   								
					DEFAULT:       "5.1f" ;}	   								
		  	 }ELSE{	SELECT (main_unit){		   							
		  		 	CASE 0:        "5.2f" ;										
		  			DEFAULT:       "5.1f" ;}									
             } 
    
 
	
	MIN_VALUE  IF (selected_proc_medium == 0) {  SELECT (main_unit){		
				    CASE 0:        0.0 ;										
					CASE 1:        0.0 ;										
					CASE 2:        0.0 ;										
					CASE 3:        0.0 ;										
					DEFAULT:       0.0 ; }										
			}ELSE{ SELECT (main_unit) {      							
				 	CASE 0:        0.0 ;										
					DEFAULT:       0.0 ; }
			}
													
																				
	MAX_VALUE IF (selected_proc_medium == 0) {  SELECT (main_unit){		
				    CASE 0:      500.0  ;										
					CASE 1:      9999.9 ;										
					CASE 2:      0.05   ;										
					CASE 3:      9999.9 ;										
					DEFAULT:     50.0   ; }										
			}ELSE{ SELECT (main_unit) {      							
				 	CASE 0:      120.0  ;										
					DEFAULT:     9999.9 ;} 
			}
	}

}

//-------------------------------------

VARIABLE write_protect
{
  LABEL	[write_protect];
  HELP	[write_protect_mode_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    {   0, [not_write_protected] },
    {   1, [write_protected] },
    { 250, [not_used] },
    { 251, [none] },
    { 252, [unknown] },
    { 253, [special] }
  }
}

//-------------------------------------

VARIABLE private_label_distributor
{
  LABEL	[private_label_distributor];
  HELP	[private_label_distributor_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    { 142, "Mettler Toledo"}
  }
}


//-------------------------------------

VARIABLE primary_analog_current_value
{   
  LABEL	[analog_value_block_1];
  HELP	[analog_value_help];    
  CLASS	CONTAINED & DYNAMIC;
  HANDLING READ;  
  CONSTANT_UNIT	[mA]; 
  TYPE FLOAT {
    DISPLAY_FORMAT	".3f";
  }
} 


VARIABLE sensor_serial_number
{
	CLASS           DEVICE;
	LABEL           "Number   " ;
	HELP            [sensor_serial_number_help] ;
	HANDLING        READ & WRITE ;
	TYPE            UNSIGNED_INTEGER (3) ;
}



VARIABLE sv_temp_units
{
  LABEL	"Unit";
  HELP	[digital_units_help];
  CLASS CORRECTION & DYNAMIC;
  HANDLING READ & WRITE;
  DEFAULT_VALUE	32;
  TYPE ENUMERATED {
    { 32, [degC],    [degrees_celsius_help] },
    { 33, [degF],    [degrees_fahrenheit_help] }
  }
}

//-------------------------------------

VARIABLE sv_temp_value
{
  LABEL	"Temperature" "|de|Temperatur";
  HELP	[digital_value_help];
  CLASS CORRECTION & DYNAMIC;
  HANDLING READ;
  
  CONSTANT_UNIT		IF( selected_temp_unit == 0 ) { [degC]; } ELSE { [degF]; }
  DISPLAY_FORMAT	IF( selected_temp_unit == 0 ) { "5.1f"; } ELSE { "3.0f"; }
 
 
   
}




/*------------------------------------------------------------------------------------*/
/*      definitions of transmitter_variables					    			      */
/*------------------------------------------------------------------------------------*/

VARIABLE transmitter_variable_index
{
	CLASS           USER_INTERFACE ;
	LABEL           [blank] ;
	TYPE            INDEX transmitter_variable_array ;
}

ARRAY OF VARIABLE transmitter_variable_array
{
	ELEMENTS{
			 transvar_sat 					,var_sat ;				/*  0 */
			 transvar_conc					,var_conc ;				/*  1 */
			 transvar_temp   				,var_temp ; 			/*  2 */
			 transvar_input_curr			,var_input_curr ;		/*  3 */
			 transvar_curr					,mA_output_current ;  	/*  8 */
			 transvar_perc					,percent_of_range ; 	/*  9 */

			 /* Als Methode  
			 transvar_input 				,var_input   			   10 */

			 transvar_press_meas			,var_press_meas ;		/* 11 */
			 transvar_curr_lrv				,output_current_lrv ;	/* 13 */
             transvar_curr_urv				,output_current_urv ;   /* 14 */
			 
			 /* Als Methode  
			 transvar_cal					,var_cal ;                 15 */

			 transvar_slope					,var_slope ;			/* 16 */   
			 transvar_cal_timer				,var_cal_timer;		    /* 17 */
			 transvar_npkt					,var_npkt ;				/* 18 */

			 transvar_rh					,var_rh ;  				/* 21 */

			 /* Als Methode
			 transvar_output				,var_output ;			   22 */

			 transvar_fix_value				,var_fix_value ; 		/* 23 */

			 /* Als Methode
			 transvar_input_temp			,var_input_temp;	       24 */

			 transvar_salinity				,var_salinity ;			/* 20 */
			 transvar_polarisation_voltage  ,var_pol_volt ;		    /* 29 */
			 transvar_sample_cal	 		,var_sample_cal ;	    /* 30 */
			 transvar_filter_1				,var_filter_1 ;		    /* 31 */
			 transvar_alarmdelay_1			,var_alarmdelay_1 ;		/* 32 */
			
			 /*Als Methode
			 transvar_led_mode				,var_led_mode ;			   33 */
	}
}



/* 							  HC275:"123456789012345678" */
#define var_fix_value_label  		"HOLD Fix Value" "|de|HOLD-Festwert"
#define var_filter_1_label			"Output Filter" "|de|Ausgangsfilter"
#define var_alarmdelay_1_label	    "Alarm Delay" "|de|Alarmzeitverzgerung"


#define var_fix_value_help			"Specify fixed output current in HOLD mode"	"|de|Festwert fr Ausgangsstrom im HOLD-Zustand"
#define var_filter_1_help			"Filtertime of output current" "|de|Filterzeit fr Ausgangsstrom"
#define var_alarmdelay_1_help		"Delay time of alarm signal" "|de|Alarmzeitverzgerung fr das Alarmsymbol"





VARIABLE var_sat										/* V0		*/
{
	CLASS           INPUT & DYNAMIC ;
					/* HC275:"123456789012345678" */
	LABEL           "SAT" ;
	HELP			"Percent Saturation value" "|de|Sttigungsindex";
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_PERC;
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_SAT }
}


VARIABLE var_conc
{

	CLASS			INPUT & DYNAMIC ;
	LABEL			"Conc";
	HELP			"Concentration value" "|de|Konzentrationswert";
	HANDLING		READ;
/* 	pv_unit_type */
	CONSTANT_UNIT IF (selected_proc_medium == 0){ SELECT (main_unit){ 
					/*CASE 0:  "%"    ;*/
					CASE 1:  "g/l" ;										 
					CASE 2:  "g/l"  ;										 
					CASE 3:  "ppb"  ;										 
					DEFAULT: "ppm"  ;}										 
			 }ELSE{  SELECT (main_unit){								 
				   	CASE 0:  "%"   ;										 
				  	DEFAULT: "ppm" ; }
	}
   TYPE FLOAT {
 
 
	DISPLAY_FORMAT IF (selected_proc_medium == 0) { SELECT (main_unit){ 	
			 		/*CASE 0:        "5.3f" ;*/
					CASE 1:        "5.2f" ;		   								
					CASE 2:        "5.5f" ;		   								
					CASE 3:        "4.0f" ;		   								
					DEFAULT:       "5.1f" ;}	   								
		  	 }ELSE{	SELECT (main_unit){		   							
		  		 	CASE 0:        "5.2f" ;										
		  			DEFAULT:       "5.1f" ;}									
             } 
    
 
	
	MIN_VALUE  IF (selected_proc_medium == 0) {  SELECT (main_unit){		
				    /*CASE 0:        0.0 ;*/
					CASE 1:        0.0 ;										
					CASE 2:        0.0 ;										
					CASE 3:        0.0 ;										
					DEFAULT:       0.0 ; }										
			}ELSE{ SELECT (main_unit) {      							
				 	CASE 0:        0.0 ;										
					DEFAULT:       0.0 ; }
			}
													
																				
	MAX_VALUE IF (selected_proc_medium == 0) {  SELECT (main_unit){		
				    /*CASE 0:      500.0  ;*/
					CASE 1:      9999.9 ;										
					CASE 2:      5.0   ;										
					CASE 3:      9999.9 ;										
					DEFAULT:     50.0   ; }										
			}ELSE{ SELECT (main_unit) {      							
				 	CASE 0:      120.0  ;										
					DEFAULT:     9999.9 ;} 
			}
	}
  	VALIDITY		modesat( FALSE;, TRUE; ) 
    
}


VARIABLE var_temp									/* V2		*/
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "Temperature" "|de|Temperatur" ;
	HELP			"Temperature for process medium temperature compensation" "|de|Temperatur des Prozemediums";
	HANDLING        READ ;
	CONSTANT_UNIT		IF( selected_temp_unit == 0 ) { [degC]; } ELSE { [degF]; }
	 TYPE FLOAT {
    DISPLAY_FORMAT	IF( selected_temp_unit == 0 ) { "5.1f"; } ELSE { "3.0f"; }

	}
}



VARIABLE var_input_curr										/* V3  Sensorstrom		*/
{
	CLASS           INPUT & DYNAMIC ;
					/* HC275:"123456789012345678" */
	LABEL           "mA" ;
	HELP			"Sensor input current" "|de|Eingangsstrom" ;
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_MA;
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_CURR }
}





VARIABLE var_press_meas
{
	CLASS           INPUT & DYNAMIC;
				  /*"123456789012345678" */
	LABEL           "Press(mbar)" "|de|Druck (mbar)" ;
	HELP		"The Preasure for measurement in mbar" "|de|Druck im Memodus Einheit [mbar]" ;
	HANDLING        READ & WRITE ;
	DEFAULT_VALUE	1013;
	TYPE            FLOAT
	{	
			DISPLAY_FORMAT_OXY_PRESS

			MIN_VALUE \
			SELECT(selected_press_unit){ \
			 CASE 1: 0.0 ;
			 CASE 2: 0.0 ;
			 DEFAULT: 0.0 ; 
			}		   

	}
}





VARIABLE var_press_cal
{
	CLASS           CORRECTION;
 	       /* HC275:"123456789012345678" */
	LABEL           "Pressure (cal)" ;
	HELP			"The Preasure for calibration" "|de|Druck fr die Kalibrierung";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MBAR; 
	DEFAULT_VALUE	1013;
	TYPE            FLOAT{	
		DISPLAY_FORMAT        DISPLAY_MBAR
		EDIT_FORMAT           DISPLAY_MBAR
		MIN_VALUE             MIN_PRESSURE 
		MAX_VALUE             MAX_PRESSURE
	}
}



VARIABLE var_slope
{
	CLASS           CORRECTION;
 	       /* HC275:"123456789012345678" */
	LABEL           "Slope" "|de|Steilheit";
	HELP		    "The Calibration generates the electrode parameters. You can also directly enter the slope of an electrode" 
					"|de|Durch die Kalibrierung werden die Parameter der Elektrode bestimmt. In diesem Men ist eine direkte Eingabe der Steilheit der Elektrode mglich";
	HANDLING IF ( selected_sensor_type == 0 ) { READ & WRITE; } ELSE { READ; }
	CONSTANT_UNIT   UNIT_MA;
	TYPE            FLOAT{
		DISPLAY_FORMAT        DISPLAY_SLOPE
		EDIT_FORMAT           DISPLAY_SLOPE
		MIN_VALUE             MIN_SLOPE	
		MAX_VALUE             MAX_SLOPE	
		DEFAULT_VALUE		  0.00006 ;
	}
}

VARIABLE var_npkt
{
	CLASS           CORRECTION;
	LABEL           "Zeropoint" "|de|Nullpunkt" ;
	HELP		    "The Calibration generates the electrode parameters. You can also directly enter the zeropoint of an electrode"
					"|de|Durch die Kalibrierung werden die Parameter der Elektrode bestimmt. In diesem Men ist eine direkte Eingabe des Nullpunktes der Elektrode mglich";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MA;
	TYPE            FLOAT{
		DISPLAY_FORMAT        "8.6f";
		EDIT_FORMAT           "8.6f";
		MIN_VALUE             -0.000002 ;	
		MAX_VALUE             0.000002 ;
		DEFAULT_VALUE		  0.000000 ;
	}
}

VARIABLE var_cal_timer							
{
	CLASS           CORRECTION;
 	       /* HC275:"123456789012345678" */
	LABEL           "Cal.Timer" "|de|Kalbriertimerintervall" ;
	HELP			"Calibration timer interval. 0 = cal time switched off" "|de|Kalibriertimerintervall erinnert rechtzeitig an eine Kalibrierung (0 = Kalibriertimer ausgeschaltet)";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_HOURS;
	TYPE            FLOAT{	
		DISPLAY_FORMAT         "04.0f";
		EDIT_FORMAT            "4.0f";
		MIN_VALUE              0.0 ;
		MAX_VALUE              9999.0 ;
	}
}


VARIABLE var_cal_mode
{
	CLASS			CORRECTION;
	LABEL			"Cal. Mode" "|de|Kalibriermodus";
	HELP			"Specify Calibration mode (Calibration to saturation or concentration)" 
					"|de|Kalibriermodus festlegen (Kalibrierung auf Sttigungsindex oder Konzentration)";
	HANDLING		READ & WRITE ;
	selected_cal_mode_enum
}

VARIABLE var_salinity
{
	CLASS			CORRECTION;
	LABEL			"Sal. Corr""|de|Salzkorrektur (Salinitt)";
	HELP			"Salinity correction ppt(parts per thousand) - corresponds to g/kg" "|de| Salzkorrektur (Salinitt) in ppt (entspricht g/kg)";
	HANDLING		READ & WRITE ;
	CONSTANT_UNIT	UNIT_NON;
	DEFAULT_VALUE	0;
	TYPE			FLOAT{
		DISPLAY_FORMAT	"5.2f";
		EDIT_FORMAT		"5.2f";
		MIN_VALUE		0.0;
		MAX_VALUE		45.0;
	}

}

VARIABLE var_rh
{
	CLASS           CORRECTION;
 	       /* HC275:"123456789012345678" */
	LABEL           "rel. humidity" "|de|Relative Feuchte";
	HELP			"relative humidity" "|de|Eingabe der relativen Feuchte (fr Kalibrierung notwendig)";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT	UNIT_PERC;
	TYPE            FLOAT{		 
		DISPLAY_FORMAT         "02.0f";
		EDIT_FORMAT            "2.0f";
		MIN_VALUE              0.0 ;
		MAX_VALUE              100.0 ;
	}
}

VARIABLE var_fix_value							/* V21		*/
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "HOLD Fix Value" "|de|HOLD-Festwert";
	HELP			"Specify fixed output current in HOLD mode" "|de|Festwert fr Ausgangsstrom im HOLD-Zustand";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MA;
	DEFAULT_VALUE	21;
	TYPE            FLOAT{	
		DISPLAY_FORMAT       DISPLAY_CURR
		EDIT_FORMAT          DISPLAY_CURR
		MIN_VALUE            3.8;
		MAX_VALUE            22.0;
	}
}

VARIABLE var_pol_volt
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "Polarisation voltage" "|de|Polarisationspannung";
	HELP			"Polarisation voltage for sensor" "|de|Polarisationsspannung des Sensors";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MV;
	DEFAULT_VALUE	675;
	TYPE            FLOAT{	
		DISPLAY_FORMAT         DISPLAY_MV
		EDIT_FORMAT            DISPLAY_MV
		MIN_VALUE              400.0;
		MAX_VALUE              1000.0;
	}
}

VARIABLE var_sample_cal							/* V30		*/
{
	/* var_sample_cal darf nicht in die upload_variables Liste */
	CLASS           CORRECTION;
	LABEL           "Sample" ;
	HELP			"Calibration with Sampling to determine the electrode zero point" ;
	HANDLING        READ & WRITE ;
	
	CONSTANT_UNIT IF (selected_proc_medium == 0){ SELECT (main_unit){ 
					CASE 0:  "%"    ;										 
					CASE 1:  "g/l" ;										 
					CASE 2:  "g/l"  ;										 
					CASE 3:  "ppb"  ;										 
					DEFAULT: "ppm"  ;}										 
			 }ELSE{  SELECT (main_unit){								 
				   	CASE 0:  "%"   ;										 
				  	DEFAULT: "ppm" ; }
	}
   TYPE FLOAT {
 
 
	DISPLAY_FORMAT IF (selected_proc_medium == 0) { SELECT (main_unit){ 	
			 		CASE 0:        "5.3f" ;		   								
					CASE 1:        "5.2f" ;		   								
					CASE 2:        "5.5f" ;		   								
					CASE 3:        "4.0f" ;		   								
					DEFAULT:       "5.1f" ;}	   								
		  	 }ELSE{	SELECT (main_unit){		   							
		  		 	CASE 0:        "5.2f" ;										
		  			DEFAULT:       "5.1f" ;}									
             } 
    
 
	
	MIN_VALUE  IF (selected_proc_medium == 0) {  SELECT (main_unit){		
				    CASE 0:        0.0 ;										
					CASE 1:        0.0 ;										
					CASE 2:        0.0 ;										
					CASE 3:        0.0 ;										
					DEFAULT:       0.0 ; }										
			}ELSE{ SELECT (main_unit) {      							
				 	CASE 0:        0.0 ;										
					DEFAULT:       0.0 ; }
			}
													
																				
	MAX_VALUE IF (selected_proc_medium == 0) {  SELECT (main_unit){		
				    CASE 0:      9999.9  ;										
					CASE 1:      9999.9 ;										
					CASE 2:      9999.9   ;										
					CASE 3:      9999.9 ;										
					DEFAULT:     9999.9   ; }										
			}ELSE{ SELECT (main_unit) {      							
				 	CASE 0:      9999.9  ;										
					DEFAULT:     9999.9 ;} 
			}
	}
}


VARIABLE var_filter_1							/* V31		*/
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "Output Filter" "|de|Ausgangsfilter";
	HELP			"Time constant of output filter" "|de|Zeitkonstante des Ausgangsfilters" ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_SEC;
	DEFAULT_VALUE	0;
	TYPE            FLOAT{	
		DISPLAY_FORMAT         "3.0f";
		EDIT_FORMAT            "3.0f";
		MIN_VALUE              0.0;
		MAX_VALUE              120.0;
	}
}


VARIABLE var_alarmdelay_1							/* V32		*/
{
	CLASS           ANALOG_OUTPUT;
	LABEL           var_alarmdelay_1_label;
	HELP			var_alarmdelay_1_help;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_SEC;
	DEFAULT_VALUE	10;
	TYPE            FLOAT{	
		DISPLAY_FORMAT         "3.0f";
		EDIT_FORMAT            "3.0f";
		MIN_VALUE              0.0;
		MAX_VALUE              600.0;
	}
}

/*------------------------------------------------------------------------------------*/
/*		definition of collection for dynamic variables		*/

/* ARRAY OF COLLECTION dynamic_variables {
	ELEMENTS	{
		PRIMARY, pv, [pv]; 
	}
}  */

COLLECTION OF VARIABLE pv
{
	LABEL           [pv] ;
	HELP            [primary_variable_help] ;
	MEMBERS         {
			 /*             Sensor Correction Information                           */

			 DIGITAL_UNITS,         sensor_units,           [units],                        [digital_units_help] ; 
			 DIGITAL_VALUE,         sensor_value,           [blank],                        [digital_value_help] ;
			 SENSOR_UNITS,          sensor_units,           [sensor_unit],                  [digital_units_help] ;

			 UPPER_SENSOR_LIMIT,    sensor_upper_limit,     [usl],                          [upper_sensor_limit_help] ;
			 LOWER_SENSOR_LIMIT,    sensor_lower_limit,     [lsl],                          [lower_sensor_limit_help] ;
			 MINIMUM_SPAN,          sensor_minimum_span,    [minimum_span],                 [minimum_span_help] ;		

			 /*             Analog Output Information                                       */

			 ANALOG_VALUE,          mA_output_current,      [analog_output_value],          [analog_value_help] ;
			 ALARM_CODE,            analog_alarm_code,      [alarm_select],                 [alarm_code_help] ; 

			 /*             Input Information                                                               */

  			 PERCENT_RANGE,         percent_of_range,       [percent_of_range_help] ;
			 TRANSFER_FUNCTION,     xmtr_transfer_function, [transfer_function_help] ;
			 RANGE_UNITS,           sensor_units,           [range_units_help] ;

			 UPPER_RANGE_VALUE,     output_current_urv,[urv],[upper_range_value_help] ;
			 LOWER_RANGE_VALUE,     output_current_lrv,[lrv],[lower_range_value_help] ;
			 SENSOR_SERIAL_NUMBER,  sensor_serial_number,   [sensor_serial_number],         [sensor_serial_number_help] ;
			 DAMPING_VALUE,         sensor_damping_value,   [damping_value],                [seconds_damping_value_help] ;
	  
			}
}

/*------------------------------------------------------------------------------------*/
/* Hilfsvariablen zum fllen von Lcken, Inhalt wird verworfen						  */
/*------------------------------------------------------------------------------------*/

VARIABLE dummy1
{
  CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
  LABEL	"Dummy1Byte";
  HANDLING READ & WRITE;
  TYPE UNSIGNED_INTEGER(1);
}

VARIABLE dummy4
{
  CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
  LABEL	"Dummy4Byte";
  HANDLING READ & WRITE;
  TYPE UNSIGNED_INTEGER(4);
}

VARIABLE xmtr_specific_status_0 {

 LABEL "Error Status" "|de|Fehlerzustnde";
 HELP  "Field Device Error Status- Failure messages of the Field Device are listed" "|de|Feldgertfehlermeldungen" ;
 STYLE "MULTILINE 12 4";
 TYPE  	BIT_ENUMERATED {

	{ 0x01, "Err 01 SAT Value" "|de|Err 01 Mebereich SAT" , DV1 (AUTO & BAD) } ,
	{ 0x02, "Err 02 Conc Value" "|de|Err 02 Mebereich Conc", DV1 (AUTO & BAD) } ,
	{ 0x04, "Err 03 Temp Value" "|de|Err 03 Temperaturfhler", TV1 (AUTO & BAD) } ,
	{ 0x08, "Err 11 Loop < 3.8mA" "|de|Err 11 Stromausgang < 3,8 mA", AO1 (AUTO & BAD) } ,
	{ 0x10, "Err 12 Loop >20.5mA" "|de|Err 12 Stromausgang > 20.5 mA", AO1 (AUTO & BAD) } ,
	{ 0x20, "Err 13 Loop Span" "|de|Err 13 Stromspanne zu klein", DATA } ,
	{ 0x40, "Err 98 Config Data" "|de|Err 98 Systemfehler", HARDWARE } ,
	{ 0x80, "Err 99 Data Lost" "|de|Err 99 Abgleichdaten defekt", HARDWARE }
 }
}

VARIABLE xmtr_specific_status_1 {
 LABEL	"Smiley Earnest" "|de|Smiley ernst" ;
 HELP	"Smiley Earnest - Maintance required. Sensoface provides information on wear and required maintance. However, device continues operation with diminished accuracy." 
 		"|de| Smiley ernst - Wartung erforderlich! Sensoface gibt Hinweise zum Zustand Ihrer Mekette.";
  STYLE "MULTILINE 12 4";
 TYPE		BIT_ENUMERATED {
	{ 0x01, "Response time between 300 - 600 sec" "|de|Einstellzeit zwischen 300-600 Sekunden", PROCESS & IGNORE_IN_HANDHELD } ,
	{ 0x02, "Over 80% of the calibration interval has already past" "|de|ber 80% des Kalbriertimerintervals abgelaufen", PROCESS & IGNORE_IN_HANDHELD } ,
	{ 0x20, "Zero point" "|de|Nullpunkt", PROCESS & IGNORE_IN_HANDHELD }
	{ 0x40, "Slope" "|de|Steilheit", PROCESS & IGNORE_IN_HANDHELD }
 }
}

VARIABLE xmtr_specific_status_2 {
  LABEL 	"Smiley Sad""|de|Smiley traurig" ;
  HELP  	"Smiley Sad - Correct measurment is no longer ensured. Sensoface provides information on wear and required maintance. However, device continues operation with seriously diminished accuracy."
  			"|de| Smiley traurig - Eine korrekte Messung wird nicht mehr gewhrleistet!  Sensoface gibt Hinweise zum Zustand Ihrer Mekette.";
  STYLE "MULTILINE 12 3";
  TYPE  	BIT_ENUMERATED {

	{ 0x01, "Response time > 600s, replace sensor" "|de|Einstellzeit > 600s Sensor ersetzen", PROCESS & IGNORE_IN_HANDHELD } ,
	{ 0x02, "Calibration interval has been exceeded" "|de|Kalibriertimerinterval abgelaufen", PROCESS & IGNORE_IN_HANDHELD } ,
	{ 0x04, "Err 33" "|de|Err 33 Anschluleitung defekt", PROCESS & IGNORE_IN_HANDHELD } ,
	{ 0x20, "Zero point outside transmitter limit < -1nA or >+1nA" "|de|Nullpunkt auerhalb der zulssigen Grenzen < -1nA oder >+1nA", PROCESS & IGNORE_IN_HANDHELD } ,
	{ 0x40, "Slope outside transmitter limit " "|de|Steilheit auerhalb des Limits", PROCESS & IGNORE_IN_HANDHELD },
	{ 0x80, "Temperature Conc or SAT outside limit" "|de|Temperatur auerhalb der Mebereiche von Konzentration oder Sttigung", PROCESS & IGNORE_IN_HANDHELD }
 }
}



VARIABLE analog_output_saturated1 {
 TYPE  BIT_ENUMERATED {

	{ 0x01, "Analog Out Saturated" "|de|Analoge Ausgang befindet sich in Sttigung", AO1 (AUTO & BAD) }
 }
}

VARIABLE analog_output_fixed1 {
  LABEL "HOLD Mode" "|de|Hold Modus" ;
  HELP  "Analog Outputs of the Field Device are fixed in HOLD mode. The analog and digital Outputs remain unchanged."
  		"|de| Der Analoge Ausgang des Feldgertes befindet sich im HOLD-Modus. ";
  STYLE "MULTILINE 12 1";
  TYPE  BIT_ENUMERATED{

	{ 0x01, "HOLD Mode" "|de|HOLD-Modus", AO1 (MANUAL & GOOD) }
 }
}

/*------------------------------------------------------------------------------------*/


VARIABLE selected_22mA								/* V20.0	*/
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "22mA on Error"
					"|de|22mA bei Fehlermeldungen";

	HELP			"Switch 22mA signal for error message on or off"
					"|de|22mA-Signal fr Fehlermeldung ein-/ausschalten";
	HANDLING        READ & WRITE ;
	selected_off_on_enum 
}


VARIABLE selected_hold_fix							/* V20.1	*/
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "HOLD Last/Fix";
	HELP			"The output current behavior in the HOLD mode can be specified. Last- The output current is frozen at its last value, Fix- A constant value from 3.8mA to 22mA"
					"|de|Der Ausgangsstrom kann im HOLD-Zustand wie folgt eingestellt werden: Last- letzter Ausgangsstromwert, Fix- Vorgabe des Ausgangsstroms";
	HANDLING        READ & WRITE ;
	selected_hold_last_fix_enum
}

VARIABLE selected_senso_check						/* V15.1	*/
{
	CLASS           CORRECTION;
	LABEL           "Sensocheck";
	HELP			"Sensocheck continously monitors the sensor" 
					"|de|Kontinuierliche berwachung des Sensors";

	HANDLING        READ & WRITE ;
	selected_off_on_enum 
}

VARIABLE selected_holdLED						  	/* V33.0	*/
{
	CLASS           DEVICE;
	LABEL           "Alarm LED Hold";
	HELP			"LED state in HOLD Mode: if setting ON - Alarm on and Hold flashes- else setting OFF - Alarm flashes and Hold on -"
					"|de|LED im Hold Zustand: Parametrierung ON - Alarm an und HOLD blinkt - Parametrierung OFF - Alarm blinkt HOLD an -";
	HANDLING        READ & WRITE ;
	selected_off_on_enum
}


/*------------------------------------------------------------------------------------*/
/*   INPUT SELECTION CODE Transmitter Specific Variable 10							  */
/*------------------------------------------------------------------------------------*/


 VARIABLE selected_pv_unit								    /* V10.0 */
 {
	CLASS 		 INPUT;
	LABEL        "PV unit " ;
	HELP		 meth_sel_unit_help;
	HANDLING     READ & WRITE ;

	TYPE         ENUMERATED{
	
		IF ( selected_proc_medium == 0 )
		{

				 { 0, "%"}   ,       
				 { 1, "g/l"},       
				 { 2, "g/l"} ,       
				 { 3, "ppb"} ,        
				 { 4, "ppm"}         

		}
		ELSE 	{
				 { 0, "%"}   ,       		
				 { 1, "ppm"}

		}
	} 
 				    
 }

 


VARIABLE selected_proc_medium								/* V10.1 */
{
	CLASS           INPUT ;
	LABEL           "Process medium" "|de|Memedium" ;
	HELP		    "Select process medium: dissolved Oxygen (DO) or measuring in GAS (GAS)"
					"|de|Auswahl Memedium: gelster Sauerstoff (DO) oder Messung in Gasen (GAS)";
	HANDLING        READ & WRITE ;
/*	selected_proc_medium_enum */

	TYPE ENUMERATED{ 
	{0, "DO"}, {1, "GAS"}
	}

	POST_EDIT_ACTIONS{
		method_set_transfer1_unit
	}

}

 
METHOD method_set_transfer1_unit
{
  CLASS	INPUT;
  DEFINITION
  {
   	if  (((selected_proc_medium==1) && ((main_unit=2) || (main_unit=3) || (main_unit=4) )) ){
		   assign_int( main_unit, 1 ); 
	}   
  } 
}





VARIABLE selected_sensor_type								/* V10.2 */
{
	CLASS           INPUT ;
	LABEL           "Sensor type"
					"|de|Sensortyp" ;
	HELP			"Typ A (standard applications) Typ B (traces)"
					"|de|Typ A Sensoren fr Standardanwendungen, Typ B Sensoren fr Spurenmessung" ;
	HANDLING        READ & WRITE ;
	selected_sensor_typ_enum
}

VARIABLE selected_press_unit								
{ 
	CLASS           INPUT ;
	LABEL           "press medium"
					"|de|Druckeinheit auswhlen" ;
	HANDLING        READ & WRITE ;

	selected_press_unit_enum
	
} 




VARIABLE selected_cal_mode
{
	CLASS           INPUT ;
	LABEL			"Cal. Mode" "|de|Kalibriermodus";
	HELP			"Specify Calibration mode (Calibration to saturation or concentration)" 
					"|de|Kalibriermodus festlegen (Kalibrierung auf Sttigungsindex oder Konzentration)";
	HANDLING        READ & WRITE ;
    selected_cal_mode_enum
}


/*------------------------------------------------------------------------------------*/
/*   INPUT SELECTION CODE for Temperature    Transmitter Specific Variable 24	      */	
/*------------------------------------------------------------------------------------*/

VARIABLE selected_temp_unit                                 /* V24.1 */
{
	CLASS           INPUT ;
	LABEL           "Temp. unit" "|de|Temperatureinheit" ;
	HANDLING        READ & WRITE ;
	selected_temp_unit_enum
}



VARIABLE selected_temp_sensor                       		/* V24.2 */                    
{
	CLASS           INPUT ;
	LABEL           "Temperaturesensor" "|de|Temperaturfhler" ;
	HANDLING        READ&WRITE ;
	selected_temp_sensor_enum
}


VARIABLE main_unit
{
  LABEL	"Measuring unit"  "|de|Hauptmegre";
  HELP	"The measuring unit is the primary HART variable"
  	"|de|Die Hauptmegre ist die primre HART-Variable";
  HANDLING READ & WRITE;
  CLASS INPUT & DYNAMIC & CORRECTION;
  TYPE ENUMERATED {
  
	IF (selected_proc_medium ==0){
  	  { 0, "%", "%" },
      { 1, "g/l", "g/l" },
	  { 2, "g/l", "g/l" },
      { 3, "ppb", "parts per billion" },
      { 4, [parts_per_million], [parts_per_million_help] }
	}ELSE{
	  { 0, "%", "% Messmodus GAS" },
   	  { 1, "ppm", "parts per million Messmodus GAS" }
	}				    
  }
}

VARIABLE primary_value
{
  LABEL	"Primary Variable" "|de|Primrer Mewert";
  HELP	[digital_value_help];
  CLASS CORRECTION & DYNAMIC;
  HANDLING READ;
 
  CONSTANT_UNIT	IF (selected_proc_medium == 0)
  {
  		SELECT (main_unit)
  		{      
			CASE 0:  "%"    ;
			CASE 1:  "g/l" ;
			CASE 2:  "g/l"  ;
			CASE 3:  "ppb"  ;											   
			DEFAULT: "ppm"  ; 
		}

  }ELSE{  
   		SELECT (main_unit)
   		{											   
   	   		CASE 0:  "%"   ;													   
   	  		DEFAULT: "ppm" ; 
   	  	}	
  }



  TYPE FLOAT 
  {
  
    DISPLAY_FORMAT	IF (selected_proc_medium == 0) 
    { 
    	SELECT (main_unit)
   		{
	   		CASE 0:        "5.3f" ;		   										    
			CASE 1:        "5.2f" ;		   							   
			CASE 2:        "5.5f" ;		   							   
			CASE 3:        "4.0f" ;		   							   
			DEFAULT:       "5.2f" ;
		}	   							   
		
	}ELSE{	
		SELECT (main_unit)
		{		   						   
			CASE 0:        "5.2f" ;									   
			DEFAULT:       "5.2f" ;
		}								   
   	} 
	  
    
    MIN_VALUE IF (selected_proc_medium == 0) 
    {  
    	SELECT (main_unit)
    	{		
		    CASE 0:        0.0 ;													
			CASE 1:        0.0 ;													
			CASE 2:        0.0 ;													
			CASE 3:        0.0 ;													
			DEFAULT:       0.0 ; 
		}													

	}ELSE{ 
	    SELECT (main_unit) 
	    {
		 	CASE 0:        0.0 ;													
			DEFAULT:       0.0 ;
		} 
    }
			
    
	MAX_VALUE IF (selected_proc_medium == 0) 
	{  
	
	    SELECT (main_unit)
	    {		
	      	CASE 0:      500.0  ;													
	   		CASE 1:      9999.9 ;													
	  		CASE 2:      0.05   ;													
			CASE 3:      9999.9 ;													
			DEFAULT:     50.0   ; 
	    }
	}ELSE{ 
	    SELECT (main_unit) 
	    {      										
	   		CASE 0:      120.0  ;													
	   		DEFAULT:     9999.9 ; 
	    }
	}
  } //TYPE FLOAT   
}  //Variable


/*--------------------------------------------------------------------------------------*/
/*
 * Used by the HART Communicator for two things
 *
 * The first is a write order list. If there are 4 variables
 * in the queue to be written and sensor_units was the third
 * item placed in the queue it will be the first variable
 * written when the send key is press because it is the first variable
 * in this list. If the variables in the queue are not in this list
 * they will be taken in the order of their ID's.
 *
 * Second this is the list of variables that the user will be 
 * allowed to view and modify under the offline configure.
 * Any variable not in this list will not appear to the user
 * in offline configure.
 */
/* Variablen die durch offline Konfigurierung im Gert gendert werden knnen */
/* Reihenfolge wie in menu_rev_config und menu_device_info */

#define def_config_variables \
      selected_proc_medium, \
      selected_sensor_type, \
      output_current_lrv, \
      output_current_urv, \
      var_filter_1, \
      selected_22mA, \
      selected_hold_fix, \
      var_fix_value, \
      selected_temp_unit, \
      selected_temp_sensor, \
      var_salinity, \
      var_pol_volt, \
      selected_cal_mode, \
      var_cal_timer, \
      selected_senso_check, \
      var_alarmdelay_1, \
      var_slope, \
	  var_npkt, \
      var_press_meas, \
      selected_holdLED
	  
	  /*selected_pv_unit, \*/
	  /* Druckeinheiten, proc_press_corr */
	  /*	  selected_press_unit, \*/
	  /*	  var_press_meas, \ */


/*------------------------------------------------------------------------------------*/
/* Hilfsvariablen um zusammengesetzte Transmitter Variablen zu definieren			  */
/*------------------------------------------------------------------------------------*/

#define def_selection_code_index( _sel ) \
  LABEL	"Sel. Code Index"; \
  HELP	""; \
  TYPE INDEX _sel; \
  CLASS USER_INTERFACE; \
  HANDLING READ & WRITE; 

VARIABLE selection_code_index  { def_selection_code_index( selection_codes   ) }

/*-------------------------------------------*/

#define def_selection_codes_tab( _sel, _cal_sel ) \
  LABEL	"Sel. Codes"; \
  HELP	""; \
  ELEMENTS { \
    			transvar_input,  	_sel, ""; \
			    transvar_cal,			_cal_sel, ""; \
			    transvar_output, 	output1_selection_code, "";


#define def_selection_codes( _sel, _cal_sel ) \
		def_selection_codes_tab( _sel, _cal_sel ) \
			transvar_led_mode, 	conf_4_selection_code, ""; \
			transvar_input_temp, input_temp_code, ""; }


ARRAY OF COLLECTION selection_codes  { def_selection_codes  ( input1_selection_code,   cal_selection_code ) }

/*------------------------------------------------------------------------------------*/
/* Variable 10 																		  */
/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE input1_selection_code
{
  LABEL "Input Sel. Code";
  MEMBERS {
    BYTE1,	selected_proc_medium ;
    BYTE2,	main_unit; /*selected_pv_unit;*/
    BYTE3,	selected_sensor_type ;
    BYTE4,	selected_press_unit ;
  }
}
/*------------------------------------------------------------------------------------*/
/* Variable 15                                                                        */
/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE cal_selection_code
{
  LABEL "Calib. Sel. Code";
  MEMBERS {
    BYTE1,	selected_cal_mode ;
    BYTE2,	selected_senso_check ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*-------------------------------------------*/

COLLECTION OF VARIABLE output1_selection_code
{
  LABEL "Output Sel. Code";
  MEMBERS {
    BYTE1,	selected_22mA ;
    BYTE2,	selected_hold_fix ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*-------------------------------------------*/

COLLECTION OF VARIABLE input_temp_code
{
  LABEL "Temp Sel. Code";
  MEMBERS {
    BYTE1,	selected_temp_unit ;
    BYTE2,	selected_temp_sensor ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
} 												 

COLLECTION OF VARIABLE conf_4_selection_code
{
  LABEL "Conf.4 Sel. Code";
  MEMBERS {
    BYTE1,	selected_holdLED;
    BYTE2,	dummy1 ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*------------------------------------------------------------------------------------*/
/*	Hilfsvariable fr transmitter-specific commands							  		  */
/*------------------------------------------------------------------------------------*/

VARIABLE transmitter_variable_unit_code
{
	CLASS           LOCAL;
	LABEL           "" ;
	HANDLING        READ ;
	TYPE            INTEGER (1) ;
}




UNIT HART_MAIN_UNIT
{
  main_unit:	primary_value,
  		output_current_lrv,
		output_current_urv,
		sensor_units,
		sensor_upper_limit,
		sensor_lower_limit,
		sensor_minimum_span
}

//=============================================================================
//  COMMANDS
//=============================================================================

COMMAND read_unique_identifier
{
  NUMBER 0;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      254,
      manufacturer_id,
      device_type,
      request_preambles,
      universal_revision,
      transmitter_revision,
      software_revision,
      hardware_revision <0xf8>,
      physical_signaling_code <0x07>,
      device_flags,
      device_id
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_primary_variable
{
  NUMBER 1;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      sensor_units,
      primary_value //sensor_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_current_and_percent_range
{
  NUMBER 2;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      mA_output_current,
      percent_of_range
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_dynamic_variables_and_pv_current
{
  NUMBER 3;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      mA_output_current,
      sensor_units,
      primary_value, //primary_value, //sensor_value,
      sv_temp_units,
      sv_temp_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND write_polling_address
{
  NUMBER 6;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      polling_address
    }
    REPLY {
      response_code,
      device_status,
      polling_address
    }
  }
  RESPONSE_CODES {
     0,	SUCCESS, [no_command_specific_errors];
     2,	DATA_ENTRY_ERROR, [invalid_selection];
     5,	MISC_ERROR, [too_few_data_bytes_recieved];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND read_unique_identifier_with_tag
{
  NUMBER 11;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST {
      tag
    }
    REPLY {
      response_code,
      device_status,
      254,
      manufacturer_id,
      device_type,
      request_preambles,
      universal_revision,
      transmitter_revision,
      software_revision,
      hardware_revision <0xf8>,
      physical_signaling_code <0x07>,
      device_flags,
      device_id 
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_message
{
  NUMBER 12;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      message
    }
  }
  RESPONSE_CODES {
    0, SUCCESS,	[no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_tag_descriptor_date
{
  NUMBER 13;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      tag,
      descriptor,
      date
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_sensor_info
{
  NUMBER 14;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      sensor_serial_number,
      sensor_units,
      sensor_upper_limit,
      sensor_lower_limit,
      sensor_minimum_span
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_output_info
{
  NUMBER 15;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      analog_alarm_code,
      xmtr_transfer_function,
      sensor_units,
      output_current_urv,
      output_current_lrv,
      primary_damping_value,
      write_protect,
      private_label_distributor
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_final_assembly_number
{
  NUMBER 16;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      final_assembly_number
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND write_message
{
  NUMBER 17;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      message
    }
    REPLY {
      response_code,
      device_status,
      message
    }
  }
  RESPONSE_CODES {
     0,	SUCCESS,    [no_command_specific_errors];
     5,	MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_tag_descriptor_date
{
  NUMBER 18;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      tag,
      descriptor,
      date
    }
    REPLY {
      response_code,
      device_status,
      tag,
      descriptor,
      date
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_final_assembly_number
{
  NUMBER 19;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      final_assembly_number
    }
    REPLY {
      response_code,
      device_status,
      final_assembly_number
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_pv_range_values
{
  NUMBER 35;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      sensor_units,
      output_current_urv,
      output_current_lrv
    }
    REPLY {
      response_code,
      device_status,
      sensor_units,
      output_current_urv,
      output_current_lrv
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
     2, DATA_ENTRY_ERROR, [invalid_selection];
     5, MISC_ERROR, [too_few_data_bytes_recieved];
     9, DATA_ENTRY_ERROR, [lower_range_value_too_high];
    10, DATA_ENTRY_ERROR, [lower_range_value_too_low];
    11, DATA_ENTRY_ERROR, [upper_range_value_too_high];
    12, DATA_ENTRY_ERROR, [upper_range_value_too_low];
    13, DATA_ENTRY_ERROR, [URV_and_LRV_out_of_limits];
    14, DATA_ENTRY_WARNING, [span_too_small];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND set_pv_upper_range_value
{
  NUMBER 36;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND set_pv_lower_range_value
{
  NUMBER 37;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND reset_configuration_change_flag
{
  NUMBER 38;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND enter_exit_fixed_pv_current_mode
{
  NUMBER 40;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST {
      primary_analog_current_value
    }
    REPLY {
      response_code,
      device_status,
      primary_analog_current_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
    4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND perform_transmitter_self_test
{
  NUMBER 41;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND perform_master_reset
{
  NUMBER 42;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND read_additional_transmitter_status
{
  NUMBER 48;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
  	  xmtr_specific_status_0 ,	/*  0  */
	  xmtr_specific_status_1 ,	/*  1  */
	  xmtr_specific_status_2 ,	/*  2  */		  	
	  dummy_status,			   
	  dummy_status,			   		   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  analog_output_saturated1 ,	   
	  dummy_status,			   
	  dummy_status,			   
	  analog_output_fixed1,		   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  dummy_status,			   
	  function_check_status
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_transmitter_variable_information
{
  NUMBER 54;
  OPERATION READ;
  TRANSACTION {
    REQUEST {
      transmitter_variable_index( INFO, INDEX )
    }
    REPLY {
      response_code,
      device_status,
      transmitter_variable_index,
      transmitter_variables[transmitter_variable_index].SENSOR_SERIAL_NUMBER,
      transmitter_variables[transmitter_variable_index].SENSOR_UNITS,
      transmitter_variables[transmitter_variable_index].UPPER_SENSOR_LIMIT,
      transmitter_variables[transmitter_variable_index].LOWER_SENSOR_LIMIT,
      transmitter_variables[transmitter_variable_index].DAMPING_VALUE,
      transmitter_variables[transmitter_variable_index].MINIMUM_SPAN
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, MISC_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_number_of_response_preambles
{
  NUMBER 59;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      response_preambles
    }
    REPLY {
      response_code,
      device_status,
      response_preambles
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
    4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-----------------------------------------------------------------------------

COMMAND read_float_variable
{
  NUMBER 128;
  OPERATION READ;
  TRANSACTION {
    REQUEST {
      transmitter_variable_index (INFO, INDEX)
    }
    REPLY {
      response_code,
      device_status,
	  transmitter_variable_index,
	  transmitter_variable_unit_code,
	  transmitter_variable_array [transmitter_variable_index]
 }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, DATA_ENTRY_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-----------------------------------------------------------------------------

COMMAND read_selections
{
  NUMBER 128;
  OPERATION READ;
  TRANSACTION 1{
    REQUEST {
      selection_code_index (INFO, INDEX)
    }
    REPLY {
      response_code,
      device_status,
      selection_code_index,
      251,		// None
	  selection_codes[selection_code_index].BYTE1,
      selection_codes[selection_code_index].BYTE2,
      selection_codes[selection_code_index].BYTE3,
      selection_codes[selection_code_index].BYTE4
    }
  }
 


  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, DATA_ENTRY_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_float_variable
{
  NUMBER 129 ;
  OPERATION WRITE ;
  TRANSACTION {
    REQUEST {
			transmitter_variable_index (INFO,INDEX) ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]

    }
    REPLY {
			response_code,	device_status,
			transmitter_variable_index ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors] ;
     2, DATA_ENTRY_ERROR, [invalid_selection] ;
     3, DATA_ENTRY_ERROR, [passed_parameter_too_large] ;
     4, DATA_ENTRY_ERROR, [passed_parameter_too_small] ;
     5, MISC_ERROR, [too_few_data_bytes_recieved] ;
     7, MODE_ERROR, [in_write_protect_mode] ;
    12, DATA_ENTRY_ERROR, "Invalid unit code" ;
    32, DATA_ENTRY_ERROR, "Busy" ;
  }
}

//-------------------------------------

COMMAND write_selections
{
  NUMBER 129 ;
  OPERATION WRITE ;
  TRANSACTION {
    REQUEST {
      selection_code_index (INFO, INDEX),
      251,		// None
		selection_codes[selection_code_index].BYTE1,
      	selection_codes[selection_code_index].BYTE2,
      	selection_codes[selection_code_index].BYTE3,
      	selection_codes[selection_code_index].BYTE4
    }
    REPLY {
      response_code,
      device_status,
      selection_code_index,
      251,		// None
      	selection_codes[selection_code_index].BYTE1,
      	selection_codes[selection_code_index].BYTE2,
      	selection_codes[selection_code_index].BYTE3,
      	selection_codes[selection_code_index].BYTE4
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors] ;
     2, DATA_ENTRY_ERROR, [invalid_selection] ;
     3, DATA_ENTRY_ERROR, [passed_parameter_too_large] ;
     4, DATA_ENTRY_ERROR, [passed_parameter_too_small] ;
     5, MISC_ERROR, [too_few_data_bytes_recieved] ;
     7, MODE_ERROR, [in_write_protect_mode] ;
    12, DATA_ENTRY_ERROR, "Invalid unit code" ;
    32, DATA_ENTRY_ERROR, "Busy" ;
  }
}


/*------------------------------------------------------------------------------------*/
/*      transmitter-specific commands #128, #129                                      */
/*------------------------------------------------------------------------------------*/

#define send_trans_read( _status, _transvar ) \
					iassign( selection_code_index, _transvar ); \
					send_trans( 128, 2, _status ); 

#define send_trans_write( _status, _transvar ) \
					iassign( selection_code_index, _transvar ); \
					send_trans( 129, 2, _status ); 
		

/*------------------------------------------------------------------------------------*/
/*      transmitter-specific commands #131                                			  */
/*------------------------------------------------------------------------------------*/

COMMAND cmd_take_sample_calibration
{
	NUMBER          131;
	OPERATION       COMMAND;

	TRANSACTION
	{
		REQUEST{ }
		REPLY{ response_code, device_status	}
	}
	RESPONSE_CODES  {	 
				 0 , SUCCESS ,          [no_command_specific_errors] ; 
				 5 , MISC_ERROR ,       [too_few_data_bytes_recieved] ; 
				16, MODE_ERROR ,		[access_restricted];	
	}
}




//=============================================================================
//  MENU Bar
//=============================================================================

MENU Menu_Main_Specialist
{
  LABEL [main_menu];
  ITEMS {
    Menu_File,
    Menu_S_Device,
    Menu_S_View,
    Menu_Options,
    Menu_Help
  }
}

//-------------------------------------

MENU Menu_Main_Maintenance
{
  LABEL [main_menu];
  ITEMS	{
    Menu_File,
    Menu_M_Device,
    Menu_M_View,
    Menu_Options,
    Menu_Help
  }
}

//-----------------------------------------------------------------------------
//    Menu: File
//-----------------------------------------------------------------------------

MENU Menu_File
{
  LABEL [menu_File];
  ITEMS {
    std_Save,
    SEPARATOR,
    std_Eigenschaften,
    SEPARATOR,
    std_Print,
    std_PrintPreview,
    std_PrintSetup,
    std_PageSetup,
    std_Schriftfelder,
    SEPARATOR,
    std_Exit
  }
}

//-------------------------------------

MENU Menu_S_Device
{
  LABEL [menu_Device];
  ITEMS {
    std_CommWay,
    SEPARATOR,
    std_LoadinDevice,										
    std_LoadinPC,											
    SEPARATOR,
    loop_test,
    self_test,
    master_reset,
    configuration_flag_reset,
    SEPARATOR,
    meth_take_sample_calibration,
    meth_lab_sample_calibration,
    SEPARATOR,
    OnlineDialog_rerange,
    SEPARATOR,
    OnlineDialog_hart_comm
  }
}

MENU Menu_M_Device
{
  LABEL [menu_Device];
  ITEMS {
    std_LoadinDevice,										
    std_LoadinPC,											
    SEPARATOR,
    self_test,
  }
}

//-------------------------------------

MENU Menu_S_View
{
  LABEL [menu_View];
  ITEMS {
    OnlineWindow_display,
    OnlineWindow_S_diagnosis, 
    SEPARATOR,
    std_Funktionsleiste,
    std_Statuszeile,
    SEPARATOR,
    std_Update
  }
}

MENU Menu_M_View
{
  LABEL [menu_View];
  ITEMS {
    OnlineWindow_display,
    OnlineWindow_M_diagnosis, 
    SEPARATOR,
    std_Funktionsleiste,
    std_Statuszeile,
    SEPARATOR,
    std_Update
  }
}

//-------------------------------------

MENU Menu_Options
{
  LABEL [menu_Options];
  ITEMS {
    std_Einstellungen,
    std_Untereintraege
  }
}

//-------------------------------------

MENU Menu_Help
{
  LABEL [menu_Help];
  ITEMS {
    std_Hilfethemen,
    std_HilfeKontext,
    SEPARATOR,
    std_HilfeGeraet,
    SEPARATOR,
    std_HilfeEinfuehrung,
    std_HilfeErsteSchritte,
    SEPARATOR,
    std_Hilfebenutzen,
    std_Info
  }
}

//=============================================================================
//  Online-Windows
//=============================================================================

MENU OnlineWindow_display	// sollte vorhanden sein (Button: Mewertanzeige)
{
  LABEL [menu_dialog_display];
  ITEMS {
    Page_1_display		// sollte vorhanden sein (Button: Mewertanzeige)
  }
}

//-----------------------------------------------------------------------------

MENU Page_1_display		// sollte vorhanden sein (Button: Mewertanzeige)
{
  LABEL "Mettler Toledo - O2 4100e/2(X)H";
  ITEMS {
    analog_output_fixed1 (READ_ONLY),
    BarVal_meas_display,
    Val_temp_display,
    mA_output_current (READ_ONLY),
    var_sat,
    var_conc,
    var_temp,
    device_status
  }
}

//-------------------------------------

MENU BarVal_meas_display
{
	LABEL	[menu_dialog_display_measure];

  ITEMS {
			primary_value, /*,main_unit, /**/
		    output_current_lrv		(READ_ONLY),
		    output_current_urv		(READ_ONLY)
 }

}



//-------------------------------------

MENU Val_temp_display
{
  LABEL	"Temperature"	"|de|Temperatur";
  ITEMS {
    sv_temp_value
  }
}

//-----------------------------------------------------------------------------

MENU OnlineWindow_S_diagnosis
{
  LABEL	[menu_dialog_diagnosis];
  ITEMS {
    OnlineWindow_diagnosis_device,
    Page_S_diagnosis_status
  }
}

MENU OnlineWindow_M_diagnosis
{
  LABEL	[menu_dialog_diagnosis];
  ITEMS {
    OnlineWindow_diagnosis_device,
    Page_M_diagnosis_status
  }
}

//-------------------------------------

MENU OnlineWindow_diagnosis_device
{
  LABEL	[menu_ident_device];
  ITEMS {
    tag			 (READ_ONLY),
// ??? removed by Siemens 03/29/99:    unit_tag		 (READ_ONLY),
    manufacturer_id	 (READ_ONLY),
    device_id		 (READ_ONLY),
    device_type		 (READ_ONLY),
    software_revision	 (READ_ONLY),
    hardware_revision	 (READ_ONLY),
    transmitter_revision (READ_ONLY),
    universal_revision	 (READ_ONLY)
  }
}

//-------------------------------------

MENU Page_S_diagnosis_status
{
  LABEL	"Errors && Smileys" "|de|Fehler && Smileys";
  ITEMS {
    xmtr_specific_status_0 (READ_ONLY),
    analog_output_fixed1	(READ_ONLY),
    function_check_status	(READ_ONLY),
    xmtr_specific_status_1	(READ_ONLY),
    xmtr_specific_status_2	(READ_ONLY),
	analog_aoutput_saturated1 (READ_ONLY),
    configuration_flag_reset
  }
}

MENU Page_M_diagnosis_status
{
  LABEL	"Errors && Smileys" "|de|Fehler && Smileys";
  ITEMS {
    xmtr_specific_status_0 (READ_ONLY),
    analog_output_fixed1	(READ_ONLY),
    function_check_status	(READ_ONLY),
    xmtr_specific_status_1	(READ_ONLY),
    xmtr_specific_status_2	(READ_ONLY),
	analog_aoutput_saturated1 (READ_ONLY),
    configuration_flag_reset
  }
}

//-------------------------------------

MENU OnlineDialog_rerange
{
  LABEL	[menu_window_lo_up_value];
  ITEMS {
    Page_rerange
  }
}

//-------------------------------------

MENU Page_rerange  //Messbereich Anfang/Ende
{
  LABEL	[menu_window_lo_up_value];
  ITEMS {
    primary_variable, 					//selected_pv_unit,		 //primary_variable
    output_current_lrv, 			//  4 mA Eingabe
    sensor_lower_limit (READ_ONLY),	//max LOWER Limit	
    output_current_urv, 			// 20 mA Eingabe	
    sensor_upper_limit (READ_ONLY),	//max UPPER limit

    sie_set    		
  }
}

//-------------------------------------

MENU OnlineDialog_hart_comm
{
  LABEL	[menu_HART_Comm];
  ITEMS {
    Page_polling_address,
    Page_request_response_preambles
  }
}

//-------------------------------------

MENU Page_polling_address
{
  LABEL	[menu_polling_address];
  ITEMS {
    polling_address,
    polling_address_set
  }
}

//-------------------------------------

MENU Page_request_response_preambles
{
  LABEL	[menu_request_response_preambles];
  ITEMS {
    response_preambles,
    request_preambles,
    sie_set
  }
}

//-----------------------------------------------------------------------------
//   Standard Methods
//-----------------------------------------------------------------------------

METHOD SEPARATOR
{
  LABEL	[menu_Separator];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Save
{
  LABEL	[menu_File_Save];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Eigenschaften
{
  LABEL	[menu_File_Properties];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Print
{
  LABEL	[menu_File_Print];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PrintPreview
{
  LABEL	[menu_File_PrintPreview];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PrintSetup
{
  LABEL	[menu_File_PrintSetup];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PageSetup
{
  LABEL	[menu_File_PageSetup];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Schriftfelder
{
  LABEL	[menu_File_Labels];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Exit
{
  LABEL	[menu_File_Exit];
  DEFINITION { }
}

//-------------------------------------

METHOD std_CommWay
{
  LABEL	[menu_Device_CommWay];
  DEFINITION { }
}

//-------------------------------------

METHOD std_LoadinDevice
{
  LABEL	[menu_Device_LoadinDevice];
  DEFINITION { }
}

//-------------------------------------

METHOD std_LoadinPC
{
  LABEL	[menu_Device_LoadinPC];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Funktionsleiste
{
  LABEL	[menu_View_Toolbar];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Statuszeile
{
  LABEL	[menu_View_Statusbar];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Update
{
  LABEL	[menu_View_Update];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Einstellungen
{
  LABEL	[menu_Options_Properties];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Untereintraege
{
  LABEL	[menu_Options_Subitems];
  DEFINITION { }
}


//=============================================================================
//  Table
//=============================================================================

MENU Table_Main_Specialist
{
  LABEL "Mettler Toledo - O2 4100e/2(X)H";
  ITEMS {
    Tab_s_identification,
    Tab_s_inputs,
    Tab_s_outputs,
    Tab_s_calibration,
    Tab_s_correction
  }
}

//-------------------------------------

MENU Tab_s_identification
{
  LABEL [menu_ident];
  ITEMS {
    Tab_s_opunit,
    Tab_s_device
  }
}

//-------------------------------------

MENU Tab_s_opunit
{
  LABEL [menu_ident_opunit];
  ITEMS {
    tag,
    descriptor,
    message
  }
}

//-------------------------------------

MENU Tab_s_device
{
  LABEL [menu_ident_device];
  ITEMS	{
    manufacturer_id,
    universal_revision,
    transmitter_revision,
    software_revision,
    hardware_revision,
    device_id,
    device_type,
    device_flags,
    physical_signaling_code,
    final_assembly_number,
    date
  }
}

//-------------------------------------

MENU Tab_s_inputs
{
  LABEL "Inputs" "|de|Eingang";
  ITEMS {
	selected_sensor_type,
	selected_proc_medium,
	main_unit, 
    selected_temp_unit ,
	selected_temp_sensor
        
  }
}

//-------------------------------------

MENU Tab_s_outputs
{
  LABEL "Outputs" "|de|Ausgang";
  ITEMS	{
    output_current_lrv,		// Anfang (4mA)
    output_current_urv,		// Ende  (20mA)
	var_filter_1,
    selected_22mA,		// 22mA bei Fehler
    selected_hold_fix,		// HOLD Last/Fix
    var_fix_value		// HOLD-Fix Wert

	//mA_output_current,
	//percent_of_range

  }
}

//-------------------------------------
MENU Tab_s_calibration
{
  LABEL "Cal settings"	"|de|Cal Einstellungen";
  ITEMS	{
	selected_cal_mode,
	var_cal_timer,
	var_slope,
	var_npkt,
    selected_senso_check,
    var_alarmdelay_1,
	selected_holdLED
  }
}

//-------------------------------------

MENU Tab_s_correction
{
  LABEL "Correction settings"	"|de|Korrektur Einstellungen";
  ITEMS	{
	var_pol_volt,
	meth_sel_press_unit,
	var_salinity,
	var_press_meas,

  }
}


//-----------------------------------------------------------------------------

MENU Table_Main_Maintenance
{
  LABEL "Mettler Toledo - O2 4100e/2(X)H";
  ITEMS {
    Tab_m_identification,
    Tab_m_inputs,
    Tab_m_outputs,
    Tab_m_calibration,
  }
}

//-------------------------------------

MENU Tab_m_identification
{
  LABEL [menu_ident];
  ITEMS {
    Tab_s_opunit,
    Tab_s_device
  }
}

//-------------------------------------

MENU Tab_m_opunit
{
  LABEL [menu_ident_opunit];
  ITEMS {
    tag (READ_ONLY),
    descriptor,
    message
  }
}

//-------------------------------------

MENU Tab_m_device
{
  LABEL [menu_ident_device];
  ITEMS	{
    manufacturer_id,
    universal_revision,
    transmitter_revision,
    software_revision,
    hardware_revision,
    device_id,
    device_type,
    device_flags,
    physical_signaling_code,
    final_assembly_number,
    date
  }
}

//-------------------------------------

MENU Tab_m_inputs
{
  LABEL "Inputs" "|de|Eingang";
  ITEMS {
	selected_sensor_type (READ_ONLY),
	selected_proc_medium (READ_ONLY),
	main_unit (READ_ONLY), 
    selected_temp_unit (READ_ONLY),
	selected_temp_sensor (READ_ONLY)
        
  }
}

//-------------------------------------

MENU Tab_m_outputs
{
  LABEL "Outputs" "|de|Ausgang";
  ITEMS	{
    output_current_lrv (READ_ONLY),		// Anfang (4mA)
    output_current_urv (READ_ONLY),		// Ende  (20mA)
	var_filter_1 (READ_ONLY),
    selected_22mA (READ_ONLY),		// 22mA bei Fehler
    selected_hold_fix (READ_ONLY),		// HOLD Last/Fix
    var_fix_value (READ_ONLY)		// HOLD-Fix Wert

	//mA_output_current,
	//percent_of_range

  }
}

//-------------------------------------
MENU Tab_m_calibration
{
  LABEL "Cal settings"	"|de|Cal Einstellungen";
  ITEMS	{
	selected_cal_mode (READ_ONLY),
	var_cal_timer (READ_ONLY),
    selected_senso_check (READ_ONLY),
    var_alarmdelay_1 (READ_ONLY),
	selected_holdLED (READ_ONLY)
  }
}

//-------------------------------------

MENU Tab_m_correction
{
  LABEL "Correction settings"	"|de|Korrektur Einstellungen";
  ITEMS	{
	var_pol_volt (READ_ONLY),
	meth_sel_press_unit (READ_ONLY),
	var_salinity (READ_ONLY),
	var_press_meas (READ_ONLY)

  }
}


//-----------------------------------------------------------------------------

MENU upload_variables		// Schreiben ins Feldgert
{
  LABEL	[menu_load_to_device];
  ITEMS {
    tag,		//--- Standard-HART-Parameter ---
    descriptor,
    message,
    final_assembly_number,
    date,
			//--- Transmitter-Specific Variables ---
    
    main_unit,
	primary_value,
	output_current_lrv,
	output_current_urv,
    def_config_variables

  }
}

//-------------------------------------

MENU download_variables		// Lesen aus Feldgert
{
  LABEL	[menu_load_to_PC];
  ITEMS {
    tag,		//--- Standard-HART-Parameter ---
    descriptor,
    message,
    manufacturer_id,
    universal_revision,
    transmitter_revision,
    software_revision,
    hardware_revision,
    device_id,
    device_type,
    device_flags,
    physical_signaling_code,
    final_assembly_number,
    date,
			//--- Transmitter-Specific Variables ---

	main_unit,
	primary_value,
	output_current_lrv,
	output_current_urv,
	def_config_variables
  }
}

//=============================================================================
//  Methods
//=============================================================================

METHOD sie_set			// Transmit-Button
{
  LABEL	[transfer];
  HELP	[transfer_help];
  CLASS INPUT;
  DEFINITION { }
}

//-------------------------------------

METHOD polling_address_set
{
  LABEL	[transfer];
  HELP 	[transfer_help];
  CLASS INPUT;
  DEFINITION {
    ACKNOWLEDGE( [message_polling_address] );
  }
}

/*------------------------------------------------------------------------------------*/
/* AMS mode Umschaltungen 												              */
/*------------------------------------------------------------------------------------*/

#ifdef AMS

#define mode0(T,F) 	IF (!e2211 && (selected_senso_check   == 0) && (xmtr_specific_status_1 == 0) && (xmtr_specific_status_2 == 0)) { T } ELSE { F }
#define mode1(T,F) 	IF (!e2211 && (selected_senso_check   == 1) && (xmtr_specific_status_1 == 0) && (xmtr_specific_status_2 == 0)) { T } ELSE { F }
#define mode2(T,F) 	IF (!e2211 && (xmtr_specific_status_1 != 0) && (xmtr_specific_status_2 == 0)) { T } ELSE { F }
#define mode3(T,F) 	IF (!e2211 && (xmtr_specific_status_2 != 0)) { T } ELSE { F }
#define mode4(T,F) 	IF ( e2211 && (selected_senso_check   == 0) && (xmtr_specific_status_1 == 0) && (xmtr_specific_status_2 == 0)) { T } ELSE { F }
#define mode5(T,F) 	IF ( e2211 && (selected_senso_check   == 1) && (xmtr_specific_status_1 == 0) && (xmtr_specific_status_2 == 0)) { T } ELSE { F }
#define mode6(T,F) 	IF ( e2211 && (xmtr_specific_status_1 != 0) && (xmtr_specific_status_2 == 0)) { T } ELSE { F }
#define mode7(T,F) 	IF ( e2211 && (xmtr_specific_status_2 != 0)) { T } ELSE { F }

REFRESH rel_ams_mode
{
	software_revision, selected_senso_check, xmtr_specific_status_1, xmtr_specific_status_2 :
	ams_mode0, ams_mode1, ams_mode2, ams_mode3, ams_mode4, ams_mode5, ams_mode6, ams_mode7
}

#define def_ams_mode( _mode ) \
	CLASS           LOCAL; \
	LABEL           ""; \
	HANDLING        READ; \
	TYPE            INTEGER (1); \
	VALIDITY			 _mode ( TRUE;, FALSE; ) 

VARIABLE ams_mode0 {	def_ams_mode( mode0 ) }	/*  2211pH: Sensoface off   Nur wenn Sensocheck off und kein Sensoface :-< oder :-I */
VARIABLE ams_mode1 {	def_ams_mode( mode1 ) }	/*  2211pH: Sensoface :-)   Nur wenn Sensofcheck on und kein Sensoface :-< oder :-I */
VARIABLE ams_mode2 {	def_ams_mode( mode2 ) }	/*  2211pH: Sensoface :-I */
VARIABLE ams_mode3 {	def_ams_mode( mode3 ) }	/*  2211pH: Sensoface :-< */
VARIABLE ams_mode4 {	def_ams_mode( mode4 ) }	/* e2211pH: Sensoface off   Nur wenn Sensocheck off und kein Sensoface :-< oder :-I */
VARIABLE ams_mode5 {	def_ams_mode( mode5 ) }	/* e2211pH: Sensoface :-)   Nur wenn Sensofcheck on und kein Sensoface :-< oder :-I */
VARIABLE ams_mode6 {	def_ams_mode( mode6 ) }	/* e2211pH: Sensoface :-I */
VARIABLE ams_mode7 {	def_ams_mode( mode7 ) }	/* e2211pH: Sensoface :-< */

#endif


/*------------------------------------------------------------------------------------*/
/*  Abhngigkeiten der Gerte Variablen 											  */
/*------------------------------------------------------------------------------------*/


REFRESH rel_pv_unit
{
	sensor_units, main_unit: 
	primary_value, var_sample_cal, 
	sensor_upper_limit, sensor_lower_limit, sensor_minimum_span,
	output_current_urv ,output_current_lrv, analog_output_fixed1 
}

REFRESH rel_sv_unit
{
	selected_temp_unit, selected_temp_sensor:
	sv_temp_value, var_temp, var_slope, var_npkt
}

REFRESH rel_status
{
	function_check_status :
	def_config_variables
}






/*------------------------------------------------------------------------------------*/
/*	methods of value transmitter_variables 			   								  */
/* Warntext wird ausgegeben da die Wert sofort im Gert gendert werden, fr AMS	  */
/* notwendig und im HC275 sinnvoll, der Anwender muss nicht extra <send> drcken 	  */
/*------------------------------------------------------------------------------------*/

#define meth_sample_check_e2211 \
		if( !e2211_meth ){ \
			ACKNOWLEDGE( "Product calibration via HART not available for device software before V4.0. \n\n Press OK to finish" \
						 "|de|Produktkalibrierung ber HART-Kommunikation erst verfgbar ab Softwareversion 4.0. \n\n Drcken Sie OK zum Beenden"  );\
			process_abort(); \
		}

#define meth_head( _check_e ) \
		  		char	status [STATUS_SIZE]; \
				char  disp_string1 [60];    \
				int   slen1;					 \
				int	selc;						 \
				long	ids [2];					 \
				int 	sec;						 \
				slen1 = 60;						 \
				if( _check_e != 0 ){ meth_sample_check_e2211 } \
				get_dictionary_string (remove_loop_from_auto, disp_string1, slen1); \
				ACKNOWLEDGE (disp_string1); \
				add_abort_method (return_to_normal);

#define meth_definition_var( _transvar, _var, _label, _meth ) \
				{	meth_head( 0 ) \
					iassign( transmitter_variable_index, _transvar ); \
					send_trans( 128, 1, status ); \
					GET_DEV_VAR_VALUE ( _label, _var ); \
					IGNORE_ALL_RESPONSE_CODES (); \
					iassign( transmitter_variable_index, _transvar ); \
					send_trans( 129, 1, status ); \
					if (status [STATUS_RESPONSE_CODE]){ \
						display_response_status (132, status [STATUS_RESPONSE_CODE]); \
						ACKNOWLEDGE( "WARNING: Configuration was abborted!\n \nACTION: Repeat this step." \
						"|de|WARNUNG: Konfiguration wurde abgebrochen!\n Hinweis:Wiederholung dieses Schrittes!" ); \
					} \
					process_abort(); \
				}

/*------------------------------------------------------------------------------------*/


METHOD meth_sel_press_unit               
{
	LABEL       "Pressure" "|de|Druckeinheit";
	HELP        "Select the Pressure-Unit and enter the Pressure-value" 
				"|de|Auswahl der Druckeinheit und Eingabe des Druckes";
 	CLASS INPUT;
 	DEFINITION
 	{		
		char status[STATUS_SIZE];
		float fval;
		iassign ( selection_code_index, transvar_input ); 	    
		send_trans(128, 2, status); 
		
		GET_DEV_VAR_VALUE ("Select Press Unit:" "|de|Auswahl der Druckeinheit", selected_press_unit) ; 	/* Druckeinheit auswaehlen */
		IGNORE_ALL_RESPONSE_CODES () ;									

		iassign ( selection_code_index, transvar_input ); 	    
	    send_trans(129, 2, status);    										/* neue Druckeinheit senden */

		iassign ( transmitter_variable_index, transvar_press_meas ); 	    /* eingestellten druck auslesen und so umwandeln das er richtig angezeigt wird!! */    
		send_trans(128, 1, status); 

	    fval = fvar_value(var_press_meas); 	   
	   	   	
	   	 switch (int_value(selected_press_unit) ){									

			case 1: fval = fval * KPA_FKT;									
			break;														
			case 2: fval = fval * PSI_FKT;								    
			break;														
			default:;													
		} 

		assign_float(var_press_meas, fval);

				
		GET_DEV_VAR_VALUE ("Enter Pressure: " "|de| Druckeingabe", var_press_meas) ;
		
		IGNORE_ALL_RESPONSE_CODES () ;
	    
		fval = fvar_value(var_press_meas); 
	    
	    switch (int_value(selected_press_unit) ){									

			case 1: fval = fval / KPA_FKT;									
			break;														
			case 2: fval = fval / PSI_FKT;								    
			break;														
			default:;													
		} 

		assign_float(var_press_meas,fval);	  

		iassign ( transmitter_variable_index, transvar_press_meas ); 
		send_trans (129,1,status);	    				
	                                    

	

		process_abort();		/* this will call return_to_normal */
	   			
	}
}







//-----------------------------------------------------------------------------

METHOD loop_test
{
  LABEL	[loop_test];
  HELP	[loop_test_help];
  DEFINITION {
    char status[STATUS_SIZE];
    int choice;
    long var_id[1];
    int use_abort_method;
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;
    get_dictionary_string( remove_loop_from_auto, disp_string1, slen1 );
    ACKNOWLEDGE( disp_string1 );
    add_abort_method( return_to_normal );

    IGNORE_ALL_RESPONSE_CODES( );

    use_abort_method = 0;
    do {
      get_dictionary_string( choose_analog_output_level, disp_string1, slen1 );
      get_dictionary_string( choices_4_20_other_end, disp_string2, slen2 );
      choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
      switch( choice ) {
	case 0:		assign_float( primary_analog_current_value, 4.0 ); 
			break;
	case 1:		assign_float( primary_analog_current_value, 20.0 ); 
			break;
	case 2:		get_dictionary_string( loop_output, disp_string1, slen1 );
			GET_DEV_VAR_VALUE( disp_string1, primary_analog_current_value ); 
			break;
	case 3:
	default:	process_abort( );
			break;
      }
      send( 40, status );
      if( !use_abort_method ) {
	if( (status[STATUS_RESPONSE_CODE] != 0) && (status[STATUS_RESPONSE_CODE] != 3) && (status[STATUS_RESPONSE_CODE] != 4) ) {
	  display_response_status( 40, status[STATUS_RESPONSE_CODE] );
	  get_dictionary_string( abort_last_error, disp_string1, slen1 );
	  DELAY( 2, disp_string1 );
	  process_abort( );
	}
	remove_abort_method( return_to_normal );
	add_abort_method( leave_fixed_current_mode );
	use_abort_method = 1;
      }
      if( status[STATUS_RESPONSE_CODE] ) {
	display_response_status( 40, status[STATUS_RESPONSE_CODE] );
	if( (status[STATUS_RESPONSE_CODE] != 3) && (status[STATUS_RESPONSE_CODE] != 4) ) {
	  get_dictionary_string( abort_last_error, disp_string1, slen1 );
	  DELAY( 2, disp_string1 );
	  process_abort( );
	}
      }
      else {
	var_id[0] = VARID( primary_analog_current_value ); 
	get_dictionary_string( fld_dev_otpt_fixed, disp_string1, slen1 );
	acknowledge( disp_string1, var_id );
      }
    } while( choice < 3 );
    process_abort( );
  }
}

//-------------------------------------

METHOD leave_fixed_current_mode
{
  LABEL	[leaving_fixed_current_mode];
  HELP	[leaving_fixed_current_mode_help_2];
  DEFINITION {
    char status[STATUS_SIZE];
    long var_id[1];
    char disp_string1[60];
    int slen1;

    slen1 = 60;

    assign_float( primary_analog_current_value, 0.0 );  
    IGNORE_ALL_RESPONSE_CODES( ); 
    do {
      get_dictionary_string( return_fld_dev_to_orig_otpt, disp_string1, slen1 );
      DELAY( 3, disp_string1 );
      send( 40, status );
      if( status[STATUS_RESPONSE_CODE] ) {
	display_response_status( 40, status[STATUS_RESPONSE_CODE] );
      }
    } while( status[STATUS_RESPONSE_CODE] );
    get_dictionary_string( loop_may_be_returned_to_auto, disp_string1, slen1 );
    ACKNOWLEDGE( disp_string1 );
  }
}

//-----------------------------------------------------------------------------

METHOD self_test
{
  LABEL	[selftest];
  HELP	[selftest_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char status[3];
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;
		
    slen1 = 60;
    slen2 = 60;
		
    get_dictionary_string( selftest_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );
		
    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      add_abort_method( return_to_normal );
      IGNORE_ALL_RESPONSE_CODES( );
      send( 41, status );
      if( (status[STATUS_RESPONSE_CODE] > 1) || status[STATUS_COMM_STATUS] || status[STATUS_DEVICE_STATUS] ) {
	if( status[STATUS_RESPONSE_CODE] > 1 ) {
	  display_response_status( 41, status[STATUS_RESPONSE_CODE] );
	}
	if( status[STATUS_COMM_STATUS] > 1 ) { // COMM_STATUS > 1 damit nur eine Fehlermeldung bei Kommunikationsfehlern ausgegeben wird
	  display_comm_status( status[STATUS_COMM_STATUS] );
	}
	if( status[STATUS_DEVICE_STATUS] ) {
	  display_device_status( status[STATUS_DEVICE_STATUS] );
	}
	process_abort( );
      }
      else {
	get_dictionary_string( selftest_ok, disp_string1, slen1 );
	ACKNOWLEDGE( disp_string1 );
      }
    }
  }
}

//-----------------------------------------------------------------------------

METHOD master_reset
{
  LABEL	[master_reset];
  HELP	[master_reset_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char status[3];
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;

    get_dictionary_string( master_reset_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );

    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      add_abort_method( return_to_normal );
      IGNORE_ALL_RESPONSE_CODES( );
      send( 42, status );
      if( (status[STATUS_RESPONSE_CODE] > 1)|| status[STATUS_COMM_STATUS] || status[STATUS_DEVICE_STATUS] ) {
	if( status[STATUS_RESPONSE_CODE] > 1 ) {
	  display_response_status(41, status[STATUS_RESPONSE_CODE]);
	}
	if( status[STATUS_COMM_STATUS] ) {
	  display_comm_status(status[STATUS_COMM_STATUS]);
	}
	if( status[STATUS_DEVICE_STATUS] ) {
	  display_device_status(status[STATUS_DEVICE_STATUS]);
	}
	process_abort( );
      }
      else {
	get_dictionary_string( master_reset_ok, disp_string1, slen1 );
	ACKNOWLEDGE( disp_string1 );
      }
    }
  }
}

//-----------------------------------------------------------------------------

METHOD configuration_flag_reset
{
  LABEL	[configuration_flag_reset];
  HELP	[configuration_flag_reset_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;

    get_dictionary_string( configuration_flag_reset_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );

    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      send_command( 38 );
    }
  }
}

/*------------------------------------------------------------------------------------*/
/* e2211 Oxy	calibration methods													  */
/*------------------------------------------------------------------------------------*/
																										

#define 	text_sample_abort "WARNING: Product calibration was abborted!\n \nACTION: Repeat this step."
#define 	text_sample_ok 	  "Press OK finish"	

METHOD meth_take_sample_calibration
{
/* HC275:			"123456789012345678" */
	LABEL          "Take Sample" "|de|Produktkalibrierung - Probenentnahme";
	HELP           "Product Calibration Sequence Take Sample" "|de|Produktkalibrierung Schritt 1 Probenentnahme";
	DEFINITION {
		char   status[STATUS_SIZE] ;
		long   ids[4];
		float  fsens;

		ids[0] = VARID( primary_value ) ;
		ids[1] = VARID( main_unit ) ;
		ids[2] = VARID( var_temp ) ;
		ids[3] = VARID( sv_temp_units ) ;

		meth_sample_check_e2211
		/* e2211 */
		/*----------------*/  

			
			ACKNOWLEDGE("Take a sample from the process and store the currently measured value."
						"\n"
						"Note that the meassured value of the sample is temperature dependent."
						" \n" 
						"Therefore, laboratory measurement should be performed at the sample temperature shown in the display, if possible."
						"\n"
						"As far as possible, you should transport the sample in an insulated container (Dewar)."
						"\n"
						"The meassured value may also be altered due to escaping of volatile substances.\nPress OK to show measured value."

						"|de|Entnehmen Sie dem Proze eine Probe und messen Sie diese, z.B. im Labor."
						"\n"
						"Beachten Sie, da der entnomme Wert temperaturbhngig ist."
						"\n"
						"Die Messung im Labor sollte daher mglichst bei der im Display angezeigten Probentemperatur erfolgen."
						"\n"
						"Transportieren Sie die Probe mglichst in einem Isoliergef (Dewar)."
						"\n" 
						"Der gemessene Wert der Probe kann auch durch Entweichen flchtiger Substanzen verflscht werden."
						"\n"
						"Drcken Sie OK um den gemessenen Wert zu erhalten.");

		/*----------------*/
		send (48, status) ;
	   if( int_value(function_check_status) & 0x03 ){
		/*----------------*/

			ACKNOWLEDGE("WARNING: Device is in calibration or configuration, no sample calibration allowed!"
						"\n\n"
						"ACTION: Leave device calibration or configuration and repeat this step."
						"\n\n"
						"Press OK finish" 
						"|de| WARNUNG: Das Feldgert befindet sich innerhalb einer Kalibrierung oder Konfigurierung, keine Probenentnahme erlaubt!"
						"\n\n"
						"HINWEIS: Verlassen Sie die Kalibrierung oder Konfigurierung und wiederholen Sie diesen Schritt."
						"\n\n"
						"Drcken Sie OK zum Beenden.");


		/*----------------*/
		}else{
	   	if( (int_value(function_check_status) & 0x04) ){
		/*----------------*/

			ACKNOWLEDGE("WARNING: Sample was already taken. If you call <Take Sample> twice then the first sample will be lost!"
						" \n\n"
						"ACTION: Confirm discarding the first sample."
						"\n\n"
						"Press OK to discard the first sample"
						"|de|WARNUNG: Es wurde bereits eine Probe entnommen! Wenn Sie (Produktkalibrierung - Probenentnahme) doppelt drcken, wird der zuerst entnommene Probenwert verworfen!"
						"\n\n"
						"HINWEIS: Besttigen Sie, das der zuletzt entnomme Probenwert verworfen werden kann."
						"\n\n"
						"Drcken Sie OK um den zuletzt entnommen Probenwert zu verwerfen");

		/*----------------*/
			}
		/*----------------*/

		  display(	"Actual measureed value: %{0} %{1}   Temperature: %{2} %{3}" "|de|Aktueller Messwert: %{0} %{1}   Temperatur: %{2} %{3}",ids); 


				fsens = fvar_value (primary_value);
				assign_float (var_sample_cal, fsens); 
				iassign( transmitter_variable_index, transvar_sample_cal );
				send_trans (129, 1, status);


		/*----------------*/
			IGNORE_ALL_RESPONSE_CODES () ;
			send (131, status) ;
			if (status [STATUS_RESPONSE_CODE]){
				display_response_status (131, status [STATUS_RESPONSE_CODE]) ;
		/*----------------*/

				ACKNOWLEDGE("Press OK finish\n\n WARNING: Product calibration was abborted!"
							"\n\n"
							"ACTION: Repeat this step."
							"|de|Drcken Sie OK zum Beenden. WARNUNG: Produktkalibrierung wurde abgebrochen!"
							"\n\n"
							"HINWEIS:Wiederholen Sie diesen Schritt.");

		/*----------------*/
			}

 

		}
		process_abort();
	}
}

// --------------------------------------------------------------------------------------------------------------------------------
/*Produktkalibrierung Schritt 2
--------------------------------------------------------------------------------------------------------------------------------*/

METHOD meth_lab_sample_calibration
{
/* HC275:			"123456789012345678" */
	LABEL          "Input Lab Sample" "|de|Produktkalibrierung - Vergleichswerteingabe";
	HELP           "Product Calibration Sequence Input Lab Sample" "|de|Produktkalibrierung Schritt2 Vergleichswerteingabe";
	DEFINITION{
		char   status [STATUS_SIZE] ;
		float  fval, fnewval, fsens;

		long   ids[1];

		ids[0] = VARID( main_unit ) ;

		meth_sample_check_e2211


			ACKNOWLEDGE("Enter the measured lab value. The new zero point is automatically calculated and stored."
						"\n\n"
						"The values obtained by sample calibration are always accepted, even if they are outside calibration limits!"
						"\n\n"
						"Press OK to enter lab value"

						"|de| Geben Sie den gemessenen Wert der Probe ein. Der neue Meketten-Nullpunkt wird automatisch berechnet und gespeichert."
						"\n\n"
						"Die Werte bei der Probenkalibrierung werden immer bernommen, auch wenn sie auerhalb des Cal-Toleranzbandes liegen!"
						"\n\n"
						"Drcken Sie OK um den Vergleichswert einzugeben");

		/*----------------*/
		send (48, status) ;
	   if( int_value(function_check_status) & 0x03 ){
		/*----------------*/

			ACKNOWLEDGE( "WARNING: Device is in calibration or configuration, no sample calibration allowed"
						 "\n\n" 
						 "ACTION: Leave device calibration or configuration and repeat this step."
						 "\n\n"
						 "Press OK finish"
						
						"|de| WARNUNG: Das Feldgert befindet sich innerhalb einer Kalibrierung oder Konfigurierung, keine Probenentnahme erlaubt!"
						"\n\n"
						"HINWEIS: Verlassen Sie die Kalibrierung oder Konfigurierung und wiederholen Sie diesen Schritt"
						"\n\n"
						"Drcken Sie OK zum Beenden.");

		/*----------------*/
		}else{
	   	if( !(int_value(function_check_status) & 0x04) ){
		/*----------------*/
 

			ACKNOWLEDGE("WARNING: No sample was taken, no sample calibration allowed"
						"\n\n"
						"ACTION: First call <Take Sample> and then <Input Lab Sample>."
						"\n\n"
						"Press OK finish"
						
						"|de| WARNUNG: Es wurde keine Probe entnommen, Produktkalibrierung nicht zulssig!"
						"\n\n"
						"HINWEIS: Als Erstes mssen Sie <Produktkalibrierung - Probenentnahme> und dann <Produktkalibrierung - Vergleichswerteingabe> aufrufen."
						"\n\n"
						"Drcken Sie OK zum Beenden.");

		/*----------------*/
			}else{
				

				fval = fvar_value (primary_value);																																  								   
				
				get_local_var_value("Enter the comparison lab value (unit %{0}): ""|de|Eingabe des Vergleichwertes (in %{0}):",ids, fval);
		
				IGNORE_ALL_RESPONSE_CODES () ; 

				
				
  				switch (int_value(main_unit) ){

				 case 2: fval = fval * 1000.0;
						break;
				 default: ;
				}

				assign_float (var_sample_cal, fval);



				iassign( transmitter_variable_index, transvar_sample_cal );
				send_trans (129, 1, status);
				if (status [STATUS_RESPONSE_CODE]){
					display_response_status (129, status [STATUS_RESPONSE_CODE]) ;
		/*----------------*/

					ACKNOWLEDGE("WARNING: Product calibration was abborted!\n \nACTION: Repeat this step"
								"\n\n"
								"Press OK finish"

								"|de| WARNUNG: Produktkalibrierung wurde abgebrochen!\n\nHINWEIS:Wiederholen Sie diesen Schritt."
								"\n\n"
								"Drcken Sie OK zum Beenden.");

		/*----------------*/
				}
			}
		}
		process_abort();
	}
}