//----------------------------------------------------------
//	Copyright (C) Siemens AG (1998). All Rights Reserved
//	Product:      SIMATIC PDM
//
//	Device:			Mettler-Toledo O2 4100e/2(x)H
//	Description:	Device Description
//	Dictionary:		SIPADC01.dct, MT__STTA.dct
//	Copyright:		Mettler Toledo GmbH,
//						Process Analytics
//						P.O.Box
//						8902 Urdorf
//						Switzerland
//
//	Last edit:		23.03.2005
//----------------------------------------------------------

MANUFACTURER	142,	// Mettler
DEVICE_TYPE		123,	// pH 2100e / 2(X)H
DEVICE_REVISION 2,
DD_REVISION		1


#define PDM 


#ifdef PDM
#define AMS_PDM
#define PDM_bool true
#else
#define PDM_bool false
#endif

#include "SI_HlpM.inc"
#include "SIHASTIDENT01.inc"


#define STATUS_SIZE		3	  
#define STATUS_RESPONSE_CODE	0	 							   
#define STATUS_COMM_STATUS	1
#define STATUS_DEVICE_STATUS	2


#define UNIT_PH		[pH];
#define UNIT_MV		[mV];
#define UNIT_TEMP_C	"C";
#define UNIT_TEMP_F	"F";
#define UNIT_PERC		"%";
#define UNIT_MA		[mA];
#define UNIT_SEC		"s";
#define UNIT_HOURS	"h";
#define UNIT_TC		"%/K";
#define UNIT_NON		"";

#define UNITS_CODE_PH		59
#define UNITS_CODE_MV		36
#define UNITS_CODE_TEMP_C	32
#define UNITS_CODE_TEMP_F	33
#define UNITS_CODE_PERC		57
#define UNITS_CODE_MA		39
#define UNITS_CODE_SEC		51
#define UNITS_CODE_HOURS	52
#define UNITS_CODE_TC		243
#define UNITS_CODE_NON		251

#define USED_UNITS      UNITS_CODE_PH, UNITS_CODE_MV
#define TEMP_UNITS      UNITS_CODE (UNITS_CODE_TEMP_C), UNITS_CODE (UNITS_CODE_TEMP_F)

#define DISPLAY_PH		"5.2f";
#define DISPLAY_MV		"5.0f";
#define DISPLAY_TEMP_C	"5.1f";
#define DISPLAY_TEMP_F	"5.0f";
#define DISPLAY_CURR		"4.1f";
#define DISPLAY_PERC		"5.1f";
#define DISPLAY_SLOPE	"5.0f";
#define DISPLAY_SEC		"5.1f";
#define DISPLAY_TC		"5.2f";

#define MIN_PH		 			 0.0;
#define MAX_PH		 			14.0;
#define MIN_MV				-1500.0;
#define MAX_MV				 1500.0;

#define MIN_PH_e			   -2.0;
#define MAX_PH_e	 			16.0;
#define MIN_MV_e			-1999.0;
#define MAX_MV_e	 		 1999.0;


#define MIN_TEMPMAN_MEAS_C   -20.0;
#define MAX_TEMPMAN_MEAS_C	  150.0;
#define MIN_TEMPMAN_MEAS_F	   -4.0;
#define MAX_TEMPMAN_MEAS_F	  302.0;
#define MIN_TEMPMAN_CAL_C	    0.0;
#define MAX_TEMPMAN_CAL_C	  100.0;
#define MIN_TEMPMAN_CAL_F		32.0;
#define MAX_TEMPMAN_CAL_F	  212.0;

#define MIN_ASYM_POT_MV   	-60.0;
#define MAX_ASYM_POT_MV   	 60.0;

#define MIN_SLOPE				 85.0;
#define MAX_SLOPE				103.0;

/*------------------------------------------------------------------------------------*/ 

#define e2211_SW_rev			40
#define e2211					(software_revision >= e2211_SW_rev)
#define e2211_meth				(int_value( software_revision ) >= e2211_SW_rev)

#define x2211( _new, _old ) 	IF( e2211 ){ _new }ELSE{ _old }	

#define valid_2211				VALIDITY x2211( FALSE;, TRUE; ) 
#define valid_e2211				VALIDITY x2211( TRUE;, FALSE; )

#define e2211_ph ((software_revision >= e2211_SW_rev) && (selected_pv_unit == 0))
#define x2211_ph ( _new, _old) IF( e2211_ph ){ _new }ELSE{ _old }	
#define valid_e2211_ph VALIDITY x2211_ph( TRUE;, FALSE; )
/*------------------------------------------------------------------------------------*/



#define def_pv_unit_type \
	CONSTANT_UNIT   IF (sensor_units == UNITS_CODE_PH) { UNIT_PH }ELSE{ UNIT_MV } \
   TYPE FLOAT{     DISPLAY_FORMAT IF (sensor_units == UNITS_CODE_PH) { DISPLAY_PH }ELSE{ DISPLAY_MV } 

#define pv_unit_type def_pv_unit_type }

/*------------------------------------------------------------------------------------*/

#define output_current_unit_type_edit def_pv_unit_type \
		EDIT_FORMAT    IF (sensor_units == UNITS_CODE_PH){ DISPLAY_PH }ELSE{ DISPLAY_MV } \
		MIN_VALUE      IF (sensor_units == UNITS_CODE_PH){ x2211( MIN_PH_e, MIN_PH ) }ELSE{ x2211( MIN_MV_e, MIN_MV ) } \
		MAX_VALUE      IF (sensor_units == UNITS_CODE_PH){ x2211( MAX_PH_e, MAX_PH ) }ELSE{ x2211( MAX_MV_e, MAX_MV ) } }

/*------------------------------------------------------------------------------------*/

#define var_pH_unit_type \
	CONSTANT_UNIT   UNIT_PH \
	TYPE FLOAT{ \
		DISPLAY_FORMAT		DISPLAY_PH \
		EDIT_FORMAT       DISPLAY_PH \
		MIN_VALUE         x2211( MIN_PH_e, MIN_PH ) \
		MAX_VALUE         x2211( MAX_PH_e, MAX_PH )	}

/*------------------------------------------------------------------------------------*/

#define var_temp_unit_type \
	CONSTANT_UNIT IF (sv_temp_units == UNITS_CODE_TEMP_C){ UNIT_TEMP_C }ELSE{ UNIT_TEMP_F } \
	TYPE FLOAT { \
		DISPLAY_FORMAT IF (sv_temp_units == UNITS_CODE_TEMP_C) { DISPLAY_TEMP_C } ELSE { DISPLAY_TEMP_F } }

/*------------------------------------------------------------------------------------*/

#define var_temp_meas_unit_type_edit \
	CONSTANT_UNIT     IF (selected_temp_mode_C){ UNIT_TEMP_C }ELSE{ UNIT_TEMP_F } \
	TYPE FLOAT { \
		DISPLAY_FORMAT IF (selected_temp_mode_C){ DISPLAY_TEMP_C }ELSE{ DISPLAY_TEMP_F } \
		EDIT_FORMAT    IF (selected_temp_mode_C){ DISPLAY_TEMP_C }ELSE{ DISPLAY_TEMP_F } \
		MIN_VALUE      IF (selected_temp_mode_C){ MIN_TEMPMAN_MEAS_C }ELSE{ MIN_TEMPMAN_MEAS_F } \
		MAX_VALUE      IF (selected_temp_mode_C){ MAX_TEMPMAN_MEAS_C }ELSE{ MAX_TEMPMAN_MEAS_F } }

/*------------------------------------------------------------------------------------*/

#define var_temp_cal_unit_type_edit \
	CONSTANT_UNIT     IF (selected_temp_mode_C){ UNIT_TEMP_C }ELSE{ UNIT_TEMP_F } \
	TYPE FLOAT { \
		DISPLAY_FORMAT IF (selected_temp_mode_C){ DISPLAY_TEMP_C }ELSE{ DISPLAY_TEMP_F } \
		EDIT_FORMAT    IF (selected_temp_mode_C){ DISPLAY_TEMP_C }ELSE{ DISPLAY_TEMP_F } \
		MIN_VALUE      IF (selected_temp_mode_C){ MIN_TEMPMAN_CAL_C }ELSE{ MIN_TEMPMAN_CAL_F } \
		MAX_VALUE      IF (selected_temp_mode_C){ MAX_TEMPMAN_CAL_C }ELSE{ MAX_TEMPMAN_CAL_F } }
		
/*------------------------------------------------------------------------------------*/

#define selected_pv_unit_enum 	TYPE ENUMERATED{ { 0, [pH] }, { 1, [mV] } }
#define selected_pv_unit_meth 	"pH;mV" 

/*------------------------------------------------------------------------------------*/
/* 2211pH + e2211pH 																  */
/*------------------------------------------------------------------------------------*/

#define selected_temp_mode_C \
			 ((!e2211 && (selected_temp_mode   == 0 || selected_temp_mode   == 2 || selected_temp_mode   == 4 || selected_temp_mode   == 6)) || \
			  ( e2211 && (selected_temp_mode_e == 0 || selected_temp_mode_e == 2 || selected_temp_mode_e == 4 || selected_temp_mode_e == 6)))


#define sel_tm0	  "Auto C" 
#define sel_tm1   "Auto F"		
#define sel_tm2   "Man C"
#define sel_tm3   "Man F"
#define sel_tm4   "Auto C / Cal Man"
#define sel_tm5   "Auto F / Cal Man"   	
#define sel_tm6_e "Man C / Cal Auto"
#define sel_tm7_e "Man F / Cal Auto"

/*------------------------------------------------------------------------------------*/
/* 2211pH 																			  */
/*------------------------------------------------------------------------------------*/

#define selected_temp_mode_enum		TYPE ENUMERATED{ { 0, sel_tm0 }, { 1, sel_tm1 }, { 2, sel_tm2 }, { 3, sel_tm3 }, { 4, sel_tm4 }, { 5, sel_tm5 } }   	
#define selected_temp_mode_meth		sel_tm0 ";" sel_tm1 ";" sel_tm2 ";" sel_tm3 ";" sel_tm4 ";" sel_tm5

/*------------------------------------------------------------------------------------*/
/* e2211pH 																			  */
/*------------------------------------------------------------------------------------*/
#define selected_temp_mode_e_enum	TYPE ENUMERATED{ { 0, sel_tm0 }, { 1, sel_tm1 }, { 2, sel_tm2 }, { 3, sel_tm3 }, { 4, sel_tm4 }, { 5, sel_tm5 }, { 6, sel_tm6_e }, { 7, sel_tm7_e } }   	
#define selected_temp_mode_e_meth	sel_tm0 ";" sel_tm1 ";" sel_tm2 ";" sel_tm3 ";" sel_tm4 ";" sel_tm5 ";" sel_tm6_e ";" sel_tm7_e

/*------------------------------------------------------------------------------------*/


#define sel_bs1  	"01: Mettler Toledo"
#define sel_bs2  	"02: Merck/Riedel"
#define sel_bs3  	"03: Ciba 1994"
#define sel_bs4  	"04: Mett.Tol.(USA)"
#define sel_bs4_e 	"04: NIST technical"
#define sel_bs5  	"05: NIST standard"
#define sel_bs6  	"06: HACH"
#define sel_bs7_e 	"07: WTW technical"
#define sel_bs10 	"Manual Calibration"
#define sel_bs11 	"Data Entry"

/*------------------------------------------------------------------------------------*/
/* 2211pH 																			  */
/*------------------------------------------------------------------------------------*/

#define selected_bufferset_enum 		TYPE ENUMERATED{  { 1, sel_bs1 }, { 2, sel_bs2 }, { 3, sel_bs3 }, { 4, sel_bs4 }, { 5, sel_bs5 }, { 6, sel_bs6 }, {10, sel_bs10 }, {11, sel_bs11 } }
#define selected_bufferset_meth 		sel_bs1 ";" sel_bs2 ";" sel_bs3 ";" sel_bs4 ";" sel_bs5 ";" sel_bs6 ";;;;" sel_bs10  ";" sel_bs11 

/*------------------------------------------------------------------------------------*/
/* e2211pH 																			  */
/*------------------------------------------------------------------------------------*/

#define selected_bufferset_e_enum 	TYPE ENUMERATED{ { 1, sel_bs1 }, { 2, sel_bs2 }, { 3, sel_bs3 }, { 4, sel_bs4_e }, { 5, sel_bs5 }, { 6, sel_bs6 }, { 7, sel_bs7_e }, {10, sel_bs10 }, {11, sel_bs11 } }
#define selected_bufferset_e_meth   sel_bs1 ";" sel_bs2 ";" sel_bs3 ";" sel_bs4_e ";" sel_bs5 ";" sel_bs6 ";" sel_bs7_e ";;;" sel_bs10  ";" sel_bs11 

/*------------------------------------------------------------------------------------*/

#define sel_ts0	"Pt 100"
#define sel_ts1	"Pt 1000"
#define sel_ts2	"NTC 30k"
#define sel_ts3	"NTC 8.55k"
#define selected_temp_sensor_enum 	TYPE ENUMERATED { { 0, sel_ts0 }, { 1, sel_ts1 }, { 2, sel_ts2 }, { 3, sel_ts3 } }
#define selected_temp_sensor_meth	sel_ts0 ";" sel_ts1 ";" sel_ts2 ";" sel_ts3

/*------------------------------------------------------------------------------------*/

#define sel_oo0	"Off" "|de|Aus" 
#define sel_oo1	"On " "|de|Ein" 
#define selected_off_on_enum 			TYPE ENUMERATED{ { 0, sel_oo0 }, { 1, sel_oo1 } }                 
#define selected_off_on_meth			sel_oo0 ";" sel_oo1

/*------------------------------------------------------------------------------------*/

#define sel_hl0	"Last Value" "|de|Letzter Wert"
#define sel_hl1	"Fixed Current" "|de|Festwert"
#define selected_hold_last_fix_enum	TYPE ENUMERATED{ { 0, sel_hl0 }, { 1, sel_hl1 } }
#define selected_hold_last_fix_meth	sel_hl0 ";" sel_hl1

/*------------------------------------------------------------------------------------*/

#define sel_el0	"Glas el."
#define sel_el1	"FET el."
#define selected_eltype_enum			TYPE ENUMERATED{ { 0, sel_el0 }, { 1, sel_el1 } }                
#define selected_eltype_meth			sel_el0 ";" sel_el1

/*------------------------------------------------------------------------------------*/
/* Transmittervariablen 															  */
/*------------------------------------------------------------------------------------*/

#define transvar_ph				0
#define transvar_orp		   	1
#define transvar_temp   		2
#define transvar_curr			8
#define transvar_perc			9
#define transvar_input 			10
#define transvar_temp_meas		11
#define transvar_curr_lrv		12
#define transvar_curr_urv		13
#define transvar_cal		   	14
#define transvar_asym_pot		15
#define transvar_slope			16
#define transvar_cal_timer		17
#define transvar_buffer_1		18
#define transvar_buffer_2		19
#define transvar_output			20
#define transvar_fix_value		21
#define transvar_temp_cal		22
#define transvar_sample_cal	    30
#define transvar_filter_1		31
#define transvar_alarmdelay_1	32
#define transvar_conf_4			33
#define transvar_TClin			34


//=============================================================================
//  VARIABLEN
//=============================================================================

VARIABLE response_code		// Standard-Variable
{
  LABEL	[response_code];
  HELP	[command_specific_response_code_help];
  CLASS USER_INTERFACE & DIAGNOSTIC;
  HANDLING READ;
  TYPE ENUMERATED {
    {  0, [success] },
    {  1, [undefined] },
    {  2, [invalid_selection] },
    {  3, [passed_parameter_too_large] },
    {  4, [passed_parameter_too_small] },
    {  5, [too_few_data_bytes_recieved] },
    {  6, [xmtr_specific_command_error] },
    {  7, [in_write_protect_mode] },
    {  8, [xmtr_specific_command_error] },
    {  9, [xmtr_specific_command_error] },
    { 10, [xmtr_specific_command_error] },
    { 11, "Invalid Transmitter Variable" },
    { 12, "Invalid Unit Code" },
    { 13, [xmtr_specific_command_error] },
    { 14, [xmtr_specific_command_error] },
    { 15, [xmtr_specific_command_error] },
    { 16, [access_restricted] },
    { 32, [busy] },
    { 64, [command_not_implemented] }
  }
}

//-------------------------------------

VARIABLE device_status		// Standard-Variable
{
  LABEL	[device_status] ;
  HELP	[field_device_status_help];
  CLASS HART & DYNAMIC & DIAGNOSTIC;
  HANDLING READ;
  TYPE BIT_ENUMERATED {
    { 0x00, [no_error], MISC },
    { 0x01, "Primary variable outside limits"	"|de|Hauptvariable auerhalb Bereich", DV1 (AUTO & BAD) },
    { 0x02, "Temperature outside limits"	"|de|Nebenvariable auerhalb Bereich", DV2 (AUTO & BAD) },
    { 0x04, "Output outside operating range"	"|de|Ausgang auerhalb Mebereich",    AO1 (AUTO & BAD) },
    { 0x08, "Output in fixed mode"		"|de|Ausgang ist auf Festwert",	       AO1 (MANUAL & GOOD) },
    { 0x10, "More Status available"		"|de|Gert hat mehr Informationen",    MORE },
    { 0x20, "Device cold start"			"|de|Feldgert Kaltstart",	       MISC },
    { 0x40, "Configuration has been changed"	"|de|Konfiguration wurde verndert",   MISC & IGNORE_IN_HANDHELD },
    { 0x80, "Device malfunction or failure"	"|de|Gertefehler oder Ausfall",      MORE}
  }
}


VARIABLE xmtr_specific_status_0 
{
	LABEL	"Error Status""|de|Fehlerzustnde" ;
	HELP   	"Field Device Error Status- Failure messages of the Field Device are listed" "|de|Feldgertfehlermeldungen";
    STYLE "MULTILINE 12 4";	 
	 TYPE		BIT_ENUMERATED {

			{ 0x01, "Err 01 pH Value" "|de|Err 01 Mebereich pH", DV1 (AUTO & BAD) } ,
			{ 0x02, "Err 02 mV Value" "|de|Err 02 Mebereich mV", DV1 (AUTO & BAD) } ,
			{ 0x04, "Err 03 Temp Value" "|de|Err 03 Temperaturfhler", TV1 (AUTO & BAD) } ,
			{ 0x08, "Err 11 Loop < 3.8mA" "|de|Err 11 Stromausgang < 3,8 mA", AO1 (AUTO & BAD) } ,
			{ 0x10, "Err 12 Loop >20.5mA" "|de|Err 12 Stromausgang > 20.5 mA", AO1 (AUTO & BAD) } ,
			{ 0x20, "Err 13 Loop Span" "|de|Err 13 Stromspanne zu klein / zu gro", DATA } ,
			{ 0x40, "Err 98 Config Data" "|de|Err 98 Systemfehler", HARDWARE } ,
			{ 0x80, "Err 99 Data Lost" "|de|Err 99 Abgleichdaten defekt", HARDWARE }	}
}

VARIABLE xmtr_specific_status_1 
{
	 LABEL	"Smiley Earnest" "|de|Smiley ernst" ;
	 HELP	"Smiley Earnest - Maintance required. Sensoface provides information on wear and required maintance. However, device continues operation with diminished accuracy." 
	        "|de|Smiley ernst - Wartung erforderlich! Sensoface gibt Hinweise zum Zustand Ihrer Mekette.";
	 STYLE "MULTILINE 12 3";
	 TYPE		BIT_ENUMERATED {

			{ 0x01, "Electrode adjusts slowly. Clean electrode, soak it in buffer for hours"
					"|de|Elektrode sollte neu justiert werden. Subern Sie Elektrode, trnken Sie sie einige Stunden lang in einer Pufferlsung", PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x02, "Over 80% of the calibration interval has already past" "|de|ber 80% des Kalbriertimerintervals abgelaufen", PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x10, "Zero point or slope are still okay, however cleaning is recommended" 
					"|de|Nullpunkt und Steilheit der Elektrode sind noch in Ordnung. Ein Austausch sollte jedoch bald erfolgen", PROCESS & IGNORE_IN_HANDHELD }
		 }
}


VARIABLE xmtr_specific_status_2 {
	LABEL 	"Smiley Sad""|de|Smiley traurig" ;
	HELP  	"Smiley Sad - Correct measurment is no longer ensured. Sensoface provides information on wear and required maintance. However, device continues operation with seriously diminished accuracy."
			"|de| Smiley traurig - Eine korrekte Messung wird nicht mehr gewhrleistet!  Sensoface gibt Hinweise zum Zustand Ihrer Mekette.";
    STYLE "MULTILINE 12 3";
	TYPE  	BIT_ENUMERATED {

			{ 0x01, "Electrode adjusts slowly. Correct measurement is no longer ensured. Replace electrode." 
					"|de|Elektrode mu neu justiert werden. Eine korrekte Messung wird nicht mehr sichergestellt. Ersetzen Sie Elektrode." , PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x02, "Calibration interval has been exceeded" "|de|Kalibriertimerinterval abgelaufen", PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x04, "Err 33 Glass electrode" "|de|Err 33 Glaselektrode", PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x08, "Err 34 Ref electrode" "|de|Err 34 Bezugselektrode", PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x10, "Zero point or slope have values which do not ensure proper calibration. Clean or replace electrode."
					"|de|Nullpunkt oder Steilheit besitzen Werte die eine korrekte Kalibrierung nicht mehr gewhrleisten. Suberen oder ersetzen Sie die Elektrode.", PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x20, "Zero point outside transmitter limit -60...+60mV" "|de|Nullpunkt auerhalb des Limits (-60 .. +60mV)", PROCESS & IGNORE_IN_HANDHELD } ,
			{ 0x40, "Slope outside transmitter limit 80...103%" "|de|Steilheit auerhalb des Limits (80 .. 103%)", PROCESS & IGNORE_IN_HANDHELD }
		 }
		}


VARIABLE analog_output_saturated1 {
 	 TYPE  BIT_ENUMERATED {
			{ 0x01, "Analog Out Saturated" "|de|Analoge Ausgang befindet sich in Sttigung", AO1 (AUTO & BAD) }
	 }
}



VARIABLE analog_output_fixed1 {
	LABEL "HOLD Mode" "|de|Hold Modus" ;
	HELP  "Analog Outputs of the Field Device are fixed in HOLD mode. The analog and digital Outputs remain unchanged." 
		  "|de|Der Analoge Ausgang des Feldgertes befindet sich im HOLD-Modus." ;
	TYPE  BIT_ENUMERATED{
						{ 0x01, "HOLD Mode" "|de|HOLD-Modus", AO1 (MANUAL & GOOD) }
	}
}

//-------------------------------------

VARIABLE tag
{
  LABEL	[tag];
  HELP	[tag_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(8); 
  HANDLING READ & WRITE;
}

//-------------------------------------

VARIABLE descriptor
{
  LABEL	[descriptor];
  HELP	[discriptor_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(16); 
  HANDLING READ & WRITE;
}

//-------------------------------------

VARIABLE message
{
  LABEL	[message];
  HELP	[message_help];
  CLASS DEVICE;
  TYPE PACKED_ASCII(32);
  HANDLING READ & WRITE;
}

//-------------------------------------


VARIABLE manufacturer_id
{
  LABEL	[manufacturer_id];
  HELP	[manufacturer_id_code_help];
  HANDLING READ;
  CLASS HART;
  TYPE ENUMERATED {
    DEFAULT_VALUE 142;
    { 142,  "Mettler Toledo" }
  }
}

//-------------------------------------

VARIABLE universal_revision
{
  LABEL	[universal_revision];
  HELP	[universal_revision_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
}

//-------------------------------------

VARIABLE transmitter_revision
{
  LABEL	[transmitter_revision];
  HELP	[field_device_revision_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
}

//-------------------------------------

VARIABLE software_revision
{
  LABEL	[software_revision];
  HELP	[field_device_software_revision_help];
  HANDLING READ;
  CLASS DEVICE;
  DEFAULT_VALUE 41;
  TYPE UNSIGNED_INTEGER { MAX_VALUE 253; }
}

//-------------------------------------

VARIABLE hardware_revision
{
  LABEL	[hardware_revision];
  HELP	[hardware_revision_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER;
}

//-------------------------------------

VARIABLE device_id
{
  LABEL	[device_identification];
  HELP	[field_device_identification_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER(3);
}

//-------------------------------------

VARIABLE device_type 
{
  LABEL	[device_type];
  HELP	[manufacturers_device_type_help];
  HANDLING READ;
  CLASS HART; 
  TYPE ENUMERATED(1) {
    IF( manufacturer_id == 142 ) {	// Mettler Toledo Device Types
      { 123, "pH 2100e/2(X)H" }
    }
    { 252, [unknown] }
  }
}

//-------------------------------------

VARIABLE request_preambles
{
  LABEL	[number_of_request_preambles];
  HELP	[number_of_request_preambles_help];
  HANDLING READ;
  CLASS HART; 
  TYPE UNSIGNED_INTEGER {
    INITIAL_VALUE 5;
    DEFAULT_VALUE 5;
    MIN_VALUE  2;
    MAX_VALUE 20;
  }
}

//-------------------------------------

VARIABLE response_preambles
{
  LABEL	[number_of_response_preambles];
  HELP	[number_of_response_preambles_help];
  HANDLING WRITE;
  CLASS HART;
  TYPE UNSIGNED_INTEGER	{
    INITIAL_VALUE 5;
    DEFAULT_VALUE 5;
  }
}

//-------------------------------------

VARIABLE device_flags
{
  LABEL	[device_flags];
  HELP	[field_device_flags_help];
  HANDLING READ;
  CLASS HART; 
  TYPE BIT_ENUMERATED {
    { 0x01, [Multisens_Dev], [multi_sensor_fld_dev] },
    { 0x02, [EEPROM_Ctrl] },
    { 0x04, [protocol_bridge_device] }
  }
}

//-------------------------------------

VARIABLE physical_signaling_code
{															  
  LABEL	[physical_signalling_code];
  HELP	[physical_signalling_code_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    { 0, [bell_202_current] },
    { 1, [bell_202_voltage] },
    { 2, [rs_485] },
    { 3, [rs_232], [rs_232_help] },
    { 6, [special] }
  }
}

//-------------------------------------

VARIABLE final_assembly_number
{
  LABEL	[final_assembly_number];
  HELP	[final_assembly_number_help];
  HANDLING READ & WRITE;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER(3) {
    MAX_VALUE 16777215;
  }
}

//-------------------------------------

VARIABLE date
{
  LABEL	[date];
  HELP	[date_help];
  HANDLING READ & WRITE;
  CLASS DEVICE;
  TYPE DATE;
}

//-------------------------------------

VARIABLE write_protect
{
  LABEL	[write_protect];
  HELP	[write_protect_mode_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    {   0, [not_write_protected] },
    {   1, [write_protected] },
    { 250, [not_used] },
    { 251, [none] },
    { 252, [unknown] },
    { 253, [special] }
  }
}

//-------------------------------------

VARIABLE private_label_distributor
{
  LABEL	[private_label_distributor];
  HELP	[private_label_distributor_help];
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED {
    { 142, "Mettler Toledo"}
  }
}

//-------------------------------------

VARIABLE primary_damping_value
{
  LABEL	[damping_value];
  HELP	[seconds_damping_value_help]; 
  CLASS CORRECTION;
  TYPE FLOAT {
    DISPLAY_FORMAT	".2f";
  }
  CONSTANT_UNIT	[sec];
  HANDLING READ & WRITE;
}

//-------------------------------------

VARIABLE primary_analog_current_value
{   
  LABEL	[analog_value_block_1];
  HELP	[analog_value_help];    
  CLASS	CONTAINED & DYNAMIC;
  HANDLING READ;  
  CONSTANT_UNIT	[mA]; 
  TYPE FLOAT {
    DISPLAY_FORMAT	".3f";
  }
}

//-------------------------------------

VARIABLE dummy_status
{	LABEL		"dummy" ;
	HELP		" " ;
	HANDLING READ ;
	TYPE		BIT_ENUMERATED {
     /* HC275:"1234567890123456" */
		{ 0x01, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x02, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x04, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x08, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x10, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x20, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x40, " ", MISC & IGNORE_IN_HANDHELD } ,
		{ 0x80, " ", MISC & IGNORE_IN_HANDHELD }
	}
}

//-------------------------------------

VARIABLE function_check_status {
	CLASS    DEVICE & DYNAMIC;
	LABEL		"Device Status" "|de|Gertestatus" ;
	HELP		"Device status and mode" "|de|Gertestatus und Zustnde";
	STYLE "MULTILINE 12 3";
	HANDLING READ ;
	TYPE		BIT_ENUMERATED {
     /* HC275:"1234567890123456" */
		{ 0x01, "Configuration" "|de|Konfiguration", MODE & IGNORE_IN_HANDHELD } ,
		{ 0x02, "Calibration" "|de|Kalibrierung", MODE & IGNORE_IN_HANDHELD } ,
		{ 0x04, "Sample was taken" "|de|Produktkalbrierung gestartet", MISC & IGNORE_IN_HANDHELD }
	}
	valid_e2211
}

/*------------------------------------------------------------------------------------*/
/*		definition of collection for dynamic variables								  */
/*------------------------------------------------------------------------------------*/

COLLECTION OF VARIABLE pv {
	LABEL           [pv] ;
	HELP            [primary_variable_help] ;
	MEMBERS         {
			 /*             Sensor Correction Information                          			  */
			 DIGITAL_UNITS,         sensor_units,           [units],                        [digital_units_help] ;
			 DIGITAL_VALUE,         sensor_value,           [blank],                        [digital_value_help] ;
			 SENSOR_UNITS,          sensor_units,           [sensor_unit],                  [digital_units_help] ;

			 UPPER_SENSOR_LIMIT,    sensor_upper_limit,     [usl],                          [upper_sensor_limit_help] ;
			 LOWER_SENSOR_LIMIT,    sensor_lower_limit,     [lsl],                          [lower_sensor_limit_help] ;
			 MINIMUM_SPAN,          sensor_minimum_span,    [minimum_span],                 [minimum_span_help] ;
			 
			 /*             Analog Output Information                                       */
			 ANALOG_VALUE,          mA_output_current,      [analog_output_value],          [analog_value_help] ;
			 ALARM_CODE,            analog_alarm_code,      [alarm_select],                 [alarm_code_help] ;
			 
			 /*             Input Information                                               */
			 PERCENT_RANGE,         percent_of_range,       [percent_of_range_help] ;
			 TRANSFER_FUNCTION,     xmtr_transfer_function, [transfer_function_help] ;
			 RANGE_UNITS,           sensor_units,           [range_units_help] ;

			 UPPER_RANGE_VALUE,     output_current_urv,[urv],[upper_range_value_help] ;
			 LOWER_RANGE_VALUE,     output_current_lrv,[lrv],[lower_range_value_help] ;
			 SENSOR_SERIAL_NUMBER,  sensor_serial_number,   [sensor_serial_number],         [sensor_serial_number_help] ;
			 DAMPING_VALUE,         sensor_damping_value,   [damping_value],                [seconds_damping_value_help] ;
			}
}


/* 2211pH */
#define def_config_variables \
      selected_pv_unit, \
      output_current_lrv, \
      output_current_urv, \
      selected_22mA, \
  	  selected_hold_fix, \
      var_fix_value, \
      selected_temp_mode, \
      selected_temp_sensor, \
      var_temp_meas, \
      var_temp_cal, \
      selected_bufferset, \
      var_cal_timer, \
      var_buffer_1, \
      var_buffer_2, \
      selected_senso_check, \
      var_asym_pot, \
      var_slope

/* e2211pH */
#define def_config_variables_e \
      selected_pv_unit, \
      selected_eltype, \
      output_current_lrv, \
      output_current_urv, \
      var_filter_1, \
      selected_22mA, \
      selected_hold_fix, \
      var_fix_value, \
      selected_temp_mode_e, \
      selected_temp_sensor, \
      var_temp_meas, \
      var_temp_cal, \
      selected_bufferset_e, \
      var_cal_timer, \
      var_buffer_1, \
      var_buffer_2, \
      selected_senso_check, \
      var_alarmdelay_1, \
      selected_holdLED, \
      var_asym_pot, \
      var_slope

//-------------------------------------


MENU upload_variables
{
	LABEL "Upload Variables";
	/* read & write variables 2211pH 
	e2211pH spezifische Variablen gehen nicht da ITEM-liste nicht umschaltbar ist und der Validitystatus der Variablen nicht bercksichtigt wird */
	ITEMS {
      polling_address,
      tag,
      descriptor,
      message,
      date,
      final_assembly_number,
      response_preambles,

		IF(software_revision >= e2211_SW_rev ){
	
		 	IF (selected_pv_unit_local == 0){    	  
			  def_config_variables_e 	
		}ELSE{
				def_config_variables_e,
				var_TClin
			}
		}ELSE{    	  
			def_config_variables
		}
	}
}

//-------------------------------------

MENU download_variables		// Lesen aus Feldgert
{
  LABEL	[menu_load_to_PC];
  ITEMS {
    tag,		//--- Standard-HART-Parameter ---
    descriptor,
    message,
    manufacturer_id,
    universal_revision,
    transmitter_revision,
    software_revision,
    hardware_revision,
    device_id,
    device_type,
    device_flags,
    physical_signaling_code,
    final_assembly_number,
    date,
			//--- Transmitter-Specific Variables ---

	main_unit,
	sensor_value,
	output_current_lrv,
	output_current_urv,

	IF(software_revision >= e2211_SW_rev ){
	
	 	IF (selected_pv_unit_local == 0){    	  
		  	def_config_variables_e 	
		}ELSE{
			def_config_variables_e,
			var_TClin
		}
	}ELSE{    	  
		  def_config_variables 	
	}
  }

  PRE_READ_ACTIONS{
		pre_load	
  }
}



METHOD pre_load
{
	LABEL "Pre-Read for Up/Download Menu";
	DEFINITION
	{

		send_command( 15 );

		 if (sensor_units == UNITS_CODE_PH){
			assign_int (selected_pv_unit_local , 1);
		 }else{
		 	assign_int (selected_pv_unit_local , 0);		
		 }

	}
}



VARIABLE selected_pv_unit_local                                                                
{
	CLASS 			LOCAL;
	HANDLING        READ & WRITE;
	TYPE			INTEGER;

}


/*------------------------------------------------------------------------------------*/
/* Hilfsvariablen zum fllen von Lcken, Inhalt wird verworfen						  */
/*------------------------------------------------------------------------------------*/

VARIABLE dummy1
{
  CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
  LABEL	"Dummy1Byte";
  HANDLING READ & WRITE;
  TYPE UNSIGNED_INTEGER(1);
}

VARIABLE dummy4
{
  CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
  LABEL	"Dummy4Byte";
  HANDLING READ & WRITE;
  TYPE UNSIGNED_INTEGER(4);
}


/*------------------------------------------------------------------------------------*/
/*      transmitter-specific commands #128, #129                                      */
/*------------------------------------------------------------------------------------*/

#define send_trans_read( _status, _transvar ) \
				if( e2211_meth ){ \
					iassign( selection_code_index_e, _transvar ); \
					send_trans( 128, 3, _status ); \
				}else{ \
					iassign( selection_code_index, _transvar ); \
					send_trans( 128, 2, _status ); \
				}

#define send_trans_write( _status, _transvar ) \
				if( e2211_meth ){ \
					iassign( selection_code_index_e, _transvar ); \
					send_trans( 129, 3, _status ); \
				}else{ \
					iassign( selection_code_index, _transvar ); \
					send_trans( 129, 2, _status ); \
				}

/*-------------------------------------------*/

REFRESH rel_pv_unit
{
	sensor_units, selected_pv_unit :
	sensor_value, 	var_ph, var_orp, var_sample_cal,
	sensor_upper_limit, sensor_lower_limit, sensor_minimum_span,
	output_current_lrv, output_current_urv, analog_output_fixed1 
}

/*-------------------------------------------*/

REFRESH rel_sv_unit
{
	selected_temp_mode, selected_temp_mode_e :
	sv_temp_value, sv_upper_limit, sv_lower_limit,
	var_temp, var_temp_meas, var_temp_cal
}

/*-------------------------------------------*/

REFRESH rel_status
{
	function_check_status :
	def_config_variables_e
}


/*------------------------------------------------------------------------------------*/
/* Hilfsvariablen um zusammengesetzte Transmitter Variablen zu definieren			  */
/*------------------------------------------------------------------------------------*/

#define def_selection_code_index( _sel ) \
  LABEL	"Sel. Code Index"; \
  HELP	""; \
  TYPE INDEX _sel; \
  CLASS USER_INTERFACE; \
  HANDLING READ & WRITE; 

VARIABLE selection_code_index  { def_selection_code_index( selection_codes   ) }
VARIABLE selection_code_index_e{ def_selection_code_index( selection_codes_e ) }

/*-------------------------------------------*/

#define def_selection_codes_tab( _sel, _cal_sel ) \
  LABEL	"Sel. Codes"; \
  HELP	""; \
  ELEMENTS { \
    transvar_input,  	_sel, ""; \
    transvar_cal,			_cal_sel, ""; \
    transvar_output, 	output1_selection_code, "";

#define def_selection_codes( _sel, _cal_sel ) \
			def_selection_codes_tab( _sel, _cal_sel ) }

#define def_selection_codes_e( _sel, _cal_sel ) \
			def_selection_codes_tab( _sel, _cal_sel ) \
		   transvar_conf_4, 	conf_4_selection_code, ""; } 

ARRAY OF COLLECTION selection_codes  { def_selection_codes  ( input1_selection_code,   cal_selection_code ) }
ARRAY OF COLLECTION selection_codes_e{ def_selection_codes_e( input1_selection_code_e, cal_selection_code_e ) }

/*------------------------------------------------------------------------------------*/

/*------------------------------------------------------------------------------------*/
/*--------------------------------------------------*/
/* V10 - 10.0 Primary variable						*/
/*		 10.1 Temperature							*/
/*		 10.2 Temperature Sensor Type				*/
/*       10.3 Undefinded							*/
/*--------------------------------------------------*/

COLLECTION OF VARIABLE input1_selection_code
{
  LABEL "Input Sel. Code";
  MEMBERS {
    BYTE1,	selected_pv_unit ;
    BYTE2,	selected_temp_mode ;
    BYTE3,	selected_temp_sensor ;
    BYTE4,	dummy1 ;
  }
}


COLLECTION OF VARIABLE input1_selection_code_e
{
  LABEL "Input Sel. Code";
  MEMBERS {
    BYTE1,	selected_pv_unit ;
    BYTE2,	selected_temp_mode_e ;
    BYTE3,	selected_temp_sensor ;
    BYTE4,	dummy1 ;
  }
}

/*--------------------------------------------------*/
/* V10.0 Primary value								*/
/*--------------------------------------------------*/

VARIABLE selected_pv_unit							
{
	CLASS           INPUT;
	LABEL           "PV Unit" "|de|PV Unit";
	HELP			"Select the PV Unit" "|de|Whlen Sie die PV Einheit";
	HANDLING        READ & WRITE ;
	selected_pv_unit_enum

	POST_READ_ACTIONS{
		method_set_unit
	}

	POST_EDIT_ACTIONS{
		method_set_unit
	}
	POST_WRITE_ACTIONS{
		method_set_unit
	}
}



METHOD method_set_unit
{
  CLASS	INPUT;
  DEFINITION
  {
		if (selected_pv_unit == 0){
			assign_int( sensor_units,59 );
			assign_int( selected_pv_unit_local, 1);
		}
		if (selected_pv_unit == 1){
			assign_int( sensor_units,36 );
			assign_int( selected_pv_unit_local, 0);
		}
   
  } 
}

/*--------------------------------------------------*/
/* V10.1 Temperature								*/
/*--------------------------------------------------*/

VARIABLE selected_temp_mode							
{
	CLASS           INPUT;
	LABEL           "Temp. Detection" "|de|Temperaturerfassung";
	HELP			"Select the temperature detection" "|de|Whlen Sie die Temperaturerfassung";
	HANDLING        READ & WRITE ;
	selected_temp_mode_enum

	valid_2211
}


VARIABLE selected_temp_mode_cal
{
	CLASS           INPUT;
	LABEL           "Temp. Detection" "|de|Temperaturerfassung";
	HELP			"Select the temperature detection" "|de|Whlen Sie die Temperaturerfassung";
	HANDLING        READ ;

	CONSTANT_UNIT  IF (selected_temp_mode   == 0 || selected_temp_mode   == 2 || selected_temp_mode   == 4 || selected_temp_mode   == 6){
    
	  UNIT_TEMP_C
  }ELSE{  
	UNIT_TEMP_F
  }


}

/*--------------------------------------------------*/
/* e2211 V10.1 Temperature							*/
/*--------------------------------------------------*/

VARIABLE selected_temp_mode_e						
{
	CLASS           INPUT;
	LABEL           "Temp. Detection" "|de|Temperaturerfassung";
	HELP			"Select the temperature detection" "|de|Whlen Sie die Temperaturerfassung";
	HANDLING        READ & WRITE ;
	selected_temp_mode_e_enum
	valid_e2211
}

/*--------------------------------------------------*/
/* V10.2 Primary value								*/
/*--------------------------------------------------*/

VARIABLE selected_temp_sensor						
{
	CLASS           INPUT;
	LABEL           "Temp. Probe" "|de|Temperaturfhler";
	HELP			"Select the temperature probe type" "|de|Whlen Sie den Temperaturfhler";
	HANDLING        READ & WRITE ;
	selected_temp_sensor_enum 
}

/*------------------------------------------------------------------------------------*/
/*--------------------------------------------------*/
/* V14 - 14.0 Bufferset, Manual or Data Entry		*/
/*		 14.1 Sensocheck							*/
/*		 14.2 Undefinded							*/
/*       14.3 Undefinded							*/
/*--------------------------------------------------*/

COLLECTION OF VARIABLE cal_selection_code
{
  LABEL "Calib. Sel. Code";
  MEMBERS {
    BYTE1,	selected_bufferset ;
    BYTE2,	selected_senso_check ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

COLLECTION OF VARIABLE cal_selection_code_e
{
  LABEL "Calib. Sel. Code";
  MEMBERS {
    BYTE1,	selected_bufferset_e ;
    BYTE2,	selected_senso_check ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*--------------------------------------------------*/
/* V14.0 Bufferset, Manual or Data Entry			*/
/*--------------------------------------------------*/

VARIABLE selected_bufferset					        
{
	CLASS           CORRECTION;
	LABEL           "Buffer Set" "|de|Puffersatz";
	HELP			"Select buffer set for automatic calibration with Calimatic or manual calibration or direct data entry"
					"|de|Stellen Sie die Puffer fr automatische Kalibrierung mit Calimatic oder manueller Kalibrierungs- oder direkter Dateneingabe ein";
	HANDLING        READ & WRITE ;
	selected_bufferset_enum
	valid_2211
}

/*--------------------------------------------------*/
/* 2211e V14.0 Bufferset, Manual or Data Entry		*/
/*--------------------------------------------------*/

VARIABLE selected_bufferset_e						
{
	CLASS           CORRECTION;
	LABEL           "Buffer Set" "|de|Puffersatz";
	HELP			"Select buffer set for automatic calibration with Calimatic or manual calibration or direct data entry"
					"|de|Stellen Sie die Puffer fr automatische Kalibrierung mit Calimatic oder manueller Kalibrierungs- oder direkter Dateneingabe ein";
	HANDLING        READ & WRITE ;
	selected_bufferset_e_enum
	valid_e2211
}

/*--------------------------------------------------*/
/* V14.1 Sensocheck									*/
/*--------------------------------------------------*/

VARIABLE selected_senso_check						
{
	CLASS           CORRECTION;
	LABEL           "Sensocheck" "|de|Sensocheck";
	HELP			"Sensocheck continously monitors the glass and reference electrode"	
					"|de|Sensocheck berwacht kontinuierlich die Glas- und die Bezugselektrode";
	HANDLING        READ & WRITE ;
	selected_off_on_enum 
}

/*------------------------------------------------------------------------------------*/
/*--------------------------------------------------*/
/* V20 - V20.0 22mA on Error						*/
/*       V20.1 HOLD Last/Fix						*/
/*		 V20.2 Undefined							*/
/*		 V20.3 Undefined							*/
/*--------------------------------------------------*/

COLLECTION OF VARIABLE output1_selection_code
{
  LABEL "Output Sel. Code";
  MEMBERS {
    BYTE1,	selected_22mA ;
    BYTE2,	selected_hold_fix ;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*--------------------------------------------------*/
/* V20.0 22mA on Error								*/
/*--------------------------------------------------*/

VARIABLE selected_22mA								
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "22mA on Error" "|de|22mA bei Fehlermeldungen";
	HELP			"Switch 22mA signal for error message on or off" "|de|Schalten Sie das Signal 22mA fr Fehlermeldung an oder aus";
	HANDLING        READ & WRITE ;
	selected_off_on_enum 
}

/*--------------------------------------------------*/
/* V20.1 HOLD Last/Fix								*/
/*--------------------------------------------------*/

VARIABLE selected_hold_fix							
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "HOLD Last/Fix" "|de|HOLD Letzter-/Festwert";
	HELP			"The output current behavior in the HOLD mode can be specified. Last- The output current is frozen at its last value, Fix- A constant value from 3.8mA to 22mA"
					"|de|Der Ausgangsstrom kann im HOLD-Zustand wie folgt eingestellt werden: Last- letzter Ausgangsstromwert, Fix- Vorgabe des Ausgangsstroms";
	HANDLING        READ & WRITE ;
	selected_hold_last_fix_enum
}

/*------------------------------------------------------------------------------------*/
/*--------------------------------------------------*/
/* V33 - V33.0 ALARM LED Mode   					*/
/*       V33.1 Electrode Type						*/
/*		 V33.2 Undefined							*/
/*		 V33.3 Undefined							*/
/*--------------------------------------------------*/


COLLECTION OF VARIABLE conf_4_selection_code
{
  LABEL "Conf.4 Sel. Code";
  MEMBERS {
    BYTE1,	selected_holdLED;
    BYTE2,	selected_eltype;
    BYTE3,	dummy1 ;
    BYTE4,	dummy1 ;
  }
}

/*--------------------------------------------------*/
/* e2211 V33.0 Alarm LED Mode						*/
/*--------------------------------------------------*/

VARIABLE selected_holdLED						  	
{
	CLASS           x2211( DEVICE;, LOCAL; )
	LABEL           "Alarm LED Hold" "|de|Alarm HOLD LED";
	HELP			"LED state in HOLD Mode: if setting ON - Alarm on and Hold flashes- else setting OFF - Alarm flashes and Hold on -" 
					"|de|LED im Hold Zustand: Parametrierung ON - Alarm an und HOLD blinkt - Parametrierung OFF - Alarm blinkt HOLD an -";
	HANDLING        READ & WRITE ;
	selected_off_on_enum
	
	VALIDITY x2211( true;, false; )
}

/*--------------------------------------------------*/
/* e2211 V33.1 Electrode Type (only at pH)			*/
/*--------------------------------------------------*/

VARIABLE selected_eltype						  	
{
	CLASS           x2211( INPUT;, LOCAL; )
	LABEL           "Glas/FET el." "|de|Glas/FET el.";
	HELP			"Select Glas or ISFET electrode type" "|de|Whlen Sie Glas oder ISFET Elektrode";
	HANDLING        READ & WRITE ;
	selected_eltype_enum
	valid_e2211
}


/*------------------------------------------------------------------------------------*/
/*	Hilfsvariable fr transmitter-specific commands									  */
/*------------------------------------------------------------------------------------*/

VARIABLE transmitter_variable_unit_code
{
	CLASS           LOCAL;
	LABEL           "" ;
	HANDLING        READ ;
	TYPE            INTEGER (1) ;
}


/*----------------------------------------------------*/
/* e2211pH 														   */

VARIABLE sensor_units
{
	CLASS           INPUT;
	LABEL           "PV Unit" ;
	HELP            [digital_units_help] ;
	HANDLING        READ & WRITE ;
	TYPE            ENUMERATED{ USED_UNITS }
	DEFAULT_VALUE   59;
}

/*-------------------------------------------*/

VARIABLE sensor_value
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           [pv] ;
	HELP            [digital_value_help] ;
	HANDLING        READ ;
	pv_unit_type
}

/*-------------------------------------------*/

VARIABLE sensor_upper_limit
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "PV USL" ;
	HELP            [upper_sensor_limit_help];
	HANDLING        READ;
	pv_unit_type
}

/*-------------------------------------------*/

VARIABLE sensor_lower_limit
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "PV LSL" ;
	HELP            [lower_sensor_limit_help] ;
	HANDLING        READ ;
	pv_unit_type
}

/*-------------------------------------------*/

VARIABLE sensor_minimum_span
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "Min. Span" ;
	HELP            [minimum_span_help] ;
	HANDLING        READ ;
	pv_unit_type
}

/*-------------------------------------------*/

VARIABLE sensor_damping_value
{
	CLASS           INPUT;
	LABEL           [pv_damping_value] ;
	HELP            [seconds_damping_value_help] ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   [sec] ;
	TYPE            INTEGER (4) ;
}

/*-------------------------------------------*/

VARIABLE analog_alarm_code
{
	CLASS           ANALOG_OUTPUT ;
	LABEL           [alarm_select] ;
	HELP            [alarm_code_help] ;
	HANDLING        READ ;
	TYPE            ENUMERATED{
		ALARM_SELECTION_CODE(0) ,
		ALARM_SELECTION_CODE(1) ,
		ALARM_SELECTION_CODE(239) ,
		ALARM_SELECTION_CODE(250) ,
		ALARM_SELECTION_CODE(251) ,
		ALARM_SELECTION_CODE(252) ,
		ALARM_SELECTION_CODE(253)
	}
}

/*-------------------------------------------*/

VARIABLE xmtr_transfer_function
{
	CLASS           CORRECTION;
	LABEL           [transfer_function] ;
	HELP            "You can choose the kind of dependence of the current from the digital value";
	HANDLING        READ & WRITE ;
	TYPE            ENUMERATED{
		TRANSFER_FUNCTION_CODE (0),            /* Linear 			*/
		TRANSFER_FUNCTION_CODE (1)             /* Square Root 	*/
	}
}

/*-------------------------------------------*/

VARIABLE sensor_serial_number
{
	CLASS           DEVICE;
	LABEL           "Number   " ;
	HELP            [sensor_serial_number_help] ;
	HANDLING        READ & WRITE ;
	TYPE            UNSIGNED_INTEGER (3) ;
}

/*----------------------------------------------*/
/*	secondary variable for universal command #3 */
/*----------------------------------------------*/

VARIABLE sv_temp_value
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "SV" ;
	HELP			"Temperature for pH value temperature compensation" "|de|Temperatur" ;
	HANDLING        READ ;
	var_temp_unit_type
}

/*-------------------------------------------*/

VARIABLE sv_temp_units
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "The specified temperature unit" "|de|Temperatureinheit" ;
	HELP            [digital_units_help] ;
	HANDLING        READ ;
	TYPE ENUMERATED {
    { 32, [degC],    [degrees_celsius_help] },
    { 33, [degF],    [degrees_fahrenheit_help] }
  }
}

/*-------------------------------------------*/

VARIABLE sv_upper_limit
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "SV USV" ;
	HELP            [upper_range_value_help] ;
	HANDLING        READ;
	var_temp_unit_type
}

/*-------------------------------------------*/

VARIABLE sv_lower_limit
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "SV LSV";
	HELP            [lower_range_value_help];
	HANDLING        READ;
	var_temp_unit_type
}

/*------------------------------------------------------------------------------------*/
/*      definitions of transmitter_variables										  */
/*------------------------------------------------------------------------------------*/

VARIABLE transmitter_variable_index
{
	CLASS           USER_INTERFACE ;
	LABEL           [blank] ;
	TYPE            INDEX transmitter_variable_array ;
}

/*-------------------------------------------*/

ARRAY OF VARIABLE transmitter_variable_array
{
	ELEMENTS{
			 transvar_ph, 				var_ph ;
			 transvar_orp, 				var_orp ;
			 transvar_temp, 			var_temp ;
			 transvar_curr, 			mA_output_current ;
			 transvar_perc, 			percent_of_range ;
			 transvar_temp_meas, 		var_temp_meas ;
			 transvar_curr_lrv, 		output_current_lrv ;
			 transvar_curr_urv, 		output_current_urv ;
			 transvar_asym_pot, 		var_asym_pot ;
			 transvar_slope, 			var_slope ;
			 transvar_cal_timer, 		var_cal_timer;
			 transvar_buffer_1, 		var_buffer_1;
			 transvar_buffer_2, 		var_buffer_2;
			 transvar_fix_value, 		var_fix_value ;
			 transvar_temp_cal, 		var_temp_cal ;
			 transvar_sample_cal,		var_sample_cal ;
			 transvar_filter_1, 		var_filter_1 ;
			 transvar_alarmdelay_1,		var_alarmdelay_1 ;
			 transvar_TClin,			var_TClin ;
			}
}



/*----------------------------------------------------*/
/* V0 pH value										  */
/*----------------------------------------------------*/

VARIABLE var_ph									
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "pH" ;
	HELP			"pH value depends from input mV and temperature calculated by slope and asymmetry potential correction"
					"|de|pH-Wert hngt vom Eingang mV und von der Temperatur ab. Er wird durch Steilheit - und Asymmetriepotentialkorrektur errechnet";
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_PH
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_PH }
}

/*----------------------------------------------------*/
/* V1 mV Value										  */
/*----------------------------------------------------*/

VARIABLE var_orp									
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "ORP" ;
	HELP			"mV value depends on chemical interaction" "|de|mV Wert hngt von der chemischen Interaktion ab" ;
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_MV
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_MV }
}

/*----------------------------------------------------*/
/* V2 Temperautre value						  		  */
/*----------------------------------------------------*/

VARIABLE var_temp									
{
	CLASS           INPUT & DYNAMIC ;
	LABEL           "Temperature" "|de|Temperatur" ;
	HELP			"Temperature for pH value temperature compensation" "|de|Temperatur fr pH-Wert (Temperaturkompensiert)" ;
	HANDLING        READ ;
	var_temp_unit_type
}

/*----------------------------------------------------*/
/* V8 mA output current								  */
/*----------------------------------------------------*/

VARIABLE mA_output_current						
{
	CLASS           ANALOG_OUTPUT & DYNAMIC ;
	LABEL           "PV AO" ;
	HELP				 [analog_value_help] ;
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MA
	TYPE            FLOAT{	
		DISPLAY_FORMAT	DISPLAY_CURR	
		EDIT_FORMAT		DISPLAY_CURR 
	}
}

/*----------------------------------------------------*/
/* V9 Percent value of output current		    	  */
/*----------------------------------------------------*/

VARIABLE percent_of_range						
{
	CLASS           ANALOG_OUTPUT & DYNAMIC ;
	LABEL           "PV %" ;
	HELP            [percent_of_range_help] ;
	HANDLING        READ ;
	CONSTANT_UNIT   UNIT_PERC
	TYPE            FLOAT{ DISPLAY_FORMAT DISPLAY_PERC }
}

/*----------------------------------------------------*/
/* V11 manuell meas temperature 			  		  */
/*----------------------------------------------------*/
VARIABLE var_temp_meas							
{
	CLASS           INPUT;
	LABEL           "Man. Meas. Temp." "|de|Manuelle Metemperatur";
	HELP			"Specify the manual measuring temperature used when the temperature compensation is set to <man>" 
					"|de|Manuelle Metemperatur, wenn bei der Auswahl der Temperaturerfassung beim Messen man gesetzt wurde";
	HANDLING        READ & WRITE ;
	DEFAULT_VALUE	25.0;
	var_temp_meas_unit_type_edit
}

/*----------------------------------------------------*/
/* V12 Output current - lower range value (4 mA)      */
/*----------------------------------------------------*/

VARIABLE output_current_lrv				  	
{
	CLASS           ANALOG_OUTPUT;
	LABEL           [pv_lrv] ;
	HELP			[lower_range_value_help] ;
	HANDLING        READ & WRITE ;
	DEFAULT_VALUE   0;
	output_current_unit_type_edit
	
}

/*----------------------------------------------------*/
/* V13 Output current - upper range value (20mA)      */
/*----------------------------------------------------*/

VARIABLE output_current_urv				  	
{
	CLASS           ANALOG_OUTPUT;
	LABEL           [pv_urv] ;
	HELP				 [upper_range_value_help] ;
	HANDLING        READ & WRITE ;
	DEFAULT_VALUE   14;
	output_current_unit_type_edit
}

/*----------------------------------------------------*/
/* V15 Electrode symmetrie potential				  */
/*----------------------------------------------------*/

VARIABLE var_asym_pot							
{
	CLASS           CORRECTION;
	LABEL           "Asym." "|de|Asymetriepotential" ;
	HELP				 "The calibration generates the electrode parameters. You can also directly enter the asymmetry potential of an electrode" 
						 "|de|Durch eine Kalibrierung werden die Parameter der Elektrode bestimmt. Hier ist eine direkte Eingabe des Asymetriepotentials der Elektrode mglich";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   [mV] ;
	TYPE            FLOAT{	
		DISPLAY_FORMAT        DISPLAY_MV
		EDIT_FORMAT           DISPLAY_MV
		MIN_VALUE             MIN_ASYM_POT_MV 
		MAX_VALUE             MAX_ASYM_POT_MV 
		DEFAULT_VALUE		  0;
	}
}

/*----------------------------------------------------*/
/* V16 Electrode slope								  */
/*----------------------------------------------------*/

VARIABLE var_slope							
{
	CLASS           CORRECTION;
	LABEL           "Slope" "|de|Steilheit" ;
	HELP		    "The calibration generates the electrode parameters. You can also directly enter the slope of an electrode" 
                    "|de|Durch eine Kalibrierung werden die Parameter der Elektrode bestimmr. Hier ist eine direkte Eingabe der Steilheit der Elektrode mglich.";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_PERC
	TYPE            FLOAT{
		DISPLAY_FORMAT        DISPLAY_SLOPE
		EDIT_FORMAT           DISPLAY_SLOPE
		MIN_VALUE             MIN_SLOPE	
		MAX_VALUE             MAX_SLOPE	
		DEFAULT_VALUE		  90.0;
	}
}

/*----------------------------------------------------*/
/* V17 Calibration timer                              */
/*----------------------------------------------------*/

VARIABLE var_cal_timer							
{
	CLASS           CORRECTION;
	LABEL           "Cal.Timer" ;
	HELP		    "Calibration timer interval. 0 = cal timer disabled" 
					"|de|Kalibriertimerinterval. 0 = Kalibriertimer ausgeschaltet";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_HOURS
	TYPE            FLOAT{	
		DISPLAY_FORMAT         "04.0f";
		EDIT_FORMAT            "4.0f";
		MIN_VALUE              0.0 ;
		MAX_VALUE              9999.0 ;
		DEFAULT_VALUE		   0.0;
	}
}

/*----------------------------------------------------*/
/* V19 Manual buffer value1 (man cal only)			  */
/*----------------------------------------------------*/

VARIABLE var_buffer_1							
{
	CLASS           CORRECTION;
	LABEL           "Buffer 1" "|de|Pufferlsung 1" ;
	HELP            "Set the pH value of your buffer solution for the proper temperature for the calibration step 1"
					"|de|Stellen Sie den pH-Wert Ihrer Pufferlsung, fr die korrekte Temperatur fr den Kalibrierung Schritt 1 ein"  ;
	HANDLING        READ & WRITE ;
	var_pH_unit_type
	DEFAULT_VALUE	7.00;
}

/*----------------------------------------------------*/
/* V19 Manual buffer value2 (man cal only)			  */
/*----------------------------------------------------*/

VARIABLE var_buffer_2							
{
	CLASS           CORRECTION;
	LABEL           "Buffer 2" "|de|Pufferlsung 2" ;
	HELP            "Set the pH value of your buffer solution for the proper temperature for the calibration step 2" 
					"|de|Stellen Sie den pH-Wert Ihrer Pufferlsung, fr die korrekte Temperatur fr den Kalibrierung Schritt 2 ein";
	HANDLING        READ & WRITE ;
	var_pH_unit_type
	DEFAULT_VALUE	4.01;
}

/*----------------------------------------------------*/
/* V21 HOLD-Fix value								  */
/*----------------------------------------------------*/

VARIABLE var_fix_value							
{
	CLASS           ANALOG_OUTPUT;
	LABEL           "HOLD Fix Value" "|de|Fix Wert Eingabe";
	HELP			"Specify fixed output current in HOLD mode" "|de|Festwert fr Ausgangsstrom im HOLD-Zustand";
	HANDLING        READ & WRITE ;
	CONSTANT_UNIT   UNIT_MA
	TYPE            FLOAT{	
		DISPLAY_FORMAT       DISPLAY_CURR
		EDIT_FORMAT          DISPLAY_CURR
		MIN_VALUE            3.8 ;
		MAX_VALUE            22.0 ;
		DEFAULT_VALUE		 21.0 ;
	}
}

/*----------------------------------------------------*/
/* V22 Manual Cal. Temperature						  */
/*----------------------------------------------------*/

VARIABLE var_temp_cal							
{
	CLASS           CORRECTION;
	LABEL           "Man. Calib. Temp." "|de|Manuelle Kalibriertemperatur";
	HELP			"Specify the manual calibration temperature used when the temperature compensation is set to <cal man>" 
					"|de|Manuelle Kalibriertemperatur, wenn bei der Auswahl der Temperaturerfassung beim Kalibrieren man gesetzt wurde" ;
	HANDLING        READ & WRITE ;
	DEFAULT_VALUE	25.0;
	var_temp_cal_unit_type_edit
}

/*----------------------------------------------------*/
/* e2211pH V30 Product calibration (step2)		      */
/*----------------------------------------------------*/

VARIABLE var_sample_cal							
{
	/* var_sample_cal darf nicht in die upload_variables Liste */
	CLASS           x2211( CORRECTION;, LOCAL; )
	LABEL           "Sample" ;
	HELP		    "Calibration with Sampling to determine the electrode zero point" ;
	HANDLING        READ & WRITE ;
	var_pH_unit_type
	valid_e2211
}

/*----------------------------------------------------*/
/* e2211pH V31 Time constant of output filter         */
/*----------------------------------------------------*/

VARIABLE var_filter_1							
{
	CLASS           x2211( ANALOG_OUTPUT;, LOCAL; )
	LABEL           "Output Filter" "|de|Ausgangsfilter";
	HELP			"Time constant of output current Filter" "|de|Filterzeit des Ausgangs";
	HANDLING        READ & WRITE ;
	DEFAULT_VALUE	0.0;
	CONSTANT_UNIT   UNIT_SEC
	TYPE            FLOAT{	
		DISPLAY_FORMAT         DISPLAY_SEC
		EDIT_FORMAT            DISPLAY_SEC
		MIN_VALUE              0.0;
		MAX_VALUE              120.0;
	}
	valid_e2211
}

/*----------------------------------------------------*/
/* e2211pH V32 Alarm delay              		      */
/*----------------------------------------------------*/

VARIABLE var_alarmdelay_1							
{
	CLASS           x2211( ANALOG_OUTPUT;, LOCAL; )
	LABEL           "Alarm Delay" "|de|Alarmzeitverzgerung";
	HELP			"Alarm delay time of alarm signal" "|de|Alarmzeitverzgerung fr das Alarmsymbol";
	HANDLING        READ & WRITE ;
	DEFAULT_VALUE	10.0;
	CONSTANT_UNIT   UNIT_SEC
	TYPE            FLOAT{	
		DISPLAY_FORMAT         DISPLAY_SEC
		EDIT_FORMAT            DISPLAY_SEC
		MIN_VALUE              0.0;
		MAX_VALUE              600.0;
	}
	valid_e2211
}

/*----------------------------------------------------*/
/* e2211pH V34 TC process medium only at pH           */
/*----------------------------------------------------*/

VARIABLE var_TClin									
{
	CLASS           x2211( CORRECTION;, LOCAL; )
	LABEL           "TC lin" "|de|TK Memedium";
	HELP			"TC lin Temperature correction value" "|de|Temperaturkompensation des Memediums (nur bei pH gltig)";
	HANDLING        READ & WRITE ;
	DEFAULT_VALUE	0.0;
	CONSTANT_UNIT   UNIT_TC
	TYPE            FLOAT{	
		DISPLAY_FORMAT         DISPLAY_TC
		EDIT_FORMAT            DISPLAY_TC
		MIN_VALUE              -19.99;
		MAX_VALUE              19.99;
	}
	valid_e2211_ph
}


//=============================================================================
//  COMMANDS
//=============================================================================

COMMAND read_unique_identifier
{
  NUMBER 0;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      254,
      manufacturer_id,
      device_type,
      request_preambles,
      universal_revision,
      transmitter_revision,
      software_revision,
      hardware_revision <0xf8>,
      physical_signaling_code <0x07>,
      device_flags,
      device_id
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_primary_variable
{
  NUMBER 1;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      sensor_units,
      sensor_value //sensor_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_current_and_percent_range
{
  NUMBER 2;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      mA_output_current,
      percent_of_range
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_dynamic_variables_and_pv_current
{
  NUMBER 3;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      mA_output_current,
      sensor_units,
      sensor_value, 
      sv_temp_units,
      sv_temp_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND write_polling_address
{
  NUMBER 6;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      polling_address
    }
    REPLY {
      response_code,
      device_status,
      polling_address
    }
  }
  RESPONSE_CODES {
     0,	SUCCESS, [no_command_specific_errors];
     2,	DATA_ENTRY_ERROR, [invalid_selection];
     5,	MISC_ERROR, [too_few_data_bytes_recieved];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND read_unique_identifier_with_tag
{
  NUMBER 11;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST {
      tag
    }
    REPLY {
      response_code,
      device_status,
      254,
      manufacturer_id,
      device_type,
      request_preambles,
      universal_revision,
      transmitter_revision,
      software_revision,
      hardware_revision <0xf8>,
      physical_signaling_code <0x07>,
      device_flags,
      device_id 
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_message
{
  NUMBER 12;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      message
    }
  }
  RESPONSE_CODES {
    0, SUCCESS,	[no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_tag_descriptor_date
{
  NUMBER 13;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      tag,
      descriptor,
      date
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_sensor_info
{
  NUMBER 14;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      sensor_serial_number,
      sensor_units,
      sensor_upper_limit,
      sensor_lower_limit,
      sensor_minimum_span
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_pv_output_info
{
  NUMBER 15;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      analog_alarm_code,
      xmtr_transfer_function,
      sensor_units,
      output_current_urv,
      output_current_lrv,
      primary_damping_value,
      write_protect,
      private_label_distributor
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND read_final_assembly_number
{
  NUMBER 16;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
      final_assembly_number
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND write_message
{
  NUMBER 17;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      message
    }
    REPLY {
      response_code,
      device_status,
      message
    }
  }
  RESPONSE_CODES {
     0,	SUCCESS,    [no_command_specific_errors];
     5,	MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_tag_descriptor_date
{
  NUMBER 18;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      tag,
      descriptor,
      date
    }
    REPLY {
      response_code,
      device_status,
      tag,
      descriptor,
      date
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_final_assembly_number
{
  NUMBER 19;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      final_assembly_number
    }
    REPLY {
      response_code,
      device_status,
      final_assembly_number
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_pv_range_values
{
  NUMBER 35;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      sensor_units,
      output_current_urv,
      output_current_lrv
    }
    REPLY {
      response_code,
      device_status,
      sensor_units,
      output_current_urv,
      output_current_lrv
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
     2, DATA_ENTRY_ERROR, [invalid_selection];
     5, MISC_ERROR, [too_few_data_bytes_recieved];
     9, DATA_ENTRY_ERROR, [lower_range_value_too_high];
    10, DATA_ENTRY_ERROR, [lower_range_value_too_low];
    11, DATA_ENTRY_ERROR, [upper_range_value_too_high];
    12, DATA_ENTRY_ERROR, [upper_range_value_too_low];
    13, DATA_ENTRY_ERROR, [URV_and_LRV_out_of_limits];
    14, DATA_ENTRY_WARNING, [span_too_small];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND set_pv_upper_range_value
{
  NUMBER 36;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND set_pv_lower_range_value
{
  NUMBER 37;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND reset_configuration_change_flag
{
  NUMBER 38;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND enter_exit_fixed_pv_current_mode
{
  NUMBER 40;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST {
      primary_analog_current_value
    }
    REPLY {
      response_code,
      device_status,
      primary_analog_current_value
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
    4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND perform_transmitter_self_test
{
  NUMBER 41;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}

//-------------------------------------

COMMAND perform_master_reset
{
  NUMBER 42;
  OPERATION COMMAND;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status
    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors];
    32, DATA_ENTRY_ERROR, [busy];
  }
}

//-------------------------------------

COMMAND read_additional_transmitter_status
{
  NUMBER 48;
  OPERATION READ;
  TRANSACTION {
    REQUEST { }
    REPLY {
      response_code,
      device_status,
  	  xmtr_specific_status_0 ,		/*  0  */
	  xmtr_specific_status_1 ,		/*  1  */
	  xmtr_specific_status_2 ,		/*  2  */		  	
	  dummy_status ,				/*  3 undefined */
	  dummy_status ,				/*  4 undefined */
	  dummy_status ,     			/*  5 undefined */
	  dummy_status ,				/*  6  */
	  dummy_status ,				/*  7  */
	  analog_output_saturated1 ,  	/*  8  */
	  dummy_status ,			  	/*  9 undefined */
	  dummy_status ,			  	/* 10 undefined */
	  analog_output_fixed1,			/* 11  */
	  dummy_status ,				/* 12 undefined */
	  dummy_status ,				/* 13 undefined */
	  dummy_status ,				/* 14 undefined */
	  dummy_status ,				/* 15 undefined */
	  dummy_status ,				/* 16 undefined */
	  dummy_status ,				/* 17 undefined */
	  dummy_status ,				/* 18 undefined */
	  dummy_status ,				/* 19 undefined */
	  dummy_status ,				/* 20 undefined */
	  dummy_status ,				/* 21 undefined */
	  dummy_status ,				/* 22 undefined */
	  dummy_status ,				/* 23 undefined */
	  function_check_status	}		/* 24  */    
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
  }
}



//-------------------------------------

COMMAND read_transmitter_variable_information
{
  NUMBER 54;
  OPERATION READ;
  TRANSACTION {
    REQUEST {
      transmitter_variable_index( INFO, INDEX )
    }
    REPLY {
      response_code,
      device_status,
      transmitter_variable_index,
      transmitter_variables[transmitter_variable_index].SENSOR_SERIAL_NUMBER,
      transmitter_variables[transmitter_variable_index].SENSOR_UNITS,
      transmitter_variables[transmitter_variable_index].UPPER_SENSOR_LIMIT,
      transmitter_variables[transmitter_variable_index].LOWER_SENSOR_LIMIT,
      transmitter_variables[transmitter_variable_index].DAMPING_VALUE,
      transmitter_variables[transmitter_variable_index].MINIMUM_SPAN
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, MISC_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_number_of_response_preambles
{
  NUMBER 59;
  OPERATION WRITE;
  TRANSACTION {
    REQUEST {
      response_preambles
    }
    REPLY {
      response_code,
      device_status,
      response_preambles
    }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
    4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-----------------------------------------------------------------------------

COMMAND read_float_variable
{
  NUMBER 128;
  OPERATION READ;
  TRANSACTION {
    REQUEST {
      transmitter_variable_index (INFO, INDEX)
    }
    REPLY {
      response_code,
      device_status,
	  transmitter_variable_index,
	  transmitter_variable_unit_code,
	  transmitter_variable_array [transmitter_variable_index]
 }
  }
  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, DATA_ENTRY_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-----------------------------------------------------------------------------

COMMAND read_selections
{
  NUMBER 128;
  OPERATION READ;
  TRANSACTION 1 {
		REQUEST { transmitter_variable_index (INFO,INDEX) }
	 	REPLY {	
	 		response_code,	device_status,
			transmitter_variable_index,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]
		}
	}
	TRANSACTION 2 {
		REQUEST { selection_code_index (INFO,INDEX) }
		REPLY {
			response_code,	device_status,
			selection_code_index,
			UNITS_CODE_NON,
      	selection_codes[selection_code_index].BYTE1,
      	selection_codes[selection_code_index].BYTE2,
      	selection_codes[selection_code_index].BYTE3,
      	selection_codes[selection_code_index].BYTE4
		}
	}
	TRANSACTION 3 {
		REQUEST { selection_code_index_e (INFO,INDEX) }
		REPLY {
			response_code,	device_status,
			selection_code_index_e,
			UNITS_CODE_NON,
      	selection_codes_e[selection_code_index_e].BYTE1,
      	selection_codes_e[selection_code_index_e].BYTE2,
      	selection_codes_e[selection_code_index_e].BYTE3,
      	selection_codes_e[selection_code_index_e].BYTE4
		}
      }

  RESPONSE_CODES {
    0, SUCCESS, [no_command_specific_errors];
    2, DATA_ENTRY_ERROR, [invalid_selection];
    5, MISC_ERROR, [too_few_data_bytes_recieved];
  }
}

//-------------------------------------

COMMAND write_float_variable
{
  NUMBER 129 ;
  OPERATION WRITE ;
  TRANSACTION {
    REQUEST {
			transmitter_variable_index (INFO,INDEX) ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]

    }
    REPLY {
			response_code,	device_status,
			transmitter_variable_index ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]    }
  }
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors] ;
     2, DATA_ENTRY_ERROR, [invalid_selection] ;
     3, DATA_ENTRY_ERROR, [passed_parameter_too_large] ;
     4, DATA_ENTRY_ERROR, [passed_parameter_too_small] ;
     5, MISC_ERROR, [too_few_data_bytes_recieved] ;
     7, MODE_ERROR, [in_write_protect_mode] ;
    12, DATA_ENTRY_ERROR, "Invalid unit code" ;
    32, DATA_ENTRY_ERROR, "Busy" ;
  }
}

//-------------------------------------

COMMAND write_selections
{
  NUMBER 129 ;
  OPERATION WRITE ;
TRANSACTION 1 {
		REQUEST {
			transmitter_variable_index (INFO,INDEX) ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]
		}
		REPLY {
			response_code,	device_status,
			transmitter_variable_index ,
			transmitter_variable_unit_code ,
			transmitter_variable_array [transmitter_variable_index]
		}
	}
	TRANSACTION 2 {
		REQUEST {
			selection_code_index (INFO,INDEX),
			UNITS_CODE_NON,
      	selection_codes[selection_code_index].BYTE1,
      	selection_codes[selection_code_index].BYTE2,
      	selection_codes[selection_code_index].BYTE3,
      	selection_codes[selection_code_index].BYTE4
		}
		REPLY {
			response_code,	device_status,
			selection_code_index,
			UNITS_CODE_NON,
      	selection_codes[selection_code_index].BYTE1,
      	selection_codes[selection_code_index].BYTE2,
      	selection_codes[selection_code_index].BYTE3,
      	selection_codes[selection_code_index].BYTE4
		}
	}
	TRANSACTION 3 {
		REQUEST {
			selection_code_index_e (INFO,INDEX),
			UNITS_CODE_NON,
      	selection_codes_e[selection_code_index_e].BYTE1,
      	selection_codes_e[selection_code_index_e].BYTE2,
      	selection_codes_e[selection_code_index_e].BYTE3,
      	selection_codes_e[selection_code_index_e].BYTE4
		}
		REPLY {
			response_code,	device_status,
			selection_code_index_e,
			UNITS_CODE_NON,
      	selection_codes_e[selection_code_index_e].BYTE1,
      	selection_codes_e[selection_code_index_e].BYTE2,
      	selection_codes_e[selection_code_index_e].BYTE3,
      	selection_codes_e[selection_code_index_e].BYTE4
		}
	}
  RESPONSE_CODES {
     0, SUCCESS, [no_command_specific_errors] ;
     2, DATA_ENTRY_ERROR, [invalid_selection] ;
     3, DATA_ENTRY_ERROR, [passed_parameter_too_large] ;
     4, DATA_ENTRY_ERROR, [passed_parameter_too_small] ;
     5, MISC_ERROR, [too_few_data_bytes_recieved] ;
     7, MODE_ERROR, [in_write_protect_mode] ;
    12, DATA_ENTRY_ERROR, "Invalid unit code" ;
    32, DATA_ENTRY_ERROR, "Busy" ;
  }
}


/*------------------------------------------------------------------------------------*/
/*      transmitter-specific commands #128, #129                                      */
/*------------------------------------------------------------------------------------*/

#define send_trans_read( _status, _transvar ) \
				if( e2211_meth ){ \
					iassign( selection_code_index_e, _transvar ); \
					send_trans( 128, 3, _status ); \
				}else{ \
					iassign( selection_code_index, _transvar ); \
					send_trans( 128, 2, _status ); \
				}

#define send_trans_write( _status, _transvar ) \
				if( e2211_meth ){ \
					iassign( selection_code_index_e, _transvar ); \
					send_trans( 129, 3, _status ); \
				}else{ \
					iassign( selection_code_index, _transvar ); \
					send_trans( 129, 2, _status ); \
				}

/*------------------------------------------------------------------------------------*/
/*      transmitter-specific commands #131                                			  */
/*------------------------------------------------------------------------------------*/

COMMAND cmd_take_sample_calibration
{
	NUMBER          131;
	OPERATION       COMMAND;

	TRANSACTION
	{
		REQUEST{ }
		REPLY{ response_code, device_status	}
	}
	RESPONSE_CODES  {	 
				 0 , SUCCESS ,          [no_command_specific_errors] ; 
				 5 , MISC_ERROR ,       [too_few_data_bytes_recieved] ; 
				16, MODE_ERROR ,		[access_restricted];	
	}
}




//=============================================================================
//  MENU Bar
//=============================================================================

MENU Menu_Main_Specialist
{
  LABEL [main_menu];
  ITEMS {
    Menu_File,
    Menu_S_Device,
    Menu_S_View,
    Menu_Options,
    Menu_Help
  }
}

//-------------------------------------

MENU Menu_Main_Maintenance
{
  LABEL [main_menu];
  ITEMS	{
    Menu_File,
    Menu_M_Device,
    Menu_M_View,
    Menu_Options,
    Menu_Help
  }
}

//-----------------------------------------------------------------------------
//    Menu: File
//-----------------------------------------------------------------------------

MENU Menu_File
{
  LABEL [menu_File];
  ITEMS {
    std_Save,
    SEPARATOR,
    std_Eigenschaften,
    SEPARATOR,
    std_Print,
    std_PrintPreview,
    std_PrintSetup,
    std_PageSetup,
    std_Schriftfelder,
    SEPARATOR,
    std_Exit
  }
}

//-------------------------------------

MENU Menu_S_Device
{
  LABEL [menu_Device];
  ITEMS {
    std_CommWay,
    SEPARATOR,
    std_LoadinDevice,										
    std_LoadinPC,											
    SEPARATOR,
    loop_test,
    self_test,
    master_reset,
    configuration_flag_reset,
    SEPARATOR,
    meth_take_sample_calibration,
    meth_lab_sample_calibration,
    SEPARATOR,
    OnlineDialog_rerange,
    SEPARATOR,
    OnlineDialog_hart_comm
  }
}

MENU Menu_M_Device
{
  LABEL [menu_Device];
  ITEMS {
    std_LoadinDevice,										
    std_LoadinPC,											
    SEPARATOR,
    self_test,
  }
}

//-------------------------------------

MENU Menu_S_View
{
  LABEL [menu_View];
  ITEMS {
    OnlineWindow_display,
    OnlineWindow_S_diagnosis, 
    SEPARATOR,
    std_Funktionsleiste,
    std_Statuszeile,
    SEPARATOR,
    std_Update
  }
}

MENU Menu_M_View
{
  LABEL [menu_View];
  ITEMS {
    OnlineWindow_display,
    OnlineWindow_M_diagnosis, 
    SEPARATOR,
    std_Funktionsleiste,
    std_Statuszeile,
    SEPARATOR,
    std_Update
  }
}

//-------------------------------------

MENU Menu_Options
{
  LABEL [menu_Options];
  ITEMS {
    std_Einstellungen,
    std_Untereintraege
  }
}

//-------------------------------------

MENU Menu_Help
{
  LABEL [menu_Help];
  ITEMS {
    std_Hilfethemen,
    std_HilfeKontext,
    SEPARATOR,
    std_HilfeGeraet,
    SEPARATOR,
    std_HilfeEinfuehrung,
    std_HilfeErsteSchritte,
    SEPARATOR,
    std_Hilfebenutzen,
    std_Info
  }
}

//=============================================================================
//  Online-Windows
//=============================================================================

MENU OnlineWindow_display	// sollte vorhanden sein (Button: Mewertanzeige)
{
  LABEL [menu_dialog_display];
  ITEMS {
    Page_1_display		// sollte vorhanden sein (Button: Mewertanzeige)
  }
}

//-----------------------------------------------------------------------------

MENU Page_1_display		// sollte vorhanden sein (Button: Mewertanzeige)
{
  LABEL "Mettler Toledo - pH 2100e/2(X)H";
  ITEMS {
    analog_output_fixed1 (READ_ONLY),
    BarVal_meas_display,
    Val_temp_display,
    mA_output_current (READ_ONLY),
    var_ph,
    var_orp,
    var_temp,
    device_status
  }
}

//-------------------------------------

MENU BarVal_meas_display
{
	LABEL	[menu_dialog_display_measure];

  ITEMS {
			sensor_value, /*,main_unit, /**/
		    output_current_lrv		(READ_ONLY),
		    output_current_urv		(READ_ONLY)
 }

}



//-------------------------------------

MENU Val_temp_display
{
  LABEL	"Temperature"	"|de|Temperatur";
  ITEMS {
    sv_temp_value
  }
}

//-----------------------------------------------------------------------------

MENU OnlineWindow_S_diagnosis
{
  LABEL	[menu_dialog_diagnosis];
  ITEMS {
    OnlineWindow_diagnosis_device,
    Page_S_diagnosis_status
  }
}

MENU OnlineWindow_M_diagnosis
{
  LABEL	[menu_dialog_diagnosis];
  ITEMS {
    OnlineWindow_diagnosis_device,
    Page_M_diagnosis_status
  }
}

//-------------------------------------

MENU OnlineWindow_diagnosis_device
{
  LABEL	[menu_ident_device];
  ITEMS {
    tag			 (READ_ONLY),
// ??? removed by Siemens 03/29/99:    unit_tag		 (READ_ONLY),
    manufacturer_id	 (READ_ONLY),
    device_id		 (READ_ONLY),
    device_type		 (READ_ONLY),
    software_revision	 (READ_ONLY),
    hardware_revision	 (READ_ONLY),
    transmitter_revision (READ_ONLY),
    universal_revision	 (READ_ONLY)
  }
}

//-------------------------------------

MENU Page_S_diagnosis_status
{
  LABEL	"Errors && Smileys" "|de|Fehler && Smileys";
  ITEMS {
    xmtr_specific_status_0 (READ_ONLY),
    analog_output_fixed1	(READ_ONLY),
    function_check_status	(READ_ONLY),
    xmtr_specific_status_1	(READ_ONLY),
    xmtr_specific_status_2	(READ_ONLY),
	analog_aoutput_saturated1 (READ_ONLY),
    configuration_flag_reset
  }
}

MENU Page_M_diagnosis_status
{
  LABEL	"Errors && Smileys" "|de|Fehler && Smileys";
  ITEMS {
    xmtr_specific_status_0 (READ_ONLY),
    analog_output_fixed1	(READ_ONLY),
    function_check_status	(READ_ONLY),
    xmtr_specific_status_1	(READ_ONLY),
    xmtr_specific_status_2	(READ_ONLY),
	analog_aoutput_saturated1 (READ_ONLY),
    configuration_flag_reset
  }
}

//-------------------------------------

MENU OnlineDialog_rerange
{
  LABEL	[menu_window_lo_up_value];
  ITEMS {
    Page_rerange
  }
}

//-------------------------------------

MENU Page_rerange  //Messbereich Anfang/Ende
{
  LABEL	[menu_window_lo_up_value];
  ITEMS {
    primary_variable, 					//selected_pv_unit,		 //primary_variable
    output_current_lrv, 			//  4 mA Eingabe
    sensor_lower_limit (READ_ONLY),	//max LOWER Limit	
    output_current_urv, 			// 20 mA Eingabe	
    sensor_upper_limit (READ_ONLY),	//max UPPER limit

    sie_set    		
  }
}

//-------------------------------------

MENU OnlineDialog_hart_comm
{
  LABEL	[menu_HART_Comm];
  ITEMS {
    Page_polling_address,
    Page_request_response_preambles
  }
}

//-------------------------------------

MENU Page_polling_address
{
  LABEL	[menu_polling_address];
  ITEMS {
    polling_address,
    polling_address_set
  }
}

//-------------------------------------

MENU Page_request_response_preambles
{
  LABEL	[menu_request_response_preambles];
  ITEMS {
    response_preambles,
    request_preambles,
    sie_set
  }
}

//-----------------------------------------------------------------------------
//   Standard Methods
//-----------------------------------------------------------------------------

METHOD SEPARATOR
{
  LABEL	[menu_Separator];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Save
{
  LABEL	[menu_File_Save];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Eigenschaften
{
  LABEL	[menu_File_Properties];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Print
{
  LABEL	[menu_File_Print];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PrintPreview
{
  LABEL	[menu_File_PrintPreview];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PrintSetup
{
  LABEL	[menu_File_PrintSetup];
  DEFINITION { }
}

//-------------------------------------

METHOD std_PageSetup
{
  LABEL	[menu_File_PageSetup];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Schriftfelder
{
  LABEL	[menu_File_Labels];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Exit
{
  LABEL	[menu_File_Exit];
  DEFINITION { }
}

//-------------------------------------

METHOD std_CommWay
{
  LABEL	[menu_Device_CommWay];
  DEFINITION { }
}

//-------------------------------------

METHOD std_LoadinDevice
{
  LABEL	[menu_Device_LoadinDevice];
  DEFINITION { }
}

//-------------------------------------

METHOD std_LoadinPC
{
  LABEL	[menu_Device_LoadinPC];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Funktionsleiste
{
  LABEL	[menu_View_Toolbar];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Statuszeile
{
  LABEL	[menu_View_Statusbar];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Update
{
  LABEL	[menu_View_Update];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Einstellungen
{
  LABEL	[menu_Options_Properties];
  DEFINITION { }
}

//-------------------------------------

METHOD std_Untereintraege
{
  LABEL	[menu_Options_Subitems];
  DEFINITION { }
}


//=============================================================================
//  Table
//=============================================================================

MENU Table_Main_Specialist
{
  LABEL "Mettler Toledo - pH 2100e/2(X)H";
  ITEMS {
    Tab_s_identification,
    Tab_s_inputs,
    Tab_s_outputs,
    Tab_s_calibration
  }
}

//-------------------------------------

MENU Tab_s_identification
{
  LABEL [menu_ident];
  ITEMS {
    Tab_s_opunit,
    Tab_s_device
  }
}

//-------------------------------------

MENU Tab_s_opunit
{
  LABEL [menu_ident_opunit];
  ITEMS {
    tag,
    descriptor,
    message
  }
}

//-------------------------------------

MENU Tab_s_device
{
  LABEL [menu_ident_device];
  ITEMS	{
    manufacturer_id,
    universal_revision,
    transmitter_revision,
    software_revision,
    hardware_revision,
    device_id,
    device_type,
    device_flags,
    physical_signaling_code,
    final_assembly_number,
    date
  }
}

//-------------------------------------

MENU Tab_s_inputs
{
  LABEL "Inputs" "|de|Eingang";
  ITEMS {
	selected_pv_unit,
	selected_eltype,
    selected_temp_mode ,
	selected_temp_mode_e,
	var_temp_meas,
	var_temp_cal,
	selected_temp_sensor,
	var_TClin
  }
}

//-------------------------------------

MENU Tab_s_outputs
{
  LABEL "Outputs" "|de|Ausgang";
  ITEMS	{
    output_current_lrv,		// Anfang (4mA)
    output_current_urv,		// Ende  (20mA)
	var_filter_1,
    selected_22mA,		// 22mA bei Fehler
    selected_hold_fix,		// HOLD Last/Fix
    var_fix_value		// HOLD-Fix Wert

	//mA_output_current,
	//percent_of_range

  }
}

//-------------------------------------
MENU Tab_s_calibration
{
  LABEL "Cal settings"	"|de|Cal Einstellungen";
  ITEMS	{
	selected_bufferset,
	selected_bufferset_e,
	var_buffer_1,
	var_buffer_2,
	var_cal_timer,
	var_asym_pot,
	var_slope,
    selected_senso_check,
    var_alarmdelay_1,
	selected_holdLED
  }
}



//-----------------------------------------------------------------------------

MENU Table_Main_Maintenance
{
  LABEL "Mettler Toledo - pH 2100e/2(X)H";
  ITEMS {
    Tab_m_identification,
    Tab_m_inputs,
    Tab_m_outputs,
    Tab_m_calibration,
  }
}

//-------------------------------------

MENU Tab_m_identification
{
  LABEL [menu_ident];
  ITEMS {
    Tab_s_opunit,
    Tab_s_device
  }
}

//-------------------------------------

MENU Tab_m_opunit
{
  LABEL [menu_ident_opunit];
  ITEMS {
    tag (READ_ONLY),
    descriptor,
    message
  }
}

//-------------------------------------

MENU Tab_m_device
{
  LABEL [menu_ident_device];
  ITEMS	{
    manufacturer_id,
    universal_revision,
    transmitter_revision,
    software_revision,
    hardware_revision,
    device_id,
    device_type,
    device_flags,
    physical_signaling_code,
    final_assembly_number,
    date
  }
}

//-------------------------------------

MENU Tab_m_inputs
{
  LABEL "Inputs" "|de|Eingang";
  ITEMS {
	selected_pv_unit (READ_ONLY),
	selected_eltype (READ_ONLY),
    selected_temp_mode (READ_ONLY),
	selected_temp_mode_e (READ_ONLY),
	var_temp_meas (READ_ONLY),
	var_temp_cal (READ_ONLY),
	selected_temp_sensor (READ_ONLY),
	var_TClin (READ_ONLY)  }
}

//-------------------------------------

MENU Tab_m_outputs
{
  LABEL "Outputs" "|de|Ausgang";
  ITEMS	{
    output_current_lrv (READ_ONLY),		// Anfang (4mA)
    output_current_urv (READ_ONLY),		// Ende  (20mA)
	var_filter_1 (READ_ONLY),
    selected_22mA (READ_ONLY),		// 22mA bei Fehler
    selected_hold_fix (READ_ONLY),		// HOLD Last/Fix
    var_fix_value (READ_ONLY)		// HOLD-Fix Wert

  }
}

//-------------------------------------
MENU Tab_m_calibration
{
  LABEL "Cal settings"	"|de|Cal Einstellungen";
  ITEMS	{
	selected_bufferset (READ_ONLY),
	selected_bufferset_e (READ_ONLY),
	var_buffer_1 (READ_ONLY),
	var_buffer_2 (READ_ONLY),
	var_cal_timer (READ_ONLY),
	var_asym_pot (READ_ONLY),
	var_slope (READ_ONLY),
    selected_senso_check (READ_ONLY),
    var_alarmdelay_1 (READ_ONLY),
	selected_holdLED (READ_ONLY)
  }
}




//=============================================================================
//  Methods
//=============================================================================

METHOD sie_set			// Transmit-Button
{
  LABEL	[transfer];
  HELP	[transfer_help];
  CLASS INPUT;
  DEFINITION { }
}

//-------------------------------------

METHOD polling_address_set
{
  LABEL	[transfer];
  HELP 	[transfer_help];
  CLASS INPUT;
  DEFINITION {
    ACKNOWLEDGE( [message_polling_address] );
  }
}






/*------------------------------------------------------------------------------------*/
/*	methods of value transmitter_variables 			   								  */
/* Warntext wird ausgegeben da die Wert sofort im Gert gendert werden, fr AMS	  */
/* notwendig und im HC275 sinnvoll, der Anwender muss nicht extra <send> drcken 	  */
/*------------------------------------------------------------------------------------*/

#define meth_sample_check_e2211 \
		if( !e2211_meth ){ \
			ACKNOWLEDGE( "Product calibration via HART not available for device software before V4.0. \n\n Press OK to finish" \
						 "|de|Produktkalibrierung ber HART-Kommunikation erst verfgbar ab Softwareversion 4.0. \n\n Drcken Sie OK zum Beenden"  );\
			process_abort(); \
		}

#define meth_head( _check_e ) \
		  		char	status [STATUS_SIZE]; \
				char  disp_string1 [60];    \
				int   slen1;					 \
				int	selc;						 \
				long	ids [2];					 \
				int 	sec;						 \
				slen1 = 60;						 \
				if( _check_e != 0 ){ meth_sample_check_e2211 } \
				get_dictionary_string (remove_loop_from_auto, disp_string1, slen1); \
				ACKNOWLEDGE (disp_string1); \
				add_abort_method (return_to_normal);

#define meth_definition_var( _transvar, _var, _label, _meth ) \
				{	meth_head( 0 ) \
					iassign( transmitter_variable_index, _transvar ); \
					send_trans( 128, 1, status ); \
					GET_DEV_VAR_VALUE ( _label, _var ); \
					IGNORE_ALL_RESPONSE_CODES (); \
					iassign( transmitter_variable_index, _transvar ); \
					send_trans( 129, 1, status ); \
					if (status [STATUS_RESPONSE_CODE]){ \
						display_response_status (132, status [STATUS_RESPONSE_CODE]); \
						ACKNOWLEDGE( "WARNING: Configuration was abborted!\n \nACTION: Repeat this step." \
						"|de|WARNUNG: Konfiguration wurde abgebrochen!\n Hinweis:Wiederholung dieses Schrittes!" ); \
					} \
					process_abort(); \
				}

/*------------------------------------------------------------------------------------*/


//-----------------------------------------------------------------------------

METHOD loop_test
{
  LABEL	[loop_test];
  HELP	[loop_test_help];
  DEFINITION {
    char status[STATUS_SIZE];
    int choice;
    long var_id[1];
    int use_abort_method;
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;
    get_dictionary_string( remove_loop_from_auto, disp_string1, slen1 );
    ACKNOWLEDGE( disp_string1 );
    add_abort_method( return_to_normal );

    IGNORE_ALL_RESPONSE_CODES( );

    use_abort_method = 0;
    do {
      get_dictionary_string( choose_analog_output_level, disp_string1, slen1 );
      get_dictionary_string( choices_4_20_other_end, disp_string2, slen2 );
      choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
      switch( choice ) {
	case 0:		assign_float( primary_analog_current_value, 4.0 ); 
			break;
	case 1:		assign_float( primary_analog_current_value, 20.0 ); 
			break;
	case 2:		get_dictionary_string( loop_output, disp_string1, slen1 );
			GET_DEV_VAR_VALUE( disp_string1, primary_analog_current_value ); 
			break;
	case 3:
	default:	process_abort( );
			break;
      }
      send( 40, status );
      if( !use_abort_method ) {
	if( (status[STATUS_RESPONSE_CODE] != 0) && (status[STATUS_RESPONSE_CODE] != 3) && (status[STATUS_RESPONSE_CODE] != 4) ) {
	  display_response_status( 40, status[STATUS_RESPONSE_CODE] );
	  get_dictionary_string( abort_last_error, disp_string1, slen1 );
	  DELAY( 2, disp_string1 );
	  process_abort( );
	}
	remove_abort_method( return_to_normal );
	add_abort_method( leave_fixed_current_mode );
	use_abort_method = 1;
      }
      if( status[STATUS_RESPONSE_CODE] ) {
	display_response_status( 40, status[STATUS_RESPONSE_CODE] );
	if( (status[STATUS_RESPONSE_CODE] != 3) && (status[STATUS_RESPONSE_CODE] != 4) ) {
	  get_dictionary_string( abort_last_error, disp_string1, slen1 );
	  DELAY( 2, disp_string1 );
	  process_abort( );
	}
      }
      else {
	var_id[0] = VARID( primary_analog_current_value ); 
	get_dictionary_string( fld_dev_otpt_fixed, disp_string1, slen1 );
	acknowledge( disp_string1, var_id );
      }
    } while( choice < 3 );
    process_abort( );
  }
}

//-------------------------------------

METHOD leave_fixed_current_mode
{
  LABEL	[leaving_fixed_current_mode];
  HELP	[leaving_fixed_current_mode_help_2];
  DEFINITION {
    char status[STATUS_SIZE];
    long var_id[1];
    char disp_string1[60];
    int slen1;

    slen1 = 60;

    assign_float( primary_analog_current_value, 0.0 );  
    IGNORE_ALL_RESPONSE_CODES( ); 
    do {
      get_dictionary_string( return_fld_dev_to_orig_otpt, disp_string1, slen1 );
      DELAY( 3, disp_string1 );
      send( 40, status );
      if( status[STATUS_RESPONSE_CODE] ) {
	display_response_status( 40, status[STATUS_RESPONSE_CODE] );
      }
    } while( status[STATUS_RESPONSE_CODE] );
    get_dictionary_string( loop_may_be_returned_to_auto, disp_string1, slen1 );
    ACKNOWLEDGE( disp_string1 );
  }
}

//-----------------------------------------------------------------------------

METHOD self_test
{
  LABEL	[selftest];
  HELP	[selftest_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char status[3];
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;
		
    slen1 = 60;
    slen2 = 60;
		
    get_dictionary_string( selftest_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );
		
    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      add_abort_method( return_to_normal );
      IGNORE_ALL_RESPONSE_CODES( );
      send( 41, status );
      if( (status[STATUS_RESPONSE_CODE] > 1) || status[STATUS_COMM_STATUS] || status[STATUS_DEVICE_STATUS] ) {
	if( status[STATUS_RESPONSE_CODE] > 1 ) {
	  display_response_status( 41, status[STATUS_RESPONSE_CODE] );
	}
	if( status[STATUS_COMM_STATUS] > 1 ) { // COMM_STATUS > 1 damit nur eine Fehlermeldung bei Kommunikationsfehlern ausgegeben wird
	  display_comm_status( status[STATUS_COMM_STATUS] );
	}
	if( status[STATUS_DEVICE_STATUS] ) {
	  display_device_status( status[STATUS_DEVICE_STATUS] );
	}
	process_abort( );
      }
      else {
	get_dictionary_string( selftest_ok, disp_string1, slen1 );
	ACKNOWLEDGE( disp_string1 );
      }
    }
  }
}

//-----------------------------------------------------------------------------

METHOD master_reset
{
  LABEL	[master_reset];
  HELP	[master_reset_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char status[3];
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;

    get_dictionary_string( master_reset_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );

    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      add_abort_method( return_to_normal );
      IGNORE_ALL_RESPONSE_CODES( );
      send( 42, status );
      if( (status[STATUS_RESPONSE_CODE] > 1)|| status[STATUS_COMM_STATUS] || status[STATUS_DEVICE_STATUS] ) {
	if( status[STATUS_RESPONSE_CODE] > 1 ) {
	  display_response_status(41, status[STATUS_RESPONSE_CODE]);
	}
	if( status[STATUS_COMM_STATUS] ) {
	  display_comm_status(status[STATUS_COMM_STATUS]);
	}
	if( status[STATUS_DEVICE_STATUS] ) {
	  display_device_status(status[STATUS_DEVICE_STATUS]);
	}
	process_abort( );
      }
      else {
	get_dictionary_string( master_reset_ok, disp_string1, slen1 );
	ACKNOWLEDGE( disp_string1 );
      }
    }
  }
}

//-----------------------------------------------------------------------------

METHOD configuration_flag_reset
{
  LABEL	[configuration_flag_reset];
  HELP	[configuration_flag_reset_help];
  CLASS INPUT;
  DEFINITION {
    int choice;
    char disp_string1[60];
    char disp_string2[60];
    int slen1;
    int slen2;

    slen1 = 60;
    slen2 = 60;

    get_dictionary_string( configuration_flag_reset_execute, disp_string1, slen1 );
    get_dictionary_string( yes_no, disp_string2, slen2 );

    choice = SELECT_FROM_LIST( disp_string1, disp_string2 );
    if( choice == 0 ) {
      send_command( 38 );
    }
  }
}

/*------------------------------------------------------------------------------------*/
/* e2211pH	calibration methods																		  */
																										

#define 	text_sample_abort "WARNING: Product calibration was abborted!\n \nACTION: Repeat this step."
#define 	text_sample_ok 	  "Press OK finish"	

METHOD meth_take_sample_calibration
{
/* HC275:			"123456789012345678" */
	LABEL          "Take Sample" "|de|Produktkalibrierung - Probenentnahme";
	HELP           "Product Calibration Sequence Take Sample" "|de|Produktkalibrierung Schritt 1 Probenentnahme";
	DEFINITION {
		char   status[STATUS_SIZE] ;
		long   ids[4];

		ids[0] = VARID( sensor_value ) ;
		ids[1] = VARID( selected_pv_unit ) ;
		ids[2] = VARID( sv_temp_value ) ;
		ids[3] = VARID( sv_temp_units ) ;

		meth_sample_check_e2211
		/* e2211 */
		/*----------------*/  

			
			ACKNOWLEDGE("Take a sample from the process and store the currently measured value."
						"\n"
						"Note that the meassured value of the sample is temperature dependent."
						" \n" 
						"Therefore, laboratory measurement should be performed at the sample temperature shown in the display, if possible."
						"\n"
						"As far as possible, you should transport the sample in an insulated container (Dewar)."
						"\n"
						"The meassured value may also be altered due to escaping of volatile substances.\nPress OK to show measured value."

						"|de|Entnehmen Sie dem Proze eine Probe und messen Sie diese, z.B. im Labor."
						"\n"
						"Beachten Sie, da der entnomme Wert temperaturbhngig ist."
						"\n"
						"Die Messung im Labor sollte daher mglichst bei der im Display angezeigten Probentemperatur erfolgen."
						"\n"
						"Transportieren Sie die Probe mglichst in einem Isoliergef (Dewar)."
						"\n" 
						"Der gemessene Wert der Probe kann auch durch Entweichen flchtiger Substanzen verflscht werden."
						"\n"
						"Drcken Sie OK um den gemessenen Wert zu erhalten.");

		/*----------------*/
		send (48, status) ;
	   if( int_value(function_check_status) & 0x03 ){
		/*----------------*/

			ACKNOWLEDGE("WARNING: Device is in calibration or configuration, no sample calibration allowed!"
						"\n\n"
						"ACTION: Leave device calibration or configuration and repeat this step."
						"\n\n"
						"Press OK finish" 
						"|de|WARNUNG: Das Feldgert befindet sich innerhalb einer Kalibrierung oder Konfigurierung, keine Probenentnahme erlaubt!"
						"\n\n"
						"HINWEIS: Verlassen Sie die Kalibrierung oder Konfigurierung und wiederholen Sie diesen Schritt."
						"\n\n"
						"Drcken Sie OK zum Beenden.");


		/*----------------*/
		}else{
	   	if( (int_value(function_check_status) & 0x04) ){
		/*----------------*/

			ACKNOWLEDGE("WARNING: Sample was already taken. If you call <Take Sample> twice then the first sample will be lost!"
						" \n\n"
						"ACTION: Confirm discarding the first sample."
						"\n\n"
						"Press OK to discard the first sample"
						"|de|WARNUNG: Es wurde bereits eine Probe entnommen! Wenn Sie (Produktkalibrierung - Probenentnahme) doppelt drcken, wird der zuerst entnommene Probenwert verworfen!"
						"\n\n"
						"HINWEIS: Besttigen Sie, das der zuletzt entnomme Probenwert verworfen werden kann."
						"\n\n"
						"Drcken Sie OK um den zuletzt entnommen Probenwert zu verwerfen");

		/*----------------*/
			}
		/*----------------*/

		  display(	"Actual measureed value: %{0} %{1}  Temperature: %{2} %{3}" "|de|Aktueller Messwert: %{0} %{1}  Temperatur: %{2} %{3}",ids); 


		/*----------------*/
			IGNORE_ALL_RESPONSE_CODES () ;
			send (131, status) ;
			if (status [STATUS_RESPONSE_CODE]){
				display_response_status (131, status [STATUS_RESPONSE_CODE]) ;
		/*----------------*/

				ACKNOWLEDGE("Press OK finish\n\n WARNING: Product calibration was abborted!"
							"\n\n"
							"ACTION: Repeat this step."
							"|de|Drcken Sie OK zum Beenden. WARNUNG: Produktkalibrierung wurde abgebrochen!"
							"\n\n"
							"HINWEIS:Wiederholen Sie diesen Schritt.");

		/*----------------*/
			}

 

		}
		process_abort();
	}
}

// --------------------------------------------------------------------------------------------------------------------------------
/*Produktkalibrierung Schritt 2
--------------------------------------------------------------------------------------------------------------------------------*/

METHOD meth_lab_sample_calibration
{
/* HC275:			"123456789012345678" */
	LABEL          "Input Lab Sample" "|de|Produktkalibrierung - Vergleichswerteingabe";
	HELP           "Product Calibration Sequence Input Lab Sample" "|de|Produktkalibrierung Schritt2 Vergleichswerteingabe";
	DEFINITION{
		char   status [STATUS_SIZE] ;
	
		float  fval;

		long   ids[1];

		ids[0] = VARID(selected_pv_unit) ;

		meth_sample_check_e2211


			ACKNOWLEDGE("Enter the measured lab value. The new zero point is automatically calculated and stored."
						"\n\n"
						"The values obtained by sample calibration are always accepted, even if they are outside calibration limits!"
						"\n\n"
						"Press OK to enter lab value"

						"|de|Geben Sie den gemessenen Wert der Probe ein. Der neue Meketten-Nullpunkt wird automatisch berechnet und gespeichert."
						"\n\n"
						"Die Werte bei der Probenkalibrierung werden immer bernommen, auch wenn sie auerhalb des Cal-Toleranzbandes liegen!"
						"\n\n"
						"Drcken Sie OK um den Vergleichswert einzugeben");

		/*----------------*/
		send (48, status) ;
	   if( int_value(function_check_status) & 0x03 ){
		/*----------------*/

			ACKNOWLEDGE( "WARNING: Device is in calibration or configuration, no sample calibration allowed"
						 "\n\n" 
						 "ACTION: Leave device calibration or configuration and repeat this step."
						 "\n\n"
						 "Press OK finish"
						
						"|de|WARNUNG: Das Feldgert befindet sich innerhalb einer Kalibrierung oder Konfigurierung, keine Probenentnahme erlaubt!"
						"\n\n"
						"HINWEIS: Verlassen Sie die Kalibrierung oder Konfigurierung und wiederholen Sie diesen Schritt"
						"\n\n"
						"Drcken Sie OK zum Beenden.");

		/*----------------*/
		}else{
	   	if( !(int_value(function_check_status) & 0x04) ){
		/*----------------*/
 

			ACKNOWLEDGE("WARNING: No sample was taken, no sample calibration allowed"
						"\n\n"
						"ACTION: First call <Take Sample> and then <Input Lab Sample>."
						"\n\n"
						"Press OK finish"
						
						"|de|WARNUNG: Es wurde keine Probe entnommen, Produktkalibrierung nicht zulssig!"
						"\n\n"
						"HINWEIS: Als Erstes mssen Sie <Produktkalibrierung - Probenentnahme> und dann <Produktkalibrierung - Vergleichswerteingabe> aufrufen."
						"\n\n"
						"Drcken Sie OK zum Beenden.");

		/*----------------*/
		 
			}else{
                fval = fvar_value (sensor_value);
                get_local_var_value ("Enter the pH/ORP lab value (%{0}) : ""|de|Eingabe des pH/ORP Vergleichwertes (%{0})", ids, fval) ;

				IGNORE_ALL_RESPONSE_CODES () ;

                assign_float (var_sample_cal, fval);
				iassign( transmitter_variable_index, transvar_sample_cal );
				send_trans (129, 1, status);
				if (status [STATUS_RESPONSE_CODE]){
					display_response_status (129, status [STATUS_RESPONSE_CODE]) ;
		/*----------------*/


					ACKNOWLEDGE("WARNING: Product calibration was abborted!\n \nACTION: Repeat this step"
								"\n\n"
								"Press OK finish"

								"|de|WARNUNG: Produktkalibrierung wurde abgebrochen!\n\nHINWEIS:Wiederholen Sie diesen Schritt."
								"\n\n"
								"Drcken Sie OK zum Beenden.");

		/*----------------*/
				}
			}
		}
		process_abort();
	}
}